;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Description:  OneSpace Designer's default "Available Commands" file
;
; (C) Copyright 1997-2005 CoCreate Software GmbH, all rights reserved.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; This file contains definitions of commands which can be used
;; on user defined toolbars, popup menus and in the menubar.
;;
;; Each command can be uniquely identified by the triple
;;      "Application" - "Group" - "Command Name"
;;
;; This file contains definitions of commands which can be used in
;; "All" applications (the first section of this file) and commands which
;; are specific to just "SolidDesigner" (the rest of this file).
;; "All" means that even if you run "Annotation", the commands of the "All"
;; application will be accessible.
;;
;; A line like (:Application "All") indicates, that all following command
;; definitions will belong to the "All" application. This statement is
;; valid until the next (:Application "Other Application") line occurs.
;; Here this will be (:Application "SolidDesigner") later in this file.
;;
;; A line like (:Group "Miscellaneous" :title "Miscellaneous")
;; indicates, that all following command definitions will go into the
;; "Miscellaneous" group. The group name (here "Miscellaneous") will
;; remain the same, even if you run a localized version of SolidDesigner.
;; Just the string after :title will be presented to the user and
;; will be localized. The "current group" remains the same for all
;; following command descriptions until a different (:Group "ABC" ...)
;; line occurs.
;;
;;
;; Command Format Description
;; --------------------------
;;  "first string" {STRING}:
;;       Command Name - unique command name within a group and application
;;  :title {STRING}:
;;       The localized name of the command to appear in the user interface.
;;       This string is displayed as tooltip as well if the command is
;;       used in a toolbar with icons. If this string is not given, the
;;       non-localizable command name is taken as :title.
;;       For multi language support see below.
;;  :action {STRING | LISP form}:
;;       The action of the button. A STRING will be executed using
;;       'sd-put-buffer' and a LISP form will be executed directly.
;;  :description {STRING}:
;;       Optional explanation of the command and its action.
;;       For multi language support see below.
;;  :image {STRING}:
;;       Specification of an image file to be used as toolbar image.
;;       This image has to be in BMP format and will be searched in
;;       the directory
;;               bitmaps/bmp/commands/"image-string"
;;        where image string could contain further directories like
;;        "application"/"group". The physical image file in the specified
;;        directory has to have the file extension ".bmp".
;;        The directory search order is the following:
;;          1. Personal-Profile-Dir/Application Data/CoCreate/OSD_Modeling/ ..
;;               ..  'OSDM-Version'/bitmaps/bmp/commands/
;;          2. $SDSITECUSTOMIZEDIR/bitmaps/bmp/commands/
;;          3. $SDCORPCUSTOMIZEDIR/bitmaps/bmp/commands/
;;          4. $SDINSTALLDIR/personality/bitmaps/bmp/commands/
;;  :ui-behavior {KEYWORD}:
;;       Optional keyword which indicates how the UI of the command should
;;       behave. Possible values: :default, :relative, :on-request or :none
;;       If nothing is specified :default will be used.
;;  :sysCmdId {NUMBER}:
;;       Windows operating system specific commands which are not defined
;;       as LISP functions or action routines.
;;  :range {LIST}:
;;       Specification of a range button which can be used on toolbars.
;;       See "Preselection" command in this file for an example.
;;  :enable {LISP expression}:
;;       This can be either a single LISP global variable or a single
;;       LISP expression (not a (progn ...) expression!). If the variable
;;       or expression evaluates to T (true) at runtime, this command
;;       is accessible by the user otherwise this command will be greyed
;;       out. If no :enable expression is given for a command, the command
;;       is accessible all the time.
;;  :context-enable {LISP expression}:
;;       Similar to ":enable" but this expression decides whether the
;;       command if used on a viewport context menu will be accessible
;;       or not (greyed out). If not given, the command will be accessible
;;       on a context menu without restrictions.
;;  :context-is-visible {LISP expression}:
;;       Similar to ":context-enable" but this expression decides whether the
;;       command if used on a viewport context menu will be visible (and
;;       so accessible) at all. If not given, the command will be 
;;       visible and ":context-enable" decides if it is accessible.
;;  :context-action {STRING | LISP form}:
;;       Similar to ":action" but this action is executed if this
;;       command is called from a viewport popup menu or preselection
;;       context menu. If this action is not given in such cases the
;;       regular ":action" is called.
;;       A specific ":context-action" is useful if you want a
;;       command to be called differently if invoked from a context menu.
;;  :sd-access {Keyword}:  :yes or :no
;;       By default no available command is accessible in "model explorer".
;;       To make all commands of a group accessible in "model explorer", add
;;       the following to the specification of a group:
;;          :all-in-sd-access :yes
;;       If you now want to disable single commands in that group to be
;;       used in "model explorer", specifiy:   :sd-access :no.
;;       If a group has no :all-in-sd-access :yes specified, all commands
;;       of that group are not accessible in "model explorer" (default). To
;;       enable single commands of that group, specify :sd-access :yes
;;       for that command.
;;  :deleted {Boolean}: T/NIL
;;       Usually a user command specification shadows a site command
;;       and a site command shadows corp and corp shadows core SD commands.
;;       If you specify :deleted T for one command you delete this
;;       specific command from the list of available commands which
;;       could be used at runtime to customize the UI.
;;       This enables e.g. a site customization to delete commands
;;       which were defined by corp or sd.
;;
;;  Multi language support:
;;    Instead of writing :title "Title" or :description "Description"
;;    you can also write something like this to support more than
;;    one language with just one available commands file:
;;      :title  (ui::multi-lang "Title in fallback language"
;;                      :german "Title in german"
;;                      :french "Title in french"
;;                      :italian "Title in italian"
;;                      :japanese "Title in japanese")
;;    Depending on the language setting of your environment, SolidDesigner
;;    will pick the appropriate title. Note, just the first fallback
;;    title has to be given. All other keyword title pairs are
;;    optional. If e.g. you specified just
;;       :title  (ui::multi-lang "Title in fallback language"
;;                      :french "Title in french")
;;    and you run SolidDesigner in german, the fallback title will be
;;    taken. So, usually the fallback title is in english language.
;;    This multi language support is available for group titles,
;;    command titles and command descriptions as well as in other
;;    toolbar, menubar and context menu definition files.
;;    Warning: 
;;      In case you run OneSpace Designer in a 2-byte environment like
;;      japanese you can't use foreign language characters with an ASCII
;;      code bigger than 127 or less than 32. This may lead to a LISP error
;;      while evaluating this function.
;;      The same is true if you run OneSpace Designer in a 1-byte environment
;;      like german. Here you can't use german umlauts (ASCII code bigger
;;      than 127) while you have a japanese string defined as well using
;;      this function.
;;      In general: It is dangerous and may lead to LISP errors while
;;      evaluation if you use 1-byte characters with an ASCII code bigger
;;      than 127 or less than 32 in a 1-byte string and you define a 2-byte
;;      string as well.

;;===== Commands valid in all Applications ====================================

(:Application "All")

;;----- All: Miscellaneous ----------------------------------------------------

(:Group "Miscellaneous" :title "Varie"
	:all-in-sd-access :yes)

("OK"
 :title       "OK"
 :action      "complete"
 :description "Conclude un comando in corso"
 :image       "All/Miscellaneous/ok")

("Cancel"
 :title       "Annulla"
 :action      "cancel"
 :description "Annulla un comando in corso"
 :image       "All/Miscellaneous/cancel")

("Cancel All"
 :title       "Annulla Tutto"
 :action      "cancel_all"
 :description "Annulla tutti i comandi in corso"
 :image       "All/Miscellaneous/cancel_all")

("Customize ..."
 :title       "&Personalizza ..."
 :sysCmdId    32774                             ;; ID_VIEW_CUSTOMIZE
 :description "Personalizza Barre Strumenti, Menu Strumenti, Menu Popup e Tastiera")

("Toolbars"
 :title       "Barre Strumenti"
 :sysCmdId    50193
 :description "Sar sostituito all'esecuzione con tutte le barre strumenti accessibili")

("Toolbox Buttons"
 :title       "Pulsanti Barra Strumenti"
 :sysCmdId    50192
 :enable      (NOT (inq-onespace3d))
 :description "Vengono sostituiti nell'esecuzione con i pulsanti della barra strumenti utente.")

("Command Specific Commands"
 :title       "Comandi Specifici"
 :sysCmdId    38600
 :description "Saranno sostituiti nell'esecuzione con comandi specifici per il comando attivo corrente")

("Activated Applications"
 :title       "Applicazioni Attivate"
 :sysCmdId    38900
 :description "Sar sostituito dinamicamente con le applicazioni attivate"
 :sd-access   :yes)

("Modules ..."
 :title       "&Moduli ..."
 :action      (ui::uic-show-module-controller)
 ;;:enable      (NOT (inq-onespace3d))
 :description "Mostra un menu per caricare Moduli e Applicazioni aggiuntivi")

;; the following is a trick to make the Exit button look correct in SD Access
("Exit"
 :title       "&Esci"
 :action      "exit"
 :image       "All/Miscellaneous/exit"
 :description "Esce da model explorer")

("Exit"
 :title       "&Esci"
 :action      "exit"
 :image       "All/Miscellaneous/exit"
 :description "Esce da CoCreate OneSpace Modeling"
 :sd-access   :no)

("SolidDesigner"
 :title       "OneSpace Modeling"
 :action      "cancel_all (oli::sd-switch-application \"SolidDesigner\")"
 :description "Passa all'applicazione OneSpace Modeling"
 :image       "All/Miscellaneous/soliddesigner"
 :sd-access   :yes)

("SheetAdv"
 :title       "Sheet Metal"
 :action      "cancel_all (oli::sd-switch-application \"SheetAdvisor\")"
 :description "Passa all'applicazione Sheet Metal"
 :enable      (oli::sd-module-active-p "SHEETADVISOR")
 :sd-access   :no)

("Annotation"
 :title       "Annotation"
 :action      (if (oli::sd-module-active-p "ANNOTATION")
                  (put-buffer "cancel_all (oli::sd-switch-application \"Annotation\")")
               ;;else
                  (ui::act_deact_module :act "ANNOTATION"
                                             "MODULE-CONTROLLER-Applications-ANNOTATION-TB"
                                             '(STARTUP::ACTIVATE-ANNOTATION)))
 :description "Passa all'applicazione Annotation"
 :image       "All/Miscellaneous/annotation"
 :sd-access   :yes)

("3DDocu"
 :title       "3D Documentation"
 :action      "cancel_all (oli::sd-switch-application \"3D Documentation\")"
 :description "Passa all'applicazione Documentazione 3D"
;; :image       "All/Miscellaneous/3ddocu"
 :enable      (startup:license-free-module-active-p "3DDOCU")
 :sd-access   :no
)

("PCB I/F"
 :title       "PCB I/F"
 :action      "cancel_all (oli::sd-switch-application \"PCB I/F\")"
 :description "Passa all'applicazione PCB I/F"
;; :image       "All/Miscellaneous/pcb_if"
 :enable      (oli::sd-module-active-p "EELINK")
 :sd-access   :no
)

("SolidLib"
 :title       "3D Library"
 :action      "cancel_all (oli::sd-switch-application \"SolidLibrary\")"
 :description "Passa a 3D Library"
;; :image       "All/Miscellaneous/solid_library"
 :enable      (or (oli::sd-module-active-p "SolidLibJu") (oli::sd-module-active-p "SolidLibAd"))
 :sd-access   :no
)

("Des.Adv."
 :title       "Design Integrity"
 :action      "cancel_all (oli::sd-switch-application \"DesignAdvisor\")"
 :description "Passa all'applicazione Design Integrity"
;; :image       "All/Miscellaneous/design_advisor"
 :sd-access   :no
)

("ToleranceAdvisor"
 :title       "ToleranceAdvisor"
 :action      "cancel_all (oli::sd-switch-application \"ToleranceAdvisor\")"
 :description "Passa all'applicazione AssistenteTolleranze"
;; :image       "All/Miscellaneous/tolerance_advisor"
 :sd-access   :no
)

("MoldDesignAdvisor"
 :title       "Mold Design"
 :action      "cancel_all (oli::sd-switch-application \"Mold Design Advisor\")"
 :description "Passa all'applicazione Mold Design."
;; :image       "All/Miscellaneous/mold_design_advisor"
 :enable      (oli::sd-module-active-p "MOLDDESIGNADVISOR")
 :sd-access   :no
)

("MoldBaseAdvisor"
 :title       "Mold Base"
 :action      "cancel_all (oli::sd-switch-application \"Mold Base Advisor\")"
 :description "Passa all'applicazione Mold Base."
;; :image       "All/Miscellaneous/mold_base_advisor"
 :enable      (oli::sd-module-active-p "MOLDBASEADVISOR")
 :sd-access   :no
)

("Toggle Open Menus"
 :title       "Cambia Menu Aperti"
 :action      (ui::uic-toggle-all-open-menus))

;;----- All: Filing -----------------------------------------------------------

(:Group "Filing" :title "Archiviazione")

("Edit File ..."
  :title        "Modifica File ..."
  :action       "edit"
  :description  "Apre un file in un editor di testi")

("Remote ..."
 :title       "Remoto ..."
 :action      (ui::uic-show-remote-menu)
 :description "Mostra un menu per le operazioni remote"
 :enable      frame2::*remote-initialized*)

("CD -> HOME"
 :title       "CD -> HOME"
 :action      (ui::uic-cd-home)
 :description "Imposta la cartella corrente alla home o profilo utente"
 :image       "All/Filing/cd_home")

("Recent File"
 :sysCmdId    #xE110       ;; ID_FILE_MRU_FIRST
 :sd-access   :yes)

;;----- All: Print ------------------------------------------------------------

(:Group "Print" :title "Stampa"
	:all-in-sd-access :yes)

("Print Setup ..."
 :title       "Imposta S&tampa"
 :sysCmdId    #xE106                            ;; ID_FILE_PRINT_SETUP
 :description "Modifica la stampante e le opzioni di stampa")

;;----- All: Edit ---------------------------------------------------

(:Group "Edit" :title "Modifica")

("Copy"
 :title       "&Copia"
 :sysCmdId    #xE122                 ;; ID_EDIT_COPY
 :description "Copia la selezione e la pone negli Appunti"
 :image       "SolidDesigner/Edit/copy"
 :sd-access   :yes)

("Paste"
 :title       "Incolla"
 :sysCmdId    #xE125                 ;; ID_EDIT_PASTE
 :description "Inserisce il contenuto degli Appunti"
 :image       "SolidDesigner/Edit/paste")

("Paste Special..."
 :title       "Incolla &Speciale..."
 :sysCmdId    #xE127                 ;; ID_EDIT_PASTE_SPECIAL
 :description "Inserisce il contenuto degli Appunti con opzioni"
 :image       "SolidDesigner/Edit/specialPaste")

;;----- All: Help -------------------------------------------------------------

(:Group "Help" :title "Guida")

("CoCreate on the Web"
 :title       "CoCreate sul Web"
 :action      (oli::sd-display-url 
	       (ui::multi-lang "http://www.cocreate.com"
			       :german   "http://www.cocreate.de"
			       :japanese "http://japan.cocreate.com"))
 :description "Home Page CoCreate"
 :image       "SolidDesigner/Help/cocreate_on_the_web"
 :sd-access   :yes)

("Contact Support"
 :title       "Centro assistenza CoCreate"
 :action      (oli::sd-display-url
	       (if (inq-onespace3d)
	       (ui::multi-lang "https://apps.cocreate.com/OneSpaceModelingPE/secure/index.cfm"
			       :german   "https://apps.cocreate.com/OneSpaceModelingPE/de/secure/index.cfm"
			       :italian  "https://apps.cocreate.com/OneSpaceModelingPE/it/secure/index.cfm"
			       :japanese "https://apps.cocreate.com/OneSpaceModelingPE/jp/secure/index.cfm")
	       (ui::multi-lang "http://www.cocreate.com/esupport"
			       :german   "http://www.cocreate.de/esupport"
			       :japanese "http://japan.cocreate.com/esupport")
				)
		)
 :description "Contattare il Centro assistenza CoCreate"
 :image       "SolidDesigner/Help/cocreate_on_the_web"
 :sd-access   :yes)

("RegisterForNewsletter"
 :title       "Registra per eNews mensili"
 :action      (frame2-ui::register-for-newsletter)
 :description "Registrazione per eNews mensili"
 :image       "SolidDesigner/Help/cocreate_on_the_web"
 :sd-access   :yes)

("QuickStartTutorial"
 :title       "Progetti rapidi"
 :action      (frame2-ui::show-quickstart-tutorial-dialog)
 :description "Apri progetti rapidi"
 :image       "SolidDesigner/Help/tip_of_the_day"
 :sd-access   :yes)

("CoCreate Web What's New"
 :title       "Novit nel Web"
 :action      (ui::display-cocreate-web-url)
 :description "Pagina Web "What's New" CoCreate"
 :image       (ui::get-last-cocreate-web-icon)
 :sd-access   :yes)

;; the following is a trick to make the About button look correct in SD Access
("About SolidDesigner ..."
 :title       "&Informazioni su model explorer..."
 :sysCmdId    #xE140    ;; ID_APP_ABOUT
 :description "Mostra informazioni sul programma, versione e copyright"
 :image       "All/Miscellaneous/osd_gear"
 :sd-access   :yes)

("About SolidDesigner ..."
 :title       "Inform&azioni su CoCreate OneSpace Modeling ..."
 :sysCmdId    #xE140    ;; ID_APP_ABOUT
 :description "Mostra informazioni sul programma, versione e copyright"
 :image       "All/Miscellaneous/osd_gear"
 :sd-access   :no)

("Command Index"
 :title       "Indice Comandi"
 :action      "info :commands"
 :description "Indice della guida per i comandi"
 :image       "SolidDesigner/Help/help_cmd_index"
 :sd-access   :no)

("On Context"
 :title       "Sul Contesto"
 :action       "info :context"
 :description "Guida relativa al contesto corrente"
 :image       "SolidDesigner/Help/help_on_context"
 :sd-access   :yes)

("On Product"
 :title       "Temi della guida"
 :action      "info :soliddesigner"
 :description "Sistema di guida online"
 :image       "SolidDesigner/Help/help_on_product"
 :sd-access   :no)

("On Interface"
 :title       "Sull'Interfaccia"
 :action      "info :uinterface"
 :description "Guida all'interfaccia utente"
 :image       "SolidDesigner/Help/help_on_interface"
 :sd-access   :no)

("What's New"
 :title       "Novit"
 :action "info :whatsnew"
 :description "Novit"
 :image       "SolidDesigner/Help/WhatsNew"
 :sd-access   :no)

("Getting Started"
 :title       "Per Cominciare"
 :action "info :getstarted"
 :description "Per Cominciare"
 :sd-access   :no)

("Tip of the Day"
 :title	      "Suggerimento del Giorno"
 :sysCmdId	184  ; CG_IDS_TIPOFTHEDAYHELP
 :description "Mostra il Suggerimento del Giorno"
 :image       "SolidDesigner/Help/tip_of_the_day"
 :sd-access   :no)


;;----- All: View -------------------------------------------------------------

(:Group "View" :title "Vista"
	:all-in-sd-access :yes)

("MainTask Bar"
 :title       "&Barra applicazioni"
 :sysCmdId    32786                  ;; ID_VIEW_MAINTASKBAR
 :description "Mostra o nasconde la barra delle applicazioni"
 :sd-access   :no)

("Enter Command"
 :title       "Linea di &Inserimento Utente"
 :sysCmdId    32773                  ;; ID_VIEW_ENTER_COMMAND
 :description "Mostra o nasconde la linea di comando")

("Status Bar"
 :title       "Barra di St&ato"
 :sysCmdId    #xE801                 ;; ID_VIEW_STATUS_BAR
 :description "Mostra o nasconde la barra di stato")

("Prompt Bar"
 :title       "Barra di &richiesta"
 :sysCmdId    32891
 :description "Mostra o nasconde la barra di richiesta")

("Console"
 :title       "&Console"
 :sysCmdId    32777                  ;; ID_SHOW_HIDE_CONSOLE
 :description "Mostra o nasconde la console")

("Show Console"
 :title       "Mostra Console"
 :sysCmdId    32888                  ;; ID_SHOW_CONSOLE
 :description "Mostra la console")

("Hide Console"
 :title       "Nascondi Console"
 :sysCmdId    32889                  ;; ID_HIDE_CONSOLE
 :description "Nasconde la console")

 ("Create Thumbnail"
 :title       "Crea Miniatura"
 :action      "create_thumbnail"
 :description "Avvia la finestra di dialogo per la creazione di miniatura"
 :image       "SolidDesigner/View/thumbnail_view")

("Catch"
 :title       "&Attiva"
 :sysCmdId    32775                  ;; ID_VIEW_CATCHBAR
 :description "Mostra o nasconde la barra di attivazione")

("Browser Bar"
 :title       "&Barra Elenchi"
 :action      (ui::uic-toggle-structure-browser-or-browser-bar)
 :description "Mostra o nasconde la finestra di dialogo elenchi"
 :image       "SolidDesigner/View/structure_browser")

("Structure Browser"
 :title       "Elenco &Struttura"
 :action      (ui::uic-toggle-graphical-browser "parcel-gbrowser")
 :description "Mostra l'elenco della struttura"
 :image       "SolidDesigner/View/structure_browser")

("Viewport"
 :title       "F. vista"
 :action      (frame2-ui::show-viewport-menu)
 :description "Mostra il menu finestra vista")

("Graphics Settings ..."
 :title       "&Impostazioni grafica"
 :action      (frame2-ui::show-general-vp-settings)
 :description "Modifica le impostazioni per tutte le viste")

("Contour Map Settings ..."
 :title       "Imp&ostazioni mappa contorno"
 :action      (frame2-ui::show-contour-map-settings)
 :description "Modifica le impostazioni per la mappa contorno"
 :sd-access   :no)

("Clip Plane Settings ..."
 :title       "I&mpostazioni piano di clipping del modello"
 :action      "model_clipplane"
 :description "Modifica le impostazioni del piano di clipping del modello")

("Viewport Settings ..."
 :title       "Impostazioni finestra &vista"
 :action      (frame2-ui::show-vp-settings)
 :description "Modifica illuminazione, colore, direzione, eccc.. della finestra vista")

("Show Settings ..."
 :title       "Impo&stazioni di visualizzazione"
 :action      (frame2-ui::show-show-settings)
 :description "Modifica opzioni di visualizzazione per la finestra vista")

("Light Settings ..."
 :title       "Impostazioni luc&i"
 :action      (frame2-ui::show-light-settings)
 :description "Modifica impostazioni per le luci della finestra vista"
 :image       "SolidDesigner/View/light_settings")

("Render"
 :title       "Rendering"
 :action      "sd_rendering"
 :description "Effettua il rendering del contenuto attuale della finestra vista"
 :image       "SolidDesigner/View/render"
 :enable      rendering::*render-enabled*)

("Last View"
 :title       "U&ltima Vista"
 :action      (ui::uic-vp-cmd "last_window_vp")
 :description "Mostra l'ultima vista"
 :image       "SolidDesigner/View/last_view")

("Fit"
 :title       "Ottimi&zza"
 :action      (ui::uic-vp-cmd "fit_vp")
 :description "Ottimizza il contenuto della finestra vista"
 :image       "SolidDesigner/View/fit_vp")

("Redraw"
 :title       "&Ridisegna"
 :action      (ui::uic-vp-cmd "redraw_vp")
 :description "Ridisegna il contenuto della finestra vista"
 :image       "SolidDesigner/View/redraw_vp")

("Window"
 :title       "Finest&ra"
 :action      (ui::uic-vp-cmd "window_vp")
 :description "Definisce una nuova finestra"
 :image       "SolidDesigner/View/window_vp")

("Move View Center"
 :title       "Sposta il Centro della Vista"
 :action      (ui::uic-vp-cmd "center_vp")
 :description "Centra la finestra vista"
 :image       "SolidDesigner/View/center_vp")

("Set View Center"
 :title       "Imposta il &Centro della Vista"
 :action      (ui::uic-vp-cmd "uic_set_vp_center")
 :description "Definisce il centro della vista indicando un punto"
 :image       "SolidDesigner/View/center_vp2"
 :ui-behavior :relative)

("Dynamic ..."
 :title       "D&inamico ..."
 :action      (ui::uic-vp-cmd "dynamic_vp")
 :description "Controlla dinamicamente la finestra vista"
 :image       "SolidDesigner/View/dynamic_vp")

("Zoom Out 2"
 :title       "Riduci Fattore 2"
 :action      (ui::uic-zoom-vp -2)
 :description "Riduce la finestra attuale di un fattore 2"
 :image       "SolidDesigner/View/zoom_out_2")

("Zoom Out 5"
 :title       "Riduci Fattore 5"
 :action      (ui::uic-zoom-vp -5)
 :description "Riduce la vista attuale di un fattore 5"
 :image       "SolidDesigner/View/zoom_out_5")

("Zoom Out 10"
 :title       "Riduci Fattore 10"
 :action      (ui::uic-zoom-vp -10)
 :description "Riduce la vista attuale di un fattore 10"
 :image       "SolidDesigner/View/zoom_out_10")

("Zoom In 2"
 :title       "Ingrandisci Fattore 2"
 :action      (ui::uic-zoom-vp 2)
 :description "Ingrandisce la vista attuale di un fattore 2"
 :image       "SolidDesigner/View/zoom_in_2")

("Zoom In 5"
 :title       "Ingrandisci Fattore 5"
 :action      (ui::uic-zoom-vp 5)
 :description "Ingrandisce la vista attuale di un fattore 5"
 :image       "SolidDesigner/View/zoom_in_5")

("Zoom In 10"
 :title       "Ingrandisci Fattore 10"
 :action      (ui::uic-zoom-vp 10)
 :description "Ingrandisce la vista attuale di un fattore 10"
 :image       "SolidDesigner/View/zoom_in_10")

("Flip View"
 :title       "Ribalta Vista"
 :action      (ui::uic-vp-cmd "uic_flip_vp")
 :description "Ribalta le viste nella finestra vista attuale"
 :image       "SolidDesigner/View/flip_view")

("View by Curr WP"
 :title       "Vedi da PL Corrente"
 :action      (ui::uic-curr-wp-vp-cmd "uic_view_by_wp_and_fit (oli::sd-inq-curr-wp) :off")
 :description "Modifica la vista dell'attuale finestra vista per renderla ortogonale al PL corrente"
 :image       "SolidDesigner/View/view_by_curr_wp")

("View by Curr WP and Fit"
 :title       "Vedi da PL corrente e Ottimizza"
 :action      (ui::uic-curr-wp-vp-cmd "uic_view_by_wp_and_fit (oli::sd-inq-curr-wp) :on")
 :description "Modifica la vista della finestra vista attuale per renderla ortogonale al PL attivo e adattarla alla vista"
 :image       "SolidDesigner/View/view_by_curr_wp_fit")

("View by Any WP"
 :title       "Vedi da ogni PL"
 :action      (ui::uic-vp-cmd "set_vp_direction_normal_to_wp")
 :description "Modifica la vista dell'attuale finestra vista per renderla ortogonale a qualunque PL"
 :image       "SolidDesigner/View/view_by_any_wp")

("View by Face"
 :title       "Vedi da Faccia"
 :action      (ui::uic-vp-cmd "uic_view_by_face")
 :description "Modifica la vista della finestra vista attuale per renderla ortogonale a qualunque faccia"
 :image       "SolidDesigner/View/view_by_face")

("View by Face and Center"
 :title       "Vedi da Faccia e Centra"
 :action      (ui::uic-vp-cmd "uic_view_by_face_and_center")
 :description "Cambia la vista della finestra vista attuale rendendola ortogonal alla faccia selezionata e imposta il punto centrale per le operazioni di vista dinamica successive."
 :image       "SolidDesigner/View/view_by_face_center")

("Isometric XYZ"
 :title       "XYZ Isometrica"
 :action      (ui::uic-set-vp-dir 1,1,1)
 :image       "SolidDesigner/View/isometric_view_xyz")

("Isometric XY-Z"
 :title       "XY-Z Isometrica"
 :action      (ui::uic-set-vp-dir 1,1,-1)
 :image       "SolidDesigner/View/isometric_view_xy-z"
 )

("Isometric X-Y-Z"
 :title       "X-Y-Z Isometrica"
 :action      (ui::uic-set-vp-dir 1,-1,-1)
 :image       "SolidDesigner/View/isometric_view_x-y-z"
 )

("Isometric -XY-Z"
 :title       "-XY-Z Isometrica"
 :action      (ui::uic-set-vp-dir -1,1,-1)
 :image       "SolidDesigner/View/isometric_view_-xy-z"
 )

("Isometric -X-Y-Z"
 :title       "-X-Y-Z Isometrica"
 :action      (ui::uic-set-vp-dir -1,-1,-1)
 :image       "SolidDesigner/View/isometric_view_-x-y-z"
 )

("Isometric -XYZ"
 :title       "-XYZ Isometrica"
 :action      (ui::uic-set-vp-dir -1,1,1)
 :image       "SolidDesigner/View/isometric_view_-xyz"
 )

("Isometric X-YZ"
 :title       "X-YZ Isometrica"
 :action      (ui::uic-set-vp-dir 1,-1,1)
 :image       "SolidDesigner/View/isometric_view_x-yz"
 )

("Isometric -X-YZ"
 :title       "-X-YZ Isometrica"
 :action      (ui::uic-set-vp-dir -1,-1,1)
 :image       "SolidDesigner/View/isometric_view_-x-yz"
 )

("View Dir X"
 :title       "Vista Dir X"
 :action      (ui::uic-set-vp-dir 1,0,0)
 :image       "SolidDesigner/View/view_dir_x"
 )

("View Dir -X"
 :title       "Vista Dir -X"
 :action      (ui::uic-set-vp-dir -1,0,0)
 :image       "SolidDesigner/View/view_dir_-x"
 )

("View Dir Y"
 :title       "Vista Dir Y"
 :action      (ui::uic-set-vp-dir 0,1,0)
 :image       "SolidDesigner/View/view_dir_y"
 )

("View Dir -Y"
 :title       "Vista Dir -Y"
 :action      (ui::uic-set-vp-dir 0,-1,0)
 :image       "SolidDesigner/View/view_dir_-y"
 )

("View Dir Z"
 :title       "Vista Dir Z"
 :action      (ui::uic-set-vp-dir 0,0,1)
 :image       "SolidDesigner/View/view_dir_z"
 )

("View Dir -Z"
 :title       "Vista Dir -Z"
 :action      (ui::uic-set-vp-dir 0,0,-1)
 :image       "SolidDesigner/View/view_dir_-z"
 )

("Rotate VP Axis +90"
 :title       "Ruota Asse FV +90"
 :action      (ui::uic-rotate-vp-axis 90)
 :image       "SolidDesigner/View/rotate_vp_axis_90")

("Rotate VP Axis -90"
 :title       "Ruota Asse FV -90"
 :action      (ui::uic-rotate-vp-axis -90)
 :image       "SolidDesigner/View/rotate_vp_axis_-90")

("Rotate VP Axis 180"
 :title       "Ruota Asse FV 180"
 :action      (ui::uic-rotate-vp-axis 180)
 :image       "SolidDesigner/View/rotate_vp_axis_180")

("Rotate VP Axis +45"
 :title       "Ruota Asse FV +45"
 :action      (ui::uic-rotate-vp-axis 45)
 :image       "SolidDesigner/View/rotate_vp_axis_45")

("Rotate VP Axis -45"
 :title       "Ruota Asse FV -45"
 :action      (ui::uic-rotate-vp-axis -45)
 :image       "SolidDesigner/View/rotate_vp_axis_-45")

("Rotate VP Axis +30"
 :title       "Ruota Asse FV +30"
 :action      (ui::uic-rotate-vp-axis 30)
 :image       "SolidDesigner/View/rotate_vp_axis_30")

("Rotate VP Axis -30"
 :title       "Ruota Asse FV -30"
 :action      (ui::uic-rotate-vp-axis -30)
 :image       "SolidDesigner/View/rotate_vp_axis_-30")

("Store View"
 :title       "Memorizza Vista"
 :action      (ui::uic-vp-cmd "uic_store_vp_view")
 :image       "SolidDesigner/View/store_view")

("Recall View"
 :title       "Richiama Vista"
 :action      (ui::uic-vp-cmd "uic_recall_vp_view")
 :image       "SolidDesigner/View/recall_view")

("Edit Camera"
 :title       "Modifica Camera"
 :action      (ui::uic-vp-cmd "uic_edit_camera :vport")
 :image       "SolidDesigner/View/edit_camera")

("Previous Camera"
 :title       "Camera Precedente"
 :action      (ui::uic-vp-cmd "uic_previous_camera")
 :enable      ui::*previous-camera-possible*
 :image       "SolidDesigner/View/prev_camera")

("Next Camera"
 :title       "Camera Successiva"
 :action      (ui::uic-vp-cmd "uic_next_camera")
 :enable      ui::*next-camera-possible*
 :image       "SolidDesigner/View/next_camera")

("Global Axes On/Off"
 :title       "Assi Globali On/Off"
 :action      (ui::uic-vp-cmd "uic_global_axes_on_off")
 :description "Commuta gli assi delle coordinate globali on/off in una data finestra vista"
 :image       "SolidDesigner/View/global_axes_on_off")

("Full Screen"
 :title       "Scher&mo Intero"
 :description "Attiva o disattiva Schermo Intero"
 :sysCmdId    32890
 :image       "SolidDesigner/View/fullscreen")

("Explicit Dynamic Pan"
 :title       "Sposta con il mouse"
 :action      (if (eql (frame2::prim-vp-get-explicit-dynamic-mode) :explicit_dynamic_none)
                 (put-buffer "explicit_dynamic_vp :pan")
              ;; ELSE
                 (put-buffer ":pan")
              )
 :description "Sposta la vista premendo il tasto sinistro del mouse"
 :image       "SolidDesigner/View/center_vp")

("Explicit Dynamic Rotate"
 :title       "Ruota con il mouse"
 :action      (if (eql (frame2::prim-vp-get-explicit-dynamic-mode) :explicit_dynamic_none)
                 (put-buffer "frame2-ui::explicit_dynamic_vp :rotate")
              ;; ELSE
                 (put-buffer ":rotate")
              )
 :description "Ruota la vista premendo il tasto sinistro del mouse"
 :image       "SolidDesigner/View/dynamic_vp")


("Explicit Dynamic Zoom"
 :title       "Ingrandisci con il mouse"
 :action      (if (eql (frame2::prim-vp-get-explicit-dynamic-mode) :explicit_dynamic_none)
                 (put-buffer "frame2-ui::explicit_dynamic_vp :zoom")
              ;; ELSE
                 (put-buffer ":zoom")
              )
 :description "Ingrandisce la vista premendo il tasto sinistro del mouse"
 :image       "SolidDesigner/View/explicit_dynamic_zoom")


("Explicit Dynamic Select"
 :title       "Seleziona con il mouse"
 :action      (if (eql (frame2::prim-vp-get-explicit-dynamic-mode) :explicit_dynamic_none)
                 (put-buffer "frame2-ui::explicit_dynamic_vp :none")
              ;; ELSE
                 (put-buffer ":none")
              )
 :description "Usa il mouse per effettuare una selezione nella finestra della vista"
 :image       "SolidDesigner/View/explicit_dynamic_select")

("Rotate View Center Toggle"
  :title "Attiva/Disattiva centro di rotazione della vista"
  :action      (put-buffer "(elan-ui::set_vp_rotate_center :toggle-mode)")
  :description "Commuta tra un centro fisso per ruotare la vista ed un centro che segue la posizione del mouse."
  :image     "SolidDesigner/View/rotate_center_vp"
)

("Rotate View Center Follow Mouse"
  :title "Segui mouse"
  :action (put-buffer "(elan-ui:set_vp_rotate_center :mouse-position)")
  :description "Il centro di rotazione della vista segue la posizione del mouse."
)

("Rotate View Center Camera Reference Point"
  :title "Punto di riferimento obiettivo"
  :action (put-buffer "(elan-ui:set_vp_rotate_center :camera-to-point)")
  :description "Il centro di rotazione della vista  fissato sul punto di riferimento dell'obiettivo."
)

("Rotate View Center Viewport Center"
  :title "Centro finestra vista"
  :action (put-buffer "(elan-ui:set_vp_rotate_center :viewport-center)")
  :description "Il centro di rotazione della vista  fissato al centro della finestra vista."
)

("Rotate View Center Model Center"
  :title "Centro modello"
  :action (put-buffer "(elan-ui:set_vp_rotate_center :model-center)")
  :description "Il centro di rotazione della vista  fissato al centro del modello visualizzato."
)

("Rotate View Center Select"
  :title "Selezionato"
  :action (put-buffer "elan-ui:select_vp_rotate_center")
  :description "Selezionare il centro di rotazione della vista."
)

(separator)


;;----- All: Select -----------------------------------------------------------

(:Group "Select" :title "Selezione"
	:all-in-sd-access :yes)

("Select"
 :title       "&Selezione"
 :action      (elan-ui::show-select-ui)
 :enable      elan-ui::*selector-enabled*
 :description "Selezione oggetti"
 :image       "SolidDesigner/Select/select")

("Start Select List"
 :title       "Inizia Lista di Selezione"
 :action      ":start"
 :description "Inizia una lista di selezione per selezioni multiple"
 :image       "SolidDesigner/Select/sl_start")

("Select List Add"
 :title       "Aggiungi a Lista di Selezione"
 :action      ":add"
 :description "Permette l'aggiunta di oggetti alla lista di selezione"
 :image       "SolidDesigner/Select/sl_add")

("Select List Remove"
 :title       "Rimuovi da Lista di Selezione"
 :action      ":remove"
 :description "Permette di rimuovere oggetti dalla lista di selezione"
 :image       "SolidDesigner/Select/sl_sub")

("Select Done"
 :title       "Concludi Selezione"
 :action      ":select_done"
 :description "Termina la Lista di Selezione"
 :image       "SolidDesigner/Select/sl_end")

;;----- All: Window -----------------------------------------------------------

(:Group "Window" :title "Finestra"
	:all-in-sd-access :yes)

("Cascade"
 :title       "&Disponi tutto"
 :sysCmdId    #xE132                      ;; ID_WINDOW_CASCADE
 :description "Sistema le finestre in modo da sovrapporle"
 :image       "SolidDesigner/Window/cascade")

("Tile Horiz"
 :title       "&Disponi Orizzontalmente"
 :sysCmdId    #xE133                      ;; ID_WINDOW_TILE_HORZ
 :description "Sistema le finestre in modo da non sovrapporle"
 :image       "SolidDesigner/Window/tile_horizontally")

("Tile Vert"
 :title       "&Disponi Verticalmente"
 :sysCmdId    #xE134                      ;; ID_WINDOW_TILE_VERT
 :description "Sistema le finestre in modo da non sovrapporle"
 :image       "SolidDesigner/Window/tile_vertically")

("Arrange Icons"
 :title       "Disponi Icone"
 :sysCmdId    #xE131                      ;; ID_WINDOW_ARRANGE
 :description "Dispone le icone al fondo della finestra"
 :image       "SolidDesigner/Window/ArrangeIcons"
 )

;;----- All: Settings -----------------------------------------------------------

(:Group "Settings" :title "Impostazioni"
	:all-in-sd-access :yes)

("System Settings"
 :title       "Impostazioni di Sistema"
 :action      (frame2::show-system_settings)
 :description "Imposta e modifica le impostazioni di sistema, es. unit."
; :image       "SolidDesigner/Settings/system_settings"
 )

("UI Settings"
 :title       "Impostazioni Interfaccia Utente"
 :action      "ui_settings"
; :image       "SolidDesigner/Settings/ui_settings"
 :description "Imposta e modifica l'Interfaccia Utente")

("Portal Settings"
 :title       "Impostazioni di collaborazione"
 :action      "os_portal_settings"
 :description "Imposta e modifica le impostazioni di collaborazione")

;;----- All: Collaboration ------------------------------------------------------

(:Group "Collaboration" :title "Collaborazione"
		        :all-in-sd-access :yes)

("Meeting Center"
 :title       "Meeting center"
 :action      "(jvm::os-start-meeting-center)"
 :description "Avvia il meeting center OneSpace.net"
  )

("Markup Viewport"
 :title       "Markup Finestra Vista attiva"
 :action      "(jvm::os-markup-current-viewport)"
 :description "Crea uno screenshot della finestra della vista corrente e la apre per il markup"
  )

("Meet Now"
 :title       "Inizia ora"
 :action      "(jvm::os-meet-now)"
 :description "Avvia il meeting center OneSpace.net e inizia una riunione"
  )

("Share Now"
 :title       "Condividi ora"
 :action      "(jvm::os-share-now)"
 :description "Avvia il meeting center OneSpace.net e condivide l'applicazione"
  )

;;----- All: Project Workspace ------------------------------------------------

(:Group "Project Workspace" :title "Spazio di lavoro progetto"
		            :sd-access-only :yes)

("Load from Portal"
 :title       "Scaricamento dallo spazio di lavoro del progetto in corso..."
 :action      "os_load_from_portal"
 :description "Scarica un file dallo spazio di lavoro di un progetto OneSpace.net"
 :ui-behavior :relative
 :sd-access   :yes)

("Save to Portal"
 :title       "Caricamento nello spazio di lavoro di un progetto in corso..."
 :action      "os_save_to_portal"
 :description "Carica un file nello spazio di lavoro di un progetto OneSpace.net"
 :ui-behavior :relative
 :sd-access   :yes)

;;----- All: eDrawings Tool ----------------- 

(:Group "eDrawings Publisher" :title "eDrawings"
	:all-in-sd-access :yes) 

("Publish eDrawings"
	:title "Pubblica eDrawings"
	:action "edrawings_export"
	:description "Pubblica in eDrawings"
	:image "eDrawings/eDPublish"
	:ui-behavior :relative
	:sd-access :yes) 
("Save3D eDrawings"
	:title "Salva eDrawings 3D"
	:action "edrawings_save3d"
	:description "Salva l'articolo selezionato in eDrawings"
	:image "eDrawings/eDSave"
	:ui-behavior :relative
	:sd-access :yes) 
("Save2D eDrawings"
	:title "Salva eDrawings 2D"
	:action "edrawings_save2d"
	:description "Salva il disegno attuale in eDrawings"
	:image "eDrawings/eDSave"
	:ui-behavior :relative
	:sd-access :yes) 
("eDrawings Options"
	:title "Opzioni eDrawings"
	:action "edrawings_options"
	:description "Opzioni eDrawings"
	:image "eDrawings/eDOption"
	:ui-behavior :relative
	:sd-access :yes) 

;;===== Commands valid in SolidDesigner =======================================

(:Application "SolidDesigner")

;;----- SolidDesigner: model explorer -----------------------------------------

(:Group "model explorer" :title "Model Explorer specifico"
                          :sd-access-only :yes)

("Align/Mate"
 :title       "Allinea/Abbina"
 :action      "align_mate_pa"
 :context-action "align_mate_pa :objects-by-select :part"
 :description "Allinea o abbina una parte o un insieme"
 :image       "SolidDesigner/Part_Assy/position_part_assy"
 :ui-behavior :on-request
 :sd-access   :yes)

;;--- we use :help as a trick. In fact, the keyword is completely ignored in model explorer
("Web Help"
 :title	      "Guida in linea"
 :action      "info :help" 
 :description "Guida in linea"
 :sd-access   :yes)


;;----- SolidDesigner: Construction -------------------------------------------

(:Group "Construction" :title "Geo costruzione")

("C Line Inf by 2 Points"
 :title       "Linea Costr. Infinita per 2 punti"
 :action      "c_line_inf :two_points"
 :description "Linea di costruzione infinita passante per 2 punti"
 :image       "SolidDesigner/Construction/c_line_inf_2_pos"
 :ui-behavior :relative)

("C Line Inf Horizontal"
 :title       "Linea Costr. Infinita Orizzontale"
 :action      "c_line_inf :horizontal"
 :description "Linea di costruzione infinita orizzontale"
 :image       "SolidDesigner/Construction/c_line_inf_horiz"
 :ui-behavior :relative)

("C Line Inf Vertical"
 :title       "Linea Costr. Infinita Verticale "
 :action      "c_line_inf :vertical"
 :description "Linea di costruzione infinita verticale"
 :image       "SolidDesigner/Construction/c_line_inf_vert"
 :ui-behavior :relative)

("C Line Inf Parallel"
 :title       "Linea Costr. Infinita Parallela"
 :action      "c_line_inf :parallel"
 :description "Linea di costruzione infinita parallela"
 :image       "SolidDesigner/Construction/c_line_inf_parallel"
 :ui-behavior :relative)

("C Line Inf Perpendicular"
 :title       "Linea Costr. Infinita Perpendicolare"
 :action      "c_line_inf :perpendicular"
 :description "Linea di costruzione infinita perpendicolare"
 :image       "SolidDesigner/Construction/c_line_inf_perpend"
 :ui-behavior :relative)

("C Line Inf Angle"
 :title       "Linea Costr. Infinita da Angolo"
 :action      "c_line_inf :angle"
 :description "Linea di costruzione infinita da un angolo"
 :image       "SolidDesigner/Construction/c_line_inf_angle"
 :ui-behavior :relative)

("C Line at a ref angle"
 :title       "Linea Costr. in un angolo di rif"
 :action      "c_line_inf :angle_reference"
 :description "Crea una linea di costruzione in un angolo rispetto a una linea di riferimento"
 :image       "SolidDesigner/Construction/c_line_at_a_ref_angle"
 :ui-behavior :relative)

("C Line Inf Tangent and Point"
 :title       "Linea Costr. Inf. Tangente per un Punto"
 :action      "c_line_inf :tangent"
 :description "Linea di costruzione infinita tangente e passante per un punto"
 :image       "SolidDesigner/Construction/c_line_inf_tan_pnt"
 :ui-behavior :relative)

("C Line Inf Tangent by 2"
 :title       "Linea Costr. Infinita Tangente in 2 punti"
 :action      "c_line_inf :two_tangent"
 :description "Linea di costruzione infinita tangente in 2 punti"
 :image       "SolidDesigner/Construction/c_line_inf_tan_by_2"
 :ui-behavior :relative)

("C Line Inf Bisec"
 :title       "Linea Costr. Infinita Bisettrice"
 :action      "c_line_inf :bisect"
 :description "Linea di costruzione infinita bisettrice"
 :image       "SolidDesigner/Construction/c_line_inf_bisec"
 :ui-behavior :relative)

("C Line Inf Angle Bisector"
 :title       "Linea Costr. Infinita Bisettrice Angolare"
 :action      "c_line_inf :ang_bisect"
 :description "Linea di costruzione infinita bisettrice angolare"
 :image       "SolidDesigner/Construction/c_line_inf_angle_bisec"
 :ui-behavior :relative)

("C Line Inf Cross"
 :title       "Linee Costr. Infinite Ortogonali"
 :action      "uic_c_line_cross"
 :description "Linea di costruzione infinita orizzontale o verticale"
 :image       "SolidDesigner/Construction/c_line_inf_cross"
 :ui-behavior :relative)

("C Circle Center and Radius"
 :title       "Cerchio di Costr. Centro e Raggio"
 :action      "c_circle :cen_rad"
 :description "Cerchio di costruzione centro e raggio"
 :image       "SolidDesigner/Construction/c_circle_cen_rad"
 :ui-behavior :relative)

("C Circle Concentric"
 :title       "Cerchio di Costr. Concentrico"
 :action      "c_circle :concentric"
 :description "Cerchio di costruzione concentrico"
 :image       "SolidDesigner/Construction/c_circle_concen"
 :ui-behavior :relative)

("C Circle Fixed Radius"
 :title       "Cerchio di Costr. Raggio Fisso"
 :action      "c_circle :radius"
 :description "Cerchio di costruzione raggio fisso"
 :image       "SolidDesigner/Construction/c_circle_fix_rad"
 :ui-behavior :relative)

("C Circle Fixed Center"
 :title       "Cerchio di Costr. Centro Fisso"
 :action      "c_circle :center"
 :description "Cerchio di costruzione centro fisso"
 :image       "SolidDesigner/Construction/c_circle_fix_cen"
 :ui-behavior :relative)

("C Circle 3 Points"
 :title       "Cerchio di Costr. per 3 Punti"
 :action      "c_circle :3_pos"
 :description "Cerchio di costruzione per tre punti"
 :image       "SolidDesigner/Construction/c_circle_3_pos"
 :ui-behavior :relative)

("C Circle Diameter"
 :title       "Cerchio di Costr. Diametro"
 :action      "c_circle :diameter"
 :description "Cerchio di costruzione da diametro"
 :image       "SolidDesigner/Construction/c_circle_dia"
 :ui-behavior :relative)

("C Circle 2 Points and Radius"
 :title       "Cerchio di Costruzione per 2 Punti e Raggio"
 :action      "c_circle :2_pos_rad"
 :description "Cerchio di costruzione centro e raggio"
 :image       "SolidDesigner/Construction/c_circle_2_pnts_rad"
 :ui-behavior :relative)

("C Circle Center and Diameter"
 :title       "Cerchio di Costruz. per Centro e Diam."
 :action      "c_circle :cen_dia"
 :description "Cerchio di Costruzione per Centro e Diametro"
 :image       "SolidDesigner/Construction/c_circle_cen_dia"
 :ui-behavior :relative)

("C Circle Tangent and Center"
 :title       "Cerchio di Costruz. per Centro e Tang."
 :action      "c_circle :tan_cen"
 :description "Cerchio di costruzione da tangente e centro"
 :image       "SolidDesigner/Construction/c_circle_cen_tan"
 :ui-behavior :relative)

("C Circle Tangent and 2 Points"
 :title       "Cerchio di Costruz. per Tang. e 2 Pti"
 :action      "c_circle :tan_pt_pt"
 :description "Cerchio di costruzione da tangente e 2 punti"
 :image       "SolidDesigner/Construction/c_circle_tan_2_pnts"
 :ui-behavior :relative)

("C Circle Tangent by 2"
 :title       "Cerchio di Costr. 2 Tangenti"
 :action      "c_circle :tan2_pt"
 :description "Cerchio di costruzione tangente in 2 punti"
 :image       "SolidDesigner/Construction/c_circle_tan_by_2"
 :ui-behavior :relative)

("C Circle Tangent by 3"
 :title       "Cerchio di Costr. 3 Tangenti"
 :action      "c_circle :tan3"
 :description "Cerchio di costruzione tangente in 3 punti"
 :image       "SolidDesigner/Construction/c_circle_tan_by_3"
 :ui-behavior :relative)

("C Project Face"
 :title       "Proietta Faccia Costr."
 :action      "uic_c_project_face"
 :description "Proietta la geometria della faccia sul PL attivo come geometria di costruzione"
 :image       "SolidDesigner/Construction/c_project_face"
 :ui-behavior :relative)

("C Project 3D Edge"
 :title       "Proietta Spigolo 3D Costr. "
 :action      "uic_c_project_3d_edge"
 :description "Proietta la geometria dello spigolo 3D sul PL attivo come geometria di costruz"
 :image       "SolidDesigner/Construction/c_project_3d_edge"
 :ui-behavior :relative)

("C Project 2D Edge"
 :title       "Proietta Spigolo 2d Costr."
 :action      "uic_c_project_2d_edge"
 :description "Proietta la geometria dello spigolo 3D sul PL attivo come geometria di costruzione"
 :image       "SolidDesigner/Construction/c_project_2d_edge"
 :ui-behavior :relative)

("C Point"
 :title       "Pto Costr."
 :action      "c_point"
 :description "Crea un punto di costruzione"
 :image       "SolidDesigner/Construction/c_point"
 :ui-behavior :relative)

("C Point Inters"
 :title       "Pto Costr. Inters"
 :action      "int_c_point"
 :description "Crea un punto di costruzione dove spigoli intersecano il piano di lavoro attuale"
 :image       "SolidDesigner/Construction/c_point_inters"
 :ui-behavior :relative)

;;----- SolidDesigner: Create 2D ----------------------------------------------

(:Group "Create 2D" :title "Disegno 2D")

("Line by 2 Points"
 :title       "Linea per 2 Punti"
 :action      (ui::uic-call-create2dgeo-command "line :two_points")
 :image       "SolidDesigner/Create_2d/line_2pnts"
 :ui-behavior :relative)

("Line Horizontal"
 :title       "Linea Orizzontale"
 :action      (ui::uic-call-create2dgeo-command "line :horizontal")
 :image       "SolidDesigner/Create_2d/line_horiz"
 :ui-behavior :relative)

("Line Vertical"
 :title       "Linea Verticale"
 :action      (ui::uic-call-create2dgeo-command "line :vertical")
 :image       "SolidDesigner/Create_2d/line_vert"
 :ui-behavior :relative)

("Line Parallel"
 :title       "Linea Parallela"
 :action      (ui::uic-call-create2dgeo-command "line :parallel")
 :description "Crea una linea parallela ad un'altra linea"
 :image       "SolidDesigner/Create_2d/line_parallel"
 :ui-behavior :relative)

("Line Perpendicular"
 :title       "Linea Costr. Infinita"
 :action      (ui::uic-call-create2dgeo-command "line :perpendicular")
 :description "Crea una linea parallela ad un'altra linea"
 :image       "SolidDesigner/Create_2d/line_perpendicular"
 :ui-behavior :relative)

("Line at an angle"
 :title       "Linea da un angolo"
 :action      (ui::uic-call-create2dgeo-command "line :angle")
 :description "Crea una linea da un angolo rispettando l'asse U del PL"
 :image       "SolidDesigner/Create_2d/line_at_an_angle"
 :ui-behavior :relative)

("Line at a ref angle"
 :title       "Linea da un angolo di riferimento"
 :action      (ui::uic-call-create2dgeo-command "line :angle_reference")
 :description "Crea una linea da un angolo rispettando una linea di riferimento"
 :image       "SolidDesigner/Create_2d/line_at_a_ref_angle"
 :ui-behavior :relative)

("Line Tangent"
 :title       "Linea Tangente"
 :action      (ui::uic-call-create2dgeo-command "line :tangent")
 :description "Crea una linea tangente ad un elemento curvilineo"
 :image       "SolidDesigner/Create_2d/line_tangent"
 :ui-behavior :relative)

("Line Tangent 2"
 :title       "Linea Tangente 2"
 :action      (ui::uic-call-create2dgeo-command "line :two_tangent")
 :description "Crea una linea tangente a due elementi curvilinei"
 :image       "SolidDesigner/Create_2d/line_tangent_2"
 :ui-behavior :relative)

("Polygon"
 :title       "Poligono"
 :action      (ui::uic-call-create2dgeo-command "polygon")
 :image       "SolidDesigner/Create_2d/polygon"
 :ui-behavior :relative)

("Rectangle"
 :title       "Rettangolo"
 :action      (ui::uic-call-create2dgeo-command "rectangle")
 :description "Crea un rettangolo da 2 punti"
 :image       "SolidDesigner/Create_2d/rectangle"
 :ui-behavior :relative)

("Slot"
 :title       "Fessura"
 :action      (ui::uic-call-create2dgeo-command "uic_slot")
 :description "Crea una fessura da due centri e una ampiezza"
 :image       "SolidDesigner/Create_2d/slot"
 :ui-behavior :relative)

("Circle by center and radius"
 :title       "Cerchio da centro e raggio"
 :action      (ui::uic-call-create2dgeo-command "circle :cen_rad")
 :image       "SolidDesigner/Create_2d/circle_cen_rad"
 :ui-behavior :relative)

("Circle Concentric"
 :title       "Cerchio Concentrico"
 :action      (ui::uic-call-create2dgeo-command "circle :concentric")
 :description "Crea un cerchio concentrico ad un altro"
 :image       "SolidDesigner/Create_2d/circle_concentric"
 :ui-behavior :relative)

("Circle fixed radius"
 :title       "Cerchio raggio fisso"
 :action      (ui::uic-call-create2dgeo-command "circle :radius")
 :image       "SolidDesigner/Create_2d/circle_fix_rad"
 :ui-behavior :relative)

("Circle fix center"
 :title       "Cerchio centro fisso"
 :action      (ui::uic-call-create2dgeo-command "circle :center")
 :description "Crea pi cerchi con lo stesso centro"
 :image       "SolidDesigner/Create_2d/circle_fix_center"
 :ui-behavior :relative)

("Circle 3 Points"
 :title       "Cerchio per 3 Punti"
 :action      (ui::uic-call-create2dgeo-command "circle :3_pos")
 :description "Crea un cerchio usando tre punti sul diametro"
 :image       "SolidDesigner/Create_2d/circle_3_points"
 :ui-behavior :relative)

("Circle Diameter"
 :title       "Cerchio da Diametro"
 :action      (ui::uic-call-create2dgeo-command "circle :diameter")
 :description "Crea un cerchio usando due punti sul diametro"
 :image       "SolidDesigner/Create_2d/circle_diameter"
 :ui-behavior :relative)

("Circle 2 Points and Radius"
 :title       "Cerchio per 2 Punti e Raggio"
 :action      (ui::uic-call-create2dgeo-command "circle :2_pos_rad")
 :description "Crea un cerchio usando tre punti sul diametro"
 :image       "SolidDesigner/Create_2d/circle_2_pnts_rad"
 :ui-behavior :relative)

("Circle center and diameter"
 :title       "Cerchio centro e diametro"
 :action      (ui::uic-call-create2dgeo-command "circle :cen_dia")
 :description "Crea un cerchio da centro e diametro"
 :image       "SolidDesigner/Create_2d/circle_cen_dia"
 :ui-behavior :relative)

("Circle Tangent and Center"
 :title       "Cerchio Tangente e Centro"
 :action      (ui::uic-call-create2dgeo-command "circle :tan_cen")
 :description "Crea un cerchio tangente ad un elemento curvilineo con un centro definito"
 :image       "SolidDesigner/Create_2d/circle_tan_cen"
 :ui-behavior :relative)

("Circle Tangent and 2 Points"
 :title       "Cerchio tangente e 2 Punti"
 :action      (ui::uic-call-create2dgeo-command "circle :tan_pt_pt")
 :description "Crea un cerchio tangente a un elemento curvilineo, per due punti e con un raggio"
 :image       "SolidDesigner/Create_2d/circle_tan_2_pnts"
 :ui-behavior :relative)

("Circle Tangent by 2"
 :title       "Cerchio Tangente in 2"
 :action      (ui::uic-call-create2dgeo-command "circle :tan2_pt")
 :description "Crea un cerchio tangente a due elementi curvilinei e con un raggio o un punto periferico"
 :image       "SolidDesigner/Create_2d/circle_tan_by_2"
 :ui-behavior :relative)

("Circle Tangent by 3"
 :title       "Cerchio da 3 Tangenti"
 :action      (ui::uic-call-create2dgeo-command "circle :tan3")
 :description "Crea un cerchio tangente a tre elementi curvilinei"
 :image       "SolidDesigner/Create_2d/circle_tan_by_3"
 :ui-behavior :relative)

("Change Circle Radius"
 :title       "Modifica Raggio Cerchio"
 :action      (ui::uic-call-create2dgeo-command "modify_radius")
 :description "Modifica il raggio di un cerchio esistente"
 :image       "SolidDesigner/Create_2d/change_rad"
 :ui-behavior :default)

("Arc Generic"
 :title       "Arco Generico"
 :action      (ui::uic-call-create2dgeo-command "arc :cen_rad_ang")
 :description "Crea un arco da centro, raggio e angolo"
 :image       "SolidDesigner/Create_2d/arc_generic"
 :ui-behavior :relative)

("Arc Concentric"
 :title       "Arco Concentrico"
 :action      (ui::uic-call-create2dgeo-command "arc :concentric")
 :description "Crea un arco concentrico ad un altro"
 :image       "SolidDesigner/Create_2d/arc_concentric"
 :ui-behavior :relative)

("Arc Smooth"
 :title       "Arco Regolare"
 :action      (ui::uic-call-create2dgeo-command "arc :smooth")
 :description "Crea un arco con transizione regolare dall'elemento adiacente"
 :image       "SolidDesigner/Create_2d/arc_smooth"
 :ui-behavior :relative)

("Arc Center"
 :title       "Arco Centro"
 :action      (ui::uic-call-create2dgeo-command "arc :center")
 :description "Crea un arco dal centro e dai punti estremi"
 :image       "SolidDesigner/Create_2d/arc_center"
 :ui-behavior :relative)

("Arc by 3 Points"
 :title       "Arco per 3 Punti"
 :action      (ui::uic-call-create2dgeo-command "arc :3_pos")
 :image       "SolidDesigner/Create_2d/arc_by_3_points"
 :ui-behavior :relative)

("Arc Diameter"
 :title       "Arco da Diametro"
 :action      (ui::uic-call-create2dgeo-command "arc :diameter")
 :description "Crea un arco con due punti sul diametro"
 :image       "SolidDesigner/Create_2d/arc_diameter"
 :ui-behavior :relative)

("Spline 2D Interpolation"
 :title       "Spline di Interpolazione 2D"
 :action      (ui::uic-call-create2dgeo-command "bspline_int")
 :description "Crea una curva B-Spline"
 :image       "SolidDesigner/Create_2d/spline_int"
 :ui-behavior :relative)

("Spline 2D Control"
 :title       "Spline di Controllo 2D"
 :action      (ui::uic-call-create2dgeo-command "bspline_con")
 :description "Crea una curva planare "
 :image       "SolidDesigner/Create_2d/spline_con"
 :ui-behavior :relative)

("Ellipse 2 Vert and Point"
 :title       "Ellisse 2 Vert e Pto"
 :action      (ui::uic-call-create2dgeo-command "ellipse_vvp")
 :description "Crea un ellisse tramite due vertici e un punto periferico"
 :image       "SolidDesigner/Create_2d/ellipse_vvp"
 :ui-behavior :relative)

("Ellipse Ctr Ang R"
 :title       "Ellisse Centro Angolo Raggio"
 :action      (ui::uic-call-create2dgeo-command "ellipse_car")
 :description "Crea un ellisse usando il centro, un angolo e due raggi"
 :image       "SolidDesigner/Create_2d/ellipse_car"
 :ui-behavior :relative)

("Ellipse Ctr and Points"
 :title       "Ellisse Centro e Punti"
 :action      (ui::uic-call-create2dgeo-command "ellipse_cpp")
 :description "Crea un ellisse usando il centro e due punti periferici"
 :image       "SolidDesigner/Create_2d/ellipse_cpp"
 :ui-behavior :relative)

("Overdraw"
 :title       "Ricalca"
 :action      (ui::uic-call-create2dgeo-command "overdraw_2d")
 :image       "SolidDesigner/Create_2d/overdraw"
 :ui-behavior :relative)

("Equidistance"
 :title       "Equidistante"
 :action      (ui::uic-call-create2dgeo-command "equidistance_2d")
 :description "Crea un contorno equidistante"
 :image       "SolidDesigner/Create_2d/equidistance"
 :ui-behavior :relative)

("Project Face"
 :title       "Proietta Faccia"
 :action      "uic_project_face"
 :description "Proietta la geometria di uno spigolo 3D sul PL attivo come geometria reale"
 :image       "SolidDesigner/Create_2d/project_face"
 :ui-behavior :relative)

("Project 3D Edge"
 :title       "Proietta Spigolo 3D"
 :action      "uic_project_3d_edge"
 :description "Proietta la geometria di uno spigolo 3D sul PL attivo come geometria reale"
 :image       "SolidDesigner/Create_2d/project_3d_edge"
 :ui-behavior :relative)

("Project 2D Edge"
 :title       "Proietta Spigolo 2D"
 :action      "uic_project_2d_edge"
 :description "Proietta la geometria di uno spigolo 2D sul PL attivo come geometria reale"
 :image       "SolidDesigner/Create_2d/project_2d_edge"
 :ui-behavior :relative)

("Cross Section"
 :title       "Sezione Trasversale"
 :action      (ui::uic-call-create2dgeo-command "cross_section")
 :description "Proietta la sezione di una parte su un PL"
 :image       "SolidDesigner/Create_2d/cross_section"
 :ui-behavior :relative)

("Text to Profile"
 :title       "Testo in Profilo"
 :action      (ui::uic-call-create2dgeo-command "create_geo_text")
 :description "Crea un profilo 2D da una stringa di testo in qualunque dimensione usando un font disponibile"
 :image       "SolidDesigner/Create_2d/text_to_geometry"
 :ui-behavior :relative)

;;----- SolidDesigner: 2D CoPilot ---------------------------------------------

(:Group "2D CoPilot" :title "CoPilota 2D")

("Construction Point"
 :title       "Punto di costruzione"
 :action      (2d::run-2dCopilot :point_mode)
 :description "Crea punti di costruzione guidati dal CoPilota 2D."
 :image        "SolidDesigner/2D_CoPilot/2dc_cpoint")

("Line/Arc"
 :title       "Linea/Arco"
 :action      (2d::run-2dCopilot :line_mode :real)
 :description "Crea segmenti di una linea e/o di un arco guidati dal CoPilota 2D."
 :image        "SolidDesigner/2D_CoPilot/2dc_line_arc")

("Rectangle"
 :title       "Rettangolo"
 :action      (2d::run-2dCopilot :rectangle_mode :real)
 :description "Crea rettangoli guidati dal CoPilota 2D."
 :image        "SolidDesigner/2D_CoPilot/2dc_rectangle")

("Circle"
 :title       "Cerchio"
 :action      (2d::run-2dCopilot :circle_mode :real)
 :description "Crea cerchi guidati dal CoPilota 2D."
 :image        "SolidDesigner/2D_CoPilot/2dc_circle")

("2D CoPilot Settings"
 :title       "Impostazioni CoPilota 2D"
 :action      (2d::show-2d-copilot-switches)
 :description "Mostra il menu impostazioni del CoPilota 2D")

;;----- SolidDesigner: Modify 2D ----------------------------------------------

(:Group "Modify 2D" :title "Modifica 2D")

("Merge 2D"
 :title       "Unisci 2D"
 :action      "merge_2d"
 :image       "SolidDesigner/Modify_2d/merge_2d"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Split 2D"
 :title       "Dividi 2D"
 :action      "split"
 :image       "SolidDesigner/Modify_2d/split_2d"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Trim One Element"
 :title       "Taglia un Elemento"
 :action      "trim :one_element"
 :description "Specifica un singolo elemento da tagliare o estendere"
 :image       "SolidDesigner/Modify_2d/trim1"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Trim by 2 Elements"
 :title       "Taglia per 2 Elementi"
 :action      "trim :two_elements"
 :image       "SolidDesigner/Modify_2d/trim2"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Trim Middle"
 :title       "Taglia Intermedio"
 :action      "trim :middle"
 :image       "SolidDesigner/Modify_2d/trim_middle"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Trim a contour"
 :title       "Taglia un contorno"
 :action      "trim :contour"
 :description "Specifica gli elementi che definiscono un contorno, da cui tutte le sporgenze devono essere eliminate"
 :image       "SolidDesigner/Modify_2d/trim_contour"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Trim and Cut Both Ends"
 :title       "Tagli entrambi gli Estremi"
 :action      "trim :both_ends"
 :description "Taglia (rimuove) gli estremi da un elemento geometrico"
 :image       "SolidDesigner/Modify_2d/both_ends"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Trim Both and Convert"
 :title       "Taglia Entrambi e Converti"
 :action      "trim :both_ends_to_geo"
 :description "Taglia gli estremi e converte il medio in geometria"
 :image       "SolidDesigner/Modify_2d/both_ends_to_geo"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Trim by Box"
 :title       "Taglia per Riquadro"
 :action      "trim :by_box"
 :description "Taglia gli estremi per un riquadro di selezione"
 :image       "SolidDesigner/Modify_2d/by_box"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Trim by Box and Convert"
 :title       "Taglia per riquadro e Converti"
 :action      "trim :by_box_to_geo"
 :description "Taglia gli estremi per un riquadro di selezione e converte i medi in geometria"
 :image       "SolidDesigner/Modify_2d/by_box_to_geo"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Move 2D"
 :title       "Sposta 2D"
 :action      "move_2d :select"
 :image       "SolidDesigner/Modify_2d/move_2d"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Rotate 2D"
 :title       "Ruota 2D"
 :action      "rotate_2d :select"
 :image       "SolidDesigner/Modify_2d/rotate_2d"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Mirror 2D"
 :title       "Simmetria 2D"
 :action      "mirror_2d :select"
 :image       "SolidDesigner/Modify_2d/mirror_2d"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Scale 2D"
 :title       "Scala 2D"
 :action      "scale_2d :select"
 :image       "SolidDesigner/Modify_2d/scale_2d"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Stretch 2D"
 :title       "Stira 2D"
 :action      "stretch_move_2d :select"
 :image       "SolidDesigner/Modify_2d/stretch_2d"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Pattern 2D"
 :title       "Motivo 2D"
 :action      "pattern_2d :select"
 :image       "SolidDesigner/Modify_2d/patterb_2d"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("2D Fillet Create"
 :title       "Crea Raccordo 2D"
 :action      "fillet :create"
 :image       "SolidDesigner/Modify_2d/fillet_2d_create"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("2D Fillet Modify"
 :title       "Modifica Raccordo 2D"
 :action      "fillet :modify"
 :image       "SolidDesigner/Modify_2d/fillet_2d_modify"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("2D Fillet Remove"
 :title       "Rimuovi Raccordo 2D"
 :action      "fillet :remove"
 :image       "SolidDesigner/Modify_2d/fillet_2d_remove"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Convert Geo"
 :title       "Converti Geo"
 :action      "toggle_type"
 :description "Converte la geometria di Costruzione in un profilo reale e viceversa"
 :image       "SolidDesigner/Modify_2d/conv_geo"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

("Convert Geo to Inf"
 :title       "Converti Geo a Infinita"
 :action      "convert_edge_into_infinite_cgeo"
 :description "Converte la geometria in geometria di costruzione infinita"
 :image       "SolidDesigner/Modify_2d/untrim_geo"
 :context-enable (agent::edge-2d-enable-context-menu-entry) 
 :ui-behavior :relative)

;;----- SolidDesigner: Workplane ----------------------------------------------

(:Group "Workplane" :title "Pianolavoro")

("New WP"
 :title       "Nuovo PL"
 :action      "create_workplane :new"
 :description "Crea un nuovo Piano di Lavoro"
 :image       "SolidDesigner/Workplane/wp_new"
 :ui-behavior :relative)

("New WP + Constr. Geo"
 :title       "Nuovo PL + Geo Costr."
 :action      "uic_new_wp_with_cgeo"
 :description "Crea un nuovo PL predefinito con una linea orizzontale infinita e una verticale attraverso la sua origine"
 :image       "SolidDesigner/Workplane/wp_default"
 :ui-behavior :none)

("New WP on Face"
 :title       "Nuovo PL su Faccia"
 :action      "uic_new_wp_on_face"
 :description "Crea un nuovo PL parallelo a una faccia"
 :image       "SolidDesigner/Workplane/wp_par_face"
 :ui-behavior :relative)

("New WP on Face and Project Real"
 :title       "Nuovo PL su faccia e Proietta Reale"
 :action      "uic_new_wp_on_face_w_proj_geo :real"
 :description "Crea un nuovo PL parallelo ad una faccia e proietta la sua geometria come reale"
 :image       "SolidDesigner/Workplane/wp_par_face_proj"
 :ui-behavior :relative)

("New WP on Face and Project Constr"
 :title       "Nuovo PL su faccia e Proietta Costruz."
 :action      "uic_new_wp_on_face_w_proj_geo :construction"
 :description "Crea un nuovo PL parallelo ad una faccia e proietta la sua geometria come costruzione"
 :image       "SolidDesigner/Workplane/wp_par_face_proj_constr"
 :ui-behavior :relative)

("New WP by Point and Dir"
 :title       "Nuovo PL per Pto e Dir"
 :action      "create_workplane :new :pt_dir :origin"
 :description "Crea un nuovo PL da un punto e una direzione"
 :image       "SolidDesigner/Workplane/wp_pnt_dir"
 :ui-behavior :relative)

("New WP on Axis"
 :title       "Nuovo PL su Asse"
 :action      "create_workplane :new :on_axis :c_face"
 :description "Crea un nuovo piano di lavoro con uno dei suoi assi allineato all'asse di una superficie curva."
 :image       "SolidDesigner/Workplane/wp_on_axis"
 :ui-behavior :relative)

("Set Active WP"
 :title       "Imposta PL Attivo"
 :action      "current_wp"
 :description "Imposta un PL come attivo"
 :image       "SolidDesigner/Workplane/set_active_wp"
 :ui-behavior :none)

("Parallel WP"
 :title       "PL Parallelo"
 :action      "create_parallel_wp"
 :description "Crea copie parallele o piani di lavoro condivisi"
 :image       "SolidDesigner/Workplane/wp_parallel"
 :ui-behavior :relative)

("Copy WP"
 :title       "Copia PL"
 :action      "create_workplane :copy"
 :description "Copia un piano di lavoro"
 :image       "SolidDesigner/Workplane/copy_wp"
 :ui-behavior :relative)

("Inclined WP"
 :title       "PL Inclinato"
 :action      "create_inclined_wp"
 :description "Crea copie inclinate o piani di lavoro condivisi"
 :image       "SolidDesigner/Workplane/wp_inclined"
 :ui-behavior :relative)

("Share WP"
 :title       "Condividi PL"
 :action      "create_workplane :share"
 :description "Condivide un piano di lavoro"
 :image       "SolidDesigner/Workplane/wp_share"
 :ui-behavior :relative)

("Last WP"
 :title       "Ultimo PL"
 :action      "recall_last_wp"
 :description "Richiama l'ultimo PL"
 :image       "SolidDesigner/Workplane/last_wp"
 :ui-behavior :relative)

("Partial WP"
 :title       "PL Parziale"
 :action      "create_workplane :partial_copy"
 :description "Crea copie parziali di piani di lavoro"
 :image       "SolidDesigner/Workplane/wp_partial"
 :ui-behavior :relative)

("Position WP"
 :title       "Posiziona PL"
 :action      "position_wp"
 :description "Posiziona il PL attivo o selezionato"
 :image       "SolidDesigner/Workplane/pos_curr_wp"
 :ui-behavior :relative)

("Position Dynamic"
 :title       "Posizionamento Dinamico"
 :action      "pos_dynamic"
 :context-action "pos_dynamic :objects-by-select :workplane"
 :description "Posiziona dinamicamente una parte, gruppo o piano di lavoro"
 :image       "SolidDesigner/Workplane/position_dynamic_wp"
 :sd-access   :yes
 :ui-behavior :on-request)

("Position Curr WP Pt/Dir"
 :title       "Posiziona PL Corrente Pto/Dir"
 :action      "position_wp :current :pt_dir :origin"
 :description "Posiziona il PL corrente da punto e direzione"
 :image       "SolidDesigner/Workplane/pos_curr_wp_pt_dir"
 :ui-behavior :relative)

("Position WP on Face"
 :title       "Posiziona PL su Faccia"
 :action      (ui::uic-pos-wp-on-face)
 :description "Posiziona il PL attivo o selezionato parallelamente ad una faccia"
 :image       "SolidDesigner/Workplane/wp_pos_par_face"
 :ui-behavior :relative)

("Rotate WP 90 U"
 :title       "Ruota PL 90 U"
 :action      (ui::uic-rotate-wp-on-axis :deg 90.0 :axis :u)
 :description "Ruota il PL attivo o selezionato di 90 gradi attorno al proprio asse U"
 :image       "SolidDesigner/Workplane/wp_rot_90u"
 :ui-behavior :none)

("Rotate WP 180 U"
 :title       "Ruota PL 180 U"
 :action      (ui::uic-rotate-wp-on-axis :deg 180.0 :axis :u)
 :description "Ruota il PL attivo o selezionato di 180 gradi attorno al proprio asse U"
 :image       "SolidDesigner/Workplane/wp_rot_180u"
 :ui-behavior :none)

("Rotate WP 90 V"
 :title       "Ruota PL 90 V"
 :action      (ui::uic-rotate-wp-on-axis :deg 90.0 :axis :v)
 :description "Ruota il PL attivo o selezionato di 90 gradi attorno al proprio asse V"
 :image       "SolidDesigner/Workplane/wp_rot_90v"
 :ui-behavior :none)

("Rotate WP 180 V"
 :title       "Ruota PL 180 V"
 :action      (ui::uic-rotate-wp-on-axis :deg 180.0 :axis :v)
 :description "Ruota il PL attivo o selezionato di 180 gradi attorno al proprio asse V"
 :image       "SolidDesigner/Workplane/wp_rot_180v"
 :ui-behavior :none)

("Rotate WP 90 W"
 :title       "Ruota PL 90 W"
 :action      (ui::uic-rotate-wp-on-axis :deg 90.0 :axis :w)
 :description "Ruota il PL attivo o selezionato di 90 gradi attorno al proprio asse W"
 :image       "SolidDesigner/Workplane/wp_rot_90w"
 :ui-behavior :none)

("Rotate WP 180 W"
 :title       "Ruota PL 180 W"
 :action      (ui::uic-rotate-wp-on-axis :deg 180.0 :axis :w)
 :description "Ruota il PL attivo o selezionato di 180 gradi attorno al proprio asse W"
 :image       "SolidDesigner/Workplane/wp_rot_180w"
 :ui-behavior :none)

("Modify WP Name"
 :title       "Modifica nomi PL"
 :action      "change_name_wp :workplane"
 :description "Rinomina i piani di lavoro"
 :image       "SolidDesigner/Workplane/wp_name"
 :ui-behavior :relative)

("Unshare WP"
 :title       "Ann. Condiv. PL"
 :action      "unshare_workplane"
 :description "Annulla la condivisione dei piani di lavoro"
 :image       "SolidDesigner/Workplane/wp_unshare"
 :ui-behavior :relative)

("Modify WP Owner"
 :title       "Modifica Propr. PL"
 :action      "change_wp_owner"
 :description "Sposta un piano di lavoro da un insieme ad un altro"
 :image       "SolidDesigner/Workplane/wp_change_owner"
 :ui-behavior :relative)

("Slide WP Origin"
 :title       "Modifica Origine PL"
 :action      "slide_wp_origin"
 :description "Specifica una nuova origine per il PL"
 :image       "SolidDesigner/Workplane/slide_wp_origin"
 :ui-behavior :relative)

("Change Curr WP Border Size"
 :title       "Modifica Dim. Contorno PL Corrente"
 :action      "set_wp_min_size :current"
 :description "Modifica la dimensione minima del PL attuale"
 :image       "SolidDesigner/Workplane/change_wp_border_size"
 :ui-behavior :relative)

("Curr WP Border -> Full"
 :title       "Contorno PL Corrente -> Pieno"
 :action      "set_wp_border_type :current :full"
 :description "Modifica il contorno per mostrare l'intero rettangolo come semitrasparente"
 :image       "SolidDesigner/Workplane/change_wp_border_full"
 :ui-behavior :relative)

("Curr WP Border -> Outline"
 :title       "Contorno PL Corrente -> solo Contorno"
 :action      "set_wp_border_type :current :outline"
 :description "Modifica il contorno per mostrare il solo contorno"
 :image       "SolidDesigner/Workplane/change_wp_border_outline"
 :ui-behavior :relative)

;;----- SolidDesigner: WP Set -------------------------------------------------

(:Group "WP Set" :title "Insieme PL")

("New WP Set"
 :title       "Nuovo Insieme PL"
 :action      "create_wpset"
 :description "Crea un nuovo insieme di piani di lavoro"
 :image       "SolidDesigner/Workplane/wpset_new"
 :ui-behavior :relative)

("Last WP Set"
 :title       "Ultimo insieme PL"
 :action      "recall_last_wp_set"
 :description "Richiama l'ultimo insieme di piani di lavoro"
 :image       "SolidDesigner/Workplane/wpset_last"
 :ui-behavior :relative)

("Copy WP Set"
 :title       "Copia insieme PL"
 :action      "copy_wpset"
 :description "Copia un insieme di piani di lavoro"
 :image       "SolidDesigner/Workplane/wpset_copy"
 :ui-behavior :relative)

("Position WP Set"
 :title       "Posiziona Ins PL"
 :action      "position_wpset"
 :description "Modifica la posizione degli insiemi di piani di lavoro"
 :image       "SolidDesigner/Workplane/wpset_position"
 :ui-behavior :relative)

("Modify WP Set Name"
 :title       "Modifica nomi set PL"
 :action      "change_name_wpset :wpset"
 :description "Modifica il nome di un insieme di piani di lavoro"
 :image       "SolidDesigner/Workplane/wpset_name"
 :ui-behavior :relative)

("Modify WP Set Owner"
 :title       "Modifica Propr. Ins PL"
 :action      "change_wpset_owner"
 :description "Modifica il proprietario di un insieme di piani di lavoro"
 :image       "SolidDesigner/Workplane/wpset_owner"
 :ui-behavior :relative)

("Unshare WP Set"
 :title       "Ann. Condiv. Ins. PL"
 :action      "unshare_wpset"
 :description "Crea insiemi di piani di lavoro indipendenti con la propria struttura dati"
 :image       "SolidDesigner/Workplane/wpset_unshare"
 :ui-behavior :relative)

;;----- SolidDesigner: Part and Assembly --------------------------------------

(:Group "Part and Assy" :title "Parti e Gruppi")

("New Part"
 :title       "Nuova Parte"
 :action      "create_part"
 :image       "SolidDesigner/Part_Assy/new_part"
 :ui-behavior :relative)

("New Assembly"
 :title       "Nuovo Gruppo"
 :action      "create_assembly"
 :image       "SolidDesigner/Part_Assy/new_assembly"
 :ui-behavior :relative)

("New Container"
 :title       "Nuovo Contenitore"
 :action      "create_container"
 :description "Crea un nuovo contenitore"
 :image       "SolidDesigner/Part_Assy/create_container"
 :ui-behavior :relative)

("Set Active Part"
 :title       "Imposta Parte Attiva"
 :action      "current_part"
 :description "Imposta una parte come attiva"
 :image       "SolidDesigner/Part_Assy/set_active_part"
 :ui-behavior :none)

("Copy Part/Assy"
 :title       "Copia Parte/Gruppo"
 :action      "create_multiple_pa :copy"
 :image       "SolidDesigner/Part_Assy/copy_part_assy"
 :ui-behavior :relative)

("Copy/Share Linear"
 :title       "Copia/Condividi Lineare"
 :action      "create_multiple_pa_array"
 :description "Crea copie o condivisioni di parti e gruppi in direzione lineare"
 :image       "SolidDesigner/Part_Assy/create_mult_array"
 :ui-behavior :relative)

("Share Part/Assy"
 :title       "Condividi Parte/Gruppo"
 :action      "create_multiple_pa :share"
 :image       "SolidDesigner/Part_Assy/share_part_assy"
 :ui-behavior :relative)

("Copy/Share Radial"
 :title       "Copia/Condividi Radiale"
 :action      "create_multiple_pa_radial"
 :description "Crea copie o condivisioni di parti e gruppi rispetto a un asse"
 :image       "SolidDesigner/Part_Assy/create_mult_radial"
 :ui-behavior :relative)

("Position Part/Assy"
 :title       "Posiziona Parte/Gruppo"
 :action      "position_pa"
 :image       "SolidDesigner/Part_Assy/position_part_assy"
 :ui-behavior :relative)

("Position Dynamic"
 :title       "Posizionamento Dinamico"
 :action      "pos_dynamic"
 :context-action "pos_dynamic :objects-by-select :part"
 :description "Posiziona dinamicamente una parte, gruppo o piano di lavoro"
 :image       "SolidDesigner/Part_Assy/position_dynamic_part"
 :ui-behavior :on-request
 :sd-access   :yes)

("Position Dynamic Assembly"
 :title       "Posizionamento Dinamico"
 :action      "pos_dynamic"
 :context-action "pos_dynamic :objects-by-select :assembly"
 :description "Posiziona dinamicamente una parte, un gruppo o un piano di lavoro"
 :image       "SolidDesigner/Part_Assy/position_dynamic_part"
 :ui-behavior :on-request
 :sd-access   :yes)

("Rename Part/Assy"
 :title       "Modifica nomi Parte/Gruppo"
 :action      "change_name_pa"
 :image       "SolidDesigner/Part_Assy/rename_part_assy"
 :ui-behavior :relative)

("Unshare Part/Assy"
 :title       "Annulla Cond. Parte/Gruppo"
 :action      "pa_unshare"
 :description "Crea parti o gruppi indipendenti con la propria struttura dati"
 :image       "SolidDesigner/Part_Assy/pa_unshare"
 :ui-behavior :relative)

("Modify Part/Assy Owner"
 :title       "Modifica proprietario di Parte/Gruppo"
 :action      "change_pa_owner"
 :description "Modifica il proprietario di una parte o gruppo"
 :image       "SolidDesigner/Part_Assy/pa_owner"
 :ui-behavior :relative)

("Sel Unshare"
 :title       "Ann. Sel. Condiv."
 :action      "pa_sel_unshare"
 :description "Annullamento selettivo di una parte o un gruppo"
 :image       "SolidDesigner/Part_Assy/pa_sel_unshare"
 :ui-behavior :relative)

("Sel Reshare"
 :title       "Rinnova Condiv. Selettiv."
 :action      "pa_sel_reshare"
 :description "Le istanze selettive esistenti saranno nuovamente condivise nella struttura di gruppo"
 :image       "SolidDesigner/Part_Assy/pa_sel_reshare"
 :ui-behavior :relative)

("Sel Cleanup"
 :title       "Pulitura Selettiva"
 :action      "pa_sel_cleanup"
 :description "Converte l'istanza selettiva in una istanza normale predefinita"
 :image       "SolidDesigner/Part_Assy/pa_sel_cleanup"
 :ui-behavior :relative)

("Sel Master 2D"
 :title       "Seleziona master 2D"
 :action      "pa_sel_master_2d"
 :description "Seleziona un'istanza selettiva da utilizzare tramite un insieme di viste"
 :image       "Annotation/View/view_vset_master"
 :ui-behavior :relative)

("Check Part"
 :title       "Verifica Parte"
 :action      "check_part"
 :description "Controllo completo parte"
 :image       "SolidDesigner/Part_Assy/check_part"
 :ui-behavior :relative
 :sd-access   :yes)

("Clash"
 :title       "Interferenza"
 :action      "clash_3d :pa_list_vs_pa_list"
 :description "Visualizza le parti che interferiscono"
 :sd-access   :yes
 :image       "SolidDesigner/Part_Assy/clash"
 :ui-behavior :relative)

("Draft Analysis"
 :title       "Analisi di Rastremazione"
 :action      "draft_analysis"
 :description "Effettua un'analisi di rastremazione"
 :image       "SolidDesigner/Part_Assy/draft_ana"
 :ui-behavior :relative)

("Clearance"
 :title       "Spaziatura"
 :action      "clash_3d :analysis_type :clearance :pa_list_vs_pa_list"
 :description "Determina la distanza di spaziatura tra due parti"
 :image       "SolidDesigner/Part_Assy/clearance"
 :ui-behavior :relative)

("Pressfits"
 :title       "Marca Forzature"
 :action      "handle_clashing_part :clashing_parts"
 :description "Controlla l'aspetto delle forzature nei disegni 2D"
 :image       "SolidDesigner/Part_Assy/pressfits"
 :ui-behavior :relative)

("Section Mode"
 :title       "Modalit sezione"
 :action      "secure_part_from_section :secured_parts"
 :description "Controlla il sezionamento delle parti nel disegno 2D"
 :image       "SolidDesigner/Part_Assy/section_mode"
 :ui-behavior :relative)

("Create Coord Sys"
 :title       "Crea Sist. Coord."
 :action      "pos_create_coordinate_system :action :create"
 :description "Crea un nuovo sistema di coordinate."
 :image       "SolidDesigner/Part_Assy/create_coord_sys"
 :ui-behavior :relative)

("Rename Coord Sys"
 :title       "Rinomina Sist. Coord."
 :action      "rename_coordinate_system"
 :description "Rinomina un sistema di coordinate gi esistente."
 :image       "SolidDesigner/Part_Assy/rename_coord_sys"
 :ui-behavior :relative)

("Position Coord Sys"
 :title       "Posiziona Sist. Coord."
 :action      "pos_create_coordinate_system :action :position"
 :description "Posiziona un sistema di coordinate."
 :image       "SolidDesigner/Part_Assy/position_coord_sys"
 :ui-behavior :relative)

("Assign Mass Properties"
 :title       "Assegna Propriet di Masssa"
 :action      "assign_mp_data"
 :description "Assegna dati di proproiet di massa a parti o a gruppi."
 :image       "SolidDesigner/Part_Assy/assign_mp"
 :ui-behavior :relative)


;;----- SolidDesigner: Machine ------------------------------------------------

(:Group "Machine" :title "Lavorazioni")

("Extrude"
 :title       "Estrusione"
 :action      (ui::uic-call-machining-action :extrude)
 :description "Estrude con specificazione immediata della distanza"
 :image       "SolidDesigner/Machine/extrude"
 :ui-behavior :relative
 :context-enable (agent::workplane-enable-context-menu-entry :with-profile))

("Unite"
 :title       "Unione"
 :action      (ui::uic-call-machining-action :unite_3d)
 :description "Unisce con specificazione immediata degli utensili"
 :image       "SolidDesigner/Machine/unite"
 :ui-behavior :relative)

("Turn"
 :title       "Rotazione"
 :action      (ui::uic-call-machining-action :turn)
 :description "Ruota con specificazione immediata dell'asse"
 :image       "SolidDesigner/Machine/turn"
 :ui-behavior :relative
 :context-enable (agent::workplane-enable-context-menu-entry :with-profile))

("Reflect"
 :title       "Riflessione"
 :action      "reflect_3d"
 :description "Copia la parte, riflette la copia e unisce le parti"
 :image       "SolidDesigner/Machine/reflect"
 :ui-behavior :relative)

("Mill"
 :title       "Fresatura"
 :action      (ui::uic-call-machining-action :mill)
 :description "Fresa con specificazione immediata della distanza"
 :image       "SolidDesigner/Machine/mill"
 :ui-behavior :relative
 :context-enable (agent::workplane-enable-context-menu-entry :with-profile))

("Bore"
 :title       "Tornitura"
 :action      (ui::uic-call-machining-action :bore)
 :description "Tornisci con specificazione immediata dell'asse"
 :image       "SolidDesigner/Machine/bore"
 :ui-behavior :relative
 :context-enable (agent::workplane-enable-context-menu-entry :with-profile))

("Punch"
 :title       "Punzonatura"
 :action      (ui::uic-call-machining-action :punch)
 :description "Rimuove materiale dall'interno del profilo"
 :image       "SolidDesigner/Machine/machine_punch"
 :ui-behavior :relative
 :context-enable (agent::workplane-enable-context-menu-entry :with-profile))

("Shell"
 :title       "Svuotamento"
 :action      (ui::uic-call-machining-action :shell_3d)
 :description "Rimuove materiale dall'interno di una parte lasciando un involucro di spessore dato"
 :image       "SolidDesigner/Machine/shell"
 :ui-behavior :relative)

("Stamp"
 :title       "Imbutitura"
 :action      (ui::uic-call-machining-action :stamp)
 :description "Rimuove materiale dall'esterno del profilo"
 :image       "SolidDesigner/Machine/machine_stamp"
 :ui-behavior :relative
 :context-enable (agent::workplane-enable-context-menu-entry :with-profile))

("Subtract"
 :title       "Sottrazione"
 :action      (ui::uic-call-machining-action :subtract_3d)
 :description "Sottrazione booleana di uno o pi utensili da una parte"
 :image       "SolidDesigner/Machine/subtract"
 :ui-behavior :relative)

("Section"
 :title       "Sezione"
 :action      (ui::uic-call-machining-action :section)
 :description "Intersezione con specificazione immediata dell'utensile"
 :image       "SolidDesigner/Machine/section"
 :ui-behavior :relative)

("Intersect"
 :title       "Intersezione"
 :action      (ui::uic-call-machining-action :intersect_3d)
 :description "Intersezione con specificazione immediata dell'utensile"
 :image       "SolidDesigner/Machine/intersect"
 :ui-behavior :relative)

("Imprint Linear"
 :title       "Stampa Lineare"
 :action      (ui::uic-call-machining-action :imprint_linear)
 :description "Stampa un profilo su una parte"
 :image       "SolidDesigner/Machine/imprint_linear"
 :ui-behavior :relative)

("Imprint Line"
 :title       "Stampa Linea"
 :action      "imprint_line"
 :description "Stampa una linea su una parte"
 :image       "SolidDesigner/Machine/imprint_line"
 :ui-behavior :relative)

("Imprint Intersection"
 :title       "Stampa Intersezione"
 :action      (ui::uic-call-machining-action :imprint_intersection)
 :description "Stampa Linea di intersezione su una parte"
 :image       "SolidDesigner/Machine/imprint_intersection"
 :ui-behavior :relative)

("Imprint Silhouette"
 :title       "Stampa Profilo"
 :action      "imprint_silhouette :imprint_direction"
 :description "Stampa un profilo su una parte"
 :image       "SolidDesigner/Machine/imprint_silhouette"
 :ui-behavior :relative)

;;----- SolidDesigner: Modify 3D ----------------------------------------------

(:Group "Modify 3D" :title "Modifica 3D")

("Create Const Radius Blend"
 :title       "Crea Raccordi a Raggio Costante"
 :action      (ui::uic-call-modify-3d-action :create-const-blend)
 :description "Comando di Raccordo"
 :image       "SolidDesigner/Modify_3d/blend"
 :sd-access   :yes
 :ui-behavior :on-request
 :context-enable (agent::edge-enable-context-menu-entry :blend))

("Create Var2 Radius Blend"
 :title       "Crea Raccordi a Raggio Variabile2"
 :action      (ui::uic-call-modify-3d-action :create-var2-blend)
 :description "Comando di Raccordo"
 :image       "SolidDesigner/Modify_3d/blend"
 :sd-access   :yes
 :ui-behavior :on-request
 :context-enable (agent::edge-enable-context-menu-entry :blend))

("Create Varn Radius Blend"
 :title       "Crea Raccordi a Raggio Variabile"
 :action      (ui::uic-call-modify-3d-action :create-varn-blend)
 :description "Comando di Raccordo"
 :image       "SolidDesigner/Modify_3d/blend"
 :sd-access   :yes
 :ui-behavior :on-request
 :context-enable (agent::edge-enable-context-menu-entry :blend))

("Insert Const Radius Blend"
 :title       "Inserisci Raccordi a Raggio Costante"
 :action      (ui::uic-call-modify-3d-action :insert-const-blend)
 :description "Comando di inserimento raccordo"
 :image       "SolidDesigner/Modify_3d/blend"
 :ui-behavior :on-request)

("Insert Var2 Radius Blend"
 :title       "Inserisci Raccordi a Raggio Variabile2"
 :action      (ui::uic-call-modify-3d-action :insert-var2-blend)
 :description "Comando di inserimento raccordo"
 :image       "SolidDesigner/Modify_3d/blend"
 :ui-behavior :on-request)

("Insert Varn Radius Blend"
 :title       "Inserisci Raccordi a Raggio Variabile"
 :action      (ui::uic-call-modify-3d-action :insert-varn-blend)
 :description "Comando di inserimento raccordo"
 :image       "SolidDesigner/Modify_3d/blend"
 :ui-behavior :on-request)

("Blend Create"
 :title       "Crea Raccordo"
 :action      (ui::uic-call-modify-3d-action :create-blend)
 :description "Comando di Raccordo"
 :image       "SolidDesigner/Modify_3d/blend"
 :ui-behavior :relative
 :context-enable (agent::edge-enable-context-menu-entry :blend))

("Blend Modify"
 :title       "Modifica Raccordo"
 :action      (ui::uic-call-modify-3d-action :modify-blend-uiless)
 :description "Comando di modifica raccordo"
 :image       "SolidDesigner/Modify_3d/blend_modify"
 :ui-behavior :on-request
 :context-enable (agent::face-enable-context-menu-entry :blend))

("Blend Insert"
 :title       "Inserisci Raccordo"
 :action      (ui::uic-call-modify-3d-action :insert-blend)
 :description "Comando di inserimento raccordo"
 :image       "SolidDesigner/Modify_3d/blend_insert"
 :ui-behavior :relative)

("Blend Remove"
 :title       "Rimuovi Raccordo"
 :action      (ui::uic-call-modify-3d-action :delete-blend)
 :description "Comando di rimozione raccordo"
 :image       "SolidDesigner/Modify_3d/blend_remove"
 :ui-behavior :relative
 :context-enable (agent::face-enable-context-menu-entry :blend))

("Blend Recognize"
 :title       "Riconoscimento Raccordo"
 :action      "recognize_blends :sel_faces"
 :description "Il comando di riconoscimento calcola le informazioni di raccordo per facce tangenti che non sono state create con Crea Raccordo"
 :image       "SolidDesigner/Modify_3d/blend_recognize"
 :ui-behavior :relative)

("Create Const Dist Chamfer"
 :title       "Crea Smusso a Distanza Costante"
 :action      (ui::uic-call-modify-3d-action :create-ccd-chamfer)
 :description "Comando Smusso"
 :image       "SolidDesigner/Modify_3d/chamfer"
 :sd-access   :yes
 :ui-behavior :on-request
 :context-enable (agent::edge-enable-context-menu-entry :chamfer))

("Create Dist Dist Chamfer"
 :title       "Crea Smusso Distanza/Distanza"
 :action      (ui::uic-call-modify-3d-action :create-cdd-chamfer)
 :description "Comando Smusso"
 :image       "SolidDesigner/Modify_3d/chamfer"
 :sd-access   :yes
 :ui-behavior :on-request
 :context-enable (agent::edge-enable-context-menu-entry :chamfer))

("Create Dist Angle Chamfer"
 :title       "Crea Smusso Distanza/Angolo"
 :action      (ui::uic-call-modify-3d-action :create-cda-chamfer)
 :description "Comando Smusso"
 :image       "SolidDesigner/Modify_3d/chamfer"
 :sd-access   :yes
 :ui-behavior :on-request
 :context-enable (agent::edge-enable-context-menu-entry :chamfer))

("Chamfer Create"
 :title       "Crea Smusso"
 :action      (ui::uic-call-modify-3d-action :create-chamfer)
 :description "Comando Smusso"
 :image       "SolidDesigner/Modify_3d/chamfer"
 :ui-behavior :relative
 :context-enable (agent::edge-enable-context-menu-entry :chamfer))

("Chamfer Modify"
 :title       "Modifica Smusso"
 :action      (ui::uic-call-modify-3d-action :modify-chamfer)
 :description "Modifica Smusso"
 :image       "SolidDesigner/Modify_3d/chamfer_modify"
 :ui-behavior :relative
 :context-enable (agent::face-enable-context-menu-entry :chamfer))

("Chamfer Remove"
 :title       "Rimuovi Smusso"
 :action      (ui::uic-call-modify-3d-action :delete-chamfer)
 :description "Rimozione Smusso"
 :image       "SolidDesigner/Modify_3d/chamfer_remove"
 :ui-behavior :relative
 :context-enable (agent::face-enable-context-menu-entry :chamfer))

("Taper"
 :title       "Rastrema"
 :action      (ui::uic-call-modify-3d-action :taper)
 :description "Comando di rastrema facce e gruppi di facce riconosciute"
 :image       "SolidDesigner/Modify_3d/taper"
 :context-enable (agent::face-enable-context-menu-entry :taper)
 :ui-behavior :relative)

("Adv Taper"
 :title       "Rastrema Avanzato"
 :action      (ui::uic-call-modify-3d-action :advanced-taper)
 :description "Comando di rastremazione avanzata delle facce per spigoli fissi"
 :image       "SolidDesigner/Modify_3d/adv_taper"
 :ui-behavior :relative)

("Move 3D"
 :title       "Sposta 3D"
 :action      (ui::uic-call-modify-3d-action :move)
 :description "Comando di spostamento facce e gruppi di facce riconosciute"
 :image       "SolidDesigner/Modify_3d/move_3d"
 :context-enable (agent::face-enable-context-menu-entry :move)
 :ui-behavior :on-request
 :sd-access   :yes)

("Move Face By 2 Points"
 :title       "Sposta Faccia per 2 Punti"
 :action      "uic_move_face_by_2_pnts"
 :image       "SolidDesigner/Modify_3d/move_face_2pnts"
 :ui-behavior :relative)

("Move Face By Normal Len"
 :title       "Sposta Faccia per Lungh Norm"
 :action      "uic_move_face_by_face_normal_len"
 :image       "SolidDesigner/Modify_3d/move_face_norlen"
 :ui-behavior :relative)

("Cut Faces"
 :title       "Taglia Facce"
 :action      (ui::uic-call-modify-3d-action :remove-faces)
 :description "Taglia un gruppo di facce o un gruppo di facce riconosciute con la possibilit di mantenere le facce come parti facce"
 :image       "SolidDesigner/Modify_3d/cut_faces"
 :ui-behavior :relative)

("Copy Faces"
 :title       "Copia Facce"
 :action      "copy_faces"
 :description "Copia un gruppo di facce o un gruppo di facce riconosciute in una parte vuota o appena creata"
 :image       "SolidDesigner/Modify_3d/copy_faces"
 :sd-access   :yes
 :ui-behavior :on-request)

("Paste"
 :title       "Incolla"
 :action      "paste_dia"
 :description "Incolla una faccia su una parte vuota con crescita automatica di tutti i cicli aperti"
 :image       "SolidDesigner/Modify_3d/paste_3d"
 :sd-access   :yes
 :ui-behavior :on-request
 )

("Lift Faces"
 :title       "Solleva Facce"
 :action      "lift_faces :linear :faces"
 :description "Solleva facce linearmente"
 :image       "SolidDesigner/Modify_3d/lift_faces"
 :ui-behavior :relative)

("Offset"
 :title       "Distanza"
 :action      (ui::uic-call-modify-3d-action :offset)
 :description "Comando di distanziamento facce e gruppi di facce riconosciute"
 :image       "SolidDesigner/Modify_3d/modify_offset"
 :context-enable (agent::face-enable-context-menu-entry :offset) 
 :ui-behavior :relative)

("Change Radius"
 :title       "Modifica raggio"
 :action      (ui::uic-call-modify-3d-action :change-hole)
 :description "Modifica il raggio di facce cilindriche"
 :image       "SolidDesigner/Modify_3d/change_radius"
 :ui-behavior :on-request
 :sd-access   :yes
 :context-enable (agent::face-enable-context-menu-entry :change-hole))

("Align"
 :title       "Allinea"
 :action      (ui::uic-call-modify-3d-action :align)
 :description "Allinea facce"
 :image       "SolidDesigner/Modify_3d/align"
 :context-enable (agent::face-enable-context-menu-entry :align)
 :ui-behavior :relative)

("Merge"
 :title       "Unisci"
 :action      "merge_3d"
 :description "Unisce una parte o un elemento 3D per rimuovere vertici, spigoli e/o facce superflue"
 :image       "SolidDesigner/Modify_3d/merge"
 :ui-behavior :relative)

("Mirror"
 :title       "Simmetria"
 :action      "mirror_3d"
 :description "Crea parte simmetrica"
 :image       "SolidDesigner/Modify_3d/mirror"
 :ui-behavior :relative)

("Scale"
 :title       "Scala"
 :action      "scale_3d"
 :description "Scala parte"
 :image       "SolidDesigner/Modify_3d/scale"
 :ui-behavior :relative)

;;----- SolidDesigner: Freeform -----------------------------------------------

(:Group "Freeform" :title "Geo libera")

("Loft Add"
 :title       "Agg. Inviluppo"
 :action      "add_loft"
 :description "Aggiungi materiale a una parte usando un inviluppo"
 :image       "SolidDesigner/Freeform/loft_add"
 :ui-behavior :relative)

("Loft To Part"
 :title       "Inviluppo a Parte"
 :action      "loft_extend"
 :description "Aggiungi materiale a una parte usando un inviluppo a una parte o a parti"
 :image       "SolidDesigner/Freeform/loft_to_part"
 :ui-behavior :default)

("Sweep Add"
 :title       "Aggiungi Rototraslazione"
 :action      "general_sweep_add"
 :description "Ruota e trasla un profilo 2D lungo un percorso per creare un solido o aggiungere materiale a un solido"
 :image       "SolidDesigner/Freeform/sweep_add"
 :ui-behavior :relative)

("Helix Add"
 :title       "Aggiungi Elicoidale"
 :action      "helix_add :axis"
 :description "Crea una forma elicoidale a partire da un profilo 2D chiuso"
 :image       "SolidDesigner/Freeform/helix_add"
 :ui-behavior :relative)

("Loft Remove"
 :title       "Elimina Inviluppo"
 :action      "remove_loft"
 :description "Rimuovi materiale da una parte usando un inviluppo"
 :image       "SolidDesigner/Freeform/loft_remove"
 :ui-behavior :relative)

("Sweep Remove"
 :title       "Rimuovi Rototraslazione"
 :action      "general_sweep_rem"
 :description "Rimuovi materiale da un solido facendo scorrere un profilo 2D lungo un percorso"
 :image       "SolidDesigner/Freeform/sweep_remove"
 :ui-behavior :relative)

("Helix Remove"
 :title       "Rimuovi Elicoidale"
 :action      "helix_rem :axis"
 :description "Rimuove materiale da una parte usando una forma elicoidale"
 :image       "SolidDesigner/Freeform/helix_remove"
 :ui-behavior :relative)

("Create Match Line"
 :title       "Crea Linea di Congiunzione"
 :action      "create_match_line"
 :description "Crea una linea di congiunzione per un inviluppo"
 :image       "SolidDesigner/Freeform/create_ml"
 :ui-behavior :relative)

("Delete Match Line"
 :title       "Cancella Linea di Congiunzione"
 :action      "delete_3d :matchline"
 :image       "SolidDesigner/Freeform/delete_ml"
 :ui-behavior :none)

;;----- SolidDesigner: Surfacing ----------------------------------------------

(:Group "Surfacing" :title "Superficie")

("Skin"
 :title       "Superficie esterna"
 :action      "skin"
 :description "Crea una faccia a partire da un insieme di spigoli 2D o 3D definendo una rete a riquadri"
 :image       "SolidDesigner/Surfacing/skin"
 :ui-behavior :relative)

("Guided Loft"
 :title       "Invil guidato"
 :action      "guided_loft"
 :description "Crea una superficie muovendo uno o pi profili lungo una direttrice ed una o pi curve a doppia traccia. "
 :image       "SolidDesigner/Surfacing/SUR_GuidedLoft"
 :ui-behavior :relative)

("Extrude Edges"
 :title       "Estr spigoli"
 :action      "extrude_edges"
 :description "Crea parti faccia estrudendo spigoli 2D e 3D in una determinata direzione."
 :image       "SolidDesigner/Surfacing/SUR_ExtrudeEdges"
 :ui-behavior :relative)

("Cap"
 :title       "Calotta"
 :action      "cap_3d"
 :description "Crea una calotta liscia sopra un esistente ciclo chiuso di spigoli"
 :image       "SolidDesigner/Surfacing/cap"
 :ui-behavior :relative)

("Face Round"
 :title       "Arrotond. faccia"
 :action      "face_round"
 :description "Crea una catena di facce in qualit di raccordo per connettere tangenzialmente due insiemi di parti faccia."
 :image       "SolidDesigner/Surfacing/SUR_RoundFace"
 :ui-behavior :relative)

("Bridge"
 :title       "Ponte"
 :action      "bridges"
 :description "Crea una superficie di transizione (ponte) tra due parti faccia"
 :image       "SolidDesigner/Surfacing/bridge"
 :ui-behavior :relative)

("Sweep"
 :title       "Rototraslazione"
 :action      "adv_general_sweep_add"
 :description "Crea un solido / parte faccia rototraslato lungo una curva"
 :image       "SolidDesigner/Surfacing/sweep"
 :ui-behavior :relative)

("Insert Face"
 :title       "Inserisci Faccia"
 :action      "create_face"
 :image       "SolidDesigner/Surfacing/SUR_InsertFace"
 :ui-behavior :relative)

("Gather Faces"
 :title       "Aggrega facce"
 :action      "gather_faces :s_faces"
 :description "Aggrega una faccia o pi in una parte"
 :image       "SolidDesigner/Surfacing/SUR_GatherFaces"
 :ui-behavior :relative)

("Trim"
 :title       "Taglio"
 :action      "trim_face_by_face"
 :description "Taglia una faccia tramite un'altra faccia."
 :image       "SolidDesigner/Surfacing/SUR_Trim"
 :ui-behavior :relative)

("Untrim"
 :title       "Annulla Taglio"
 :action      "untrim_dialog"
 :description "Annulla il taglio di una faccia e crea una nuova parte faccia"
 :image       "SolidDesigner/Surfacing/SUR_Untrim"
 :ui-behavior :relative)

("Extrude Face Part"
 :title       "Estrudi Faccia Parte "
 :action      "extrude_faces :tool_part"
 :image       "SolidDesigner/Surfacing/SUR_Extrude"
 :ui-behavior :relative)

("Thicken a Face Part"
 :title       "Aumenta spessore di Faccia Parte"
 :action      "thicken_face_part :distance"
 :image       "SolidDesigner/Surfacing/SUR_Thicken"
 :ui-behavior :relative)

("Delete Face"
 :title       "Elimina Faccia"
 :action      "remove_face_rep"
 :description "Rimuove una o pi facce - senza tentare di mantenere un solido"
 :image       "SolidDesigner/Surfacing/SUR_Delete"
 :ui-behavior :relative)

("Flip Faces"
 :title       "Ribalta Facce"
 :action      "flip_faces"
 :image       "SolidDesigner/Surfacing/SUR_Flip"
 :ui-behavior :relative)

("Reintersect Faces"
 :title       "Reinterseca facce"
 :action      "reintersect_faces :edges"
 :description "Chiude lo spazio tra le facce reintersecando le facce adiacenti"
 :image       "SolidDesigner/Surfacing/SUR_Reintersect"
 :ui-behavior :relative)

("Offset Face Part"
 :title       "Distanzia Parte Faccia"
 :action      "offset_face_part :distance"
 :description "Distanzia una faccia parte"
 :image       "SolidDesigner/Surfacing/SUR_Offset"
 :ui-behavior :relative)

("Modify Surface"
 :title       "Modifica Superficie"
 :action      "surface_modification"
 :description "Modifica superfici manipolando le reti che le definiscono"
 :image       "SolidDesigner/Surfacing/SUR_Modify"
 :ui-behavior :relative)

("Grow Surface"
 :title       "Accresci Superficie"
 :action      "GROW_DIA"
 :description "Accresce una superficie"
 :image       "SolidDesigner/Surfacing/SUR_Grow"
 :ui-behavior :relative)

("Smooth Surface"
 :title       "Regolarizza Superficie"
 :action      "SF_SMOOTH_DIA"
 :description "Regolarizza una superficie"
 :image       "SolidDesigner/Surfacing/SUR_Smooth"
 :ui-behavior :relative)

("Adjust Faces"
 :title       "Adatta facce"
 :action      "adjust_faces"
 :description "Migliora la regolarizzazione tra le facce."
 :image       "SolidDesigner/Surfacing/SUR_AdjustFaces"
 :ui-behavior :relative)

("Split Edge"
 :title       "Spezza Spigolo"
 :action      "split_edge_3d"
 :description "Spezza spigoli appartenenti a una parte e introduce un nuovo vertice"
 :image       "SolidDesigner/Surfacing/SUR_SplitEdge"
 :ui-behavior :relative)

("Show Gaps"
 :title       "Mostra Spazi"
 :action      "show_open_edges"
 :description "Evidenzia spazi tra le facce"
 :image       "SolidDesigner/Surfacing/SUR_ShowGaps"
 :ui-behavior :relative)

("Surf Analysis"
 :title       "Analisi di Superficie"
 :action      "sf_quality_analysis"
 :description "Analizza la qualit della superficie"
 :image       "SolidDesigner/Surfacing/SUR_Analysis"
 :ui-behavior :relative)

("Angle Analysis"
 :title       "Analisi di Angolo"
 :action      "face_angle_analysis"
 :description "Analizza l'angolo tra le facce"
 :image       "SolidDesigner/Surfacing/SUR_AngleAnalysis"
 :ui-behavior :relative)

;;----- SolidDesigner: 3D Curve -----------------------------------------------

(:Group "3D Curve" :title "Curva 3D")

("Straight 3D"
 :title       "Linea 3D"
 :action      "create_straight"
 :description "Crea linea retta 3D"
 :image       "SolidDesigner/3D_Curve/straight"
 :ui-behavior :relative)

("Circle 3D"
 :title       "Cerchio 3D"
 :action      "create_circle"
 :description "Crea cerchi 3D"
 :image       "SolidDesigner/3D_Curve/circle"
 :ui-behavior :relative)

("Spline 3D"
 :title       "Spline 3D"
 :action      "create_bspline"
 :description "Crea spline 3D"
 :image       "SolidDesigner/3D_Curve/spline_create"
 :ui-behavior :relative)

("Arc 3D"
 :title       "Arco 3D"
 :action      "create_arc"
 :description "Crea Arco 3D"
 :image       "SolidDesigner/3D_Curve/arc"
 :ui-behavior :relative)

("Spiral 3D/Helix"
 :title       "Spirale 3D/Forma elicoidale"
 :action      "spiral"
 :description "Crea una curva a spirale planare, conica o elicodidale in 3D."
 :image       "SolidDesigner/3D_Curve/helical_spiral"
 :ui-behavior :relative)

("Curve on Surface"
 :title       "Curva su Superficie"
 :action      "create_curve_on_surface"
 :description "Crea curve 3D su una superficie esistente, specificata per punti o tangenze"
 :image       "SolidDesigner/3D_Curve/crv_on_surf"
 :ui-behavior :relative)

("Curve by Intersection"
 :title       "Curva per Intersezione"
 :action      "curve_3d_by_int :first_face"
 :description "Crea la curva di intersezione tra due facce"
 :image       "SolidDesigner/3D_Curve/3DC_intersection"
 :ui-behavior :relative)

("Curve by 2D Cvs"
 :title       "Curva per Curve 2D"
 :action      "curve_3d_by_2d :first_edge"
 :description "Crea una curva 3D da curve 2D"
 :image       "SolidDesigner/3D_Curve/3DC_By2dCrv"
 :ui-behavior :relative)

("Wrap On Surf"
  :title      "Avv. Su Super."
  :action     "wrap_2d_curve_on_surface"
  :description "Avvolge una curva 2D su una faccia"
  :image "SolidDesigner/3D_Curve/3DC_wrap"
  :ui-behavior :relative)

("Convert Curve"
 :title       "Converti Curva"
 :action      "curve_conversion :wire_part"
 :description "Converte i tratti di geometria 3D esistente approssimando con una spline"
 :image       "SolidDesigner/3D_Curve/3DC_convert"
 :ui-behavior :relative)

("Gather"
 :title       "Aggrega"
 :action      "curve_gather"
 :description "Copia gli spigoli della geometria 3D esistente in una parte fil di ferro"
 :image       "SolidDesigner/3D_Curve/3DC_gather"
 :ui-behavior :relative)

("Offset Curve"
 :title       "Distanzia Curva"
 :action      "curve_offset"
 :description "Sposta gli spigoli selezionati da un solido o faccia parte e li combina in una faccia fil di ferro"
 :image       "SolidDesigner/3D_Curve/3DC_offset"
 :ui-behavior :relative)

("Mesh"
 :title       "Mesh"
 :action      "curve_mesh"
 :description "Crea una mesh da una faccia selezionata e la aggiunge a una data parte in fil di ferro"
 :image       "SolidDesigner/3D_Curve/3DC_mesh"
 :ui-behavior :relative)

("Modify Spline 3D"
 :title       "Modifica Spline"
 :action      "modify_bspline"
 :description "Modifica spline nello spazio 3D e cancella curve 3D senza eliminare la parte intera"
 :image       "SolidDesigner/3D_Curve/3DC_spline_modify"
 :ui-behavior :relative
 :context-enable (agent::edge-enable-context-menu-entry :modify-spline))

("Adjust Curves"
 :title       "Adatta curva"
 :action      "adjust_curves"
 :description "Adatta una o due curve in condizione di connessione tangenziale o di curvatura continua."
 :image       "SolidDesigner/3D_Curve/3DC_adjust_curves"
 :ui-behavior :relative)

("Fillet Curve"
 :title       "Curva di raccordo"
 :action      "fillet_curve"
 :description "Crea un raccordo tra due curve."
 :image       "SolidDesigner/3D_Curve/3DC_fillet_curve"
 :ui-behavior :relative)

("Delete Curve"
 :title       "Elimina Curva"
 :action      "curve_deletion"
 :description "Rimuove le curve 3D selezionate dalla parte fil di ferro"
 :image       "SolidDesigner/3D_Curve/3DC_delete"
 :ui-behavior :relative
 :context-enable (agent::edge-enable-context-menu-entry :delete-curve))

("Vertex 3D"
 :title       "Vertice 3D"
 :action      "vertex_creation"
 :description "Crea un vertice nello spazio 3D"
 :image       "SolidDesigner/3D_Curve/3DC_vertex"
 :ui-behavior :relative)

("Curve Analysis"
 :title       "Analisi di Curva"
 :action      "curvature_analysis"
 :description "Analizza una curva 3D"
 :image       "SolidDesigner/3D_Curve/3DC_analysis"
 :ui-behavior :relative)

;;----- SolidDesigner: Features -----------------------------------------------

(:Group "Features" :title "Gruppi di Facce")

("Create Feature"
 :title       "Crea Gruppo di Facce"
 :action      "define_feature"
 :description "Crea un gruppo di facce definito dall'utente"
 :image       "SolidDesigner/Features/create_feature"
 :ui-behavior :relative)

("Remove Feature"
 :title       "Rimuovi Gruppo di Facce"
 :action      "remove_feature"
 :description "Rimuove un gruppo di facce definito dall'utente"
 :image       "SolidDesigner/Features/remove_feature"
 :ui-behavior :relative)

("Rename Feature"
 :title       "Rinomina Gruppo di Facce"
 :action      "rename_feature"
 :description "Rinomina un gruppo di facce definito dall'utente"
 :image       "SolidDesigner/Features/rename_feature"
 :ui-behavior :relative)

("Highlight Feature"
 :title       "Evidenzia Gruppo di Facce"
 :action      "highlight_feature"
 :description "Evidenzia un gruppo di facce definito dall'utente"
 :image       "SolidDesigner/Features/highlight_feature"
 :ui-behavior :relative)

("Edit Feature"
 :title       "Modifica Gruppo di Facce"
 :action      "edit_feature"
 :description "Modifica un gruppo di facce definito dall'utente"
 :image       "SolidDesigner/Features/edit_feature"
 :ui-behavior :relative)

;;----- SolidDesigner: Process Info -------------------------------------------

(:Group "Process Info" :title "Info Processo")

("Generate Custom Feature Report"
 :title       "Genera un Prospetto per Gruppi Personalizzati"
 :action      "gen_cust_feat_report"
 :image       "SolidDesigner/Process_Info/cust_feat_report"
 :ui-behavior :relative
 :sd-access   :yes)

("Show Custom Features"
 :title       "Mostra Gruppi Personalizzati"
 :action      "cust_feat_show"
 :description "Mostra o nasconde le caratteristiche di processi personalizzati."
 :image       "SolidDesigner/Process_Info/cust_feat_show"
 :ui-behavior :relative
 :sd-access   :yes)

("Highlight Custom Features"
 :title       "Evidenzia Gruppi Personalizzati"
 :action      "cust_feat_highlight :select_feature"
 :description "Evidenzia un gruppo del processo personalizzato."
 :image       "SolidDesigner/Process_Info/cust_feat_highlight"
 :ui-behavior :relative
 :sd-access   :yes)

("Display URL"
 :title       "Visualizza URL"
 :action      "show_3d_note_url"
 :description "Visualizza l'URL associato all'interno della lista."
 :context-enable (agent::anno-enable-context-menu-entry :3d-note-url) 
 :image       "SolidDesigner/Process_Info/cust_feat_url"
 :ui-behavior :relative
 :sd-access   :yes)

("Create Custom Feature"
 :title       "Crea gruppo personalizzato"
 :action      "create_custom_feature"
 :description "Evidenzia un gruppo del processo personalizzato. Pu essere selezionato ogni tipo di gruppo disponibile."
 :image       "SolidDesigner/Process_Info/create_custom_feature"
 :ui-behavior :relative)

("Modify Custom Feature"
 :title       "Modifica gruppo personalizzato"
 :action      "modify_custom_feature :any"
 :description "Modifica un gruppo del processo personalizzato."
 :image       "SolidDesigner/Process_Info/modify_custom_feature"
 :ui-behavior :relative)

("Copy Custom Feature"
 :title       "Copia gruppo personalizzato"
 :action      "copy_custom_feature :any"
 :description "Copia un gruppo del processo personalizzato."
 :image       "SolidDesigner/Process_Info/copy_custom_feature"
 :ui-behavior :relative)

("Create Custom Feature Pattern"
 :title       "Crea pattern gruppo personalizzato"
 :action      "cocreate_cust_feat_pattern :action :create :any :ref_feat"
 :description "Evidenzia un pattern di gruppo del processo personalizzato."
 :image       "SolidDesigner/Process_Info/create_custom_feature_pattern"
 :ui-behavior :relative)

("Delete Custom Feature"
 :title       "Cancella gruppo personalizzato"
 :action      "delete_custom_feature :any_category :display-ui :with_geo :on"
 :description "Cancella un gruppo del processo personalizzato assieme alla sua geometria fisica."
 :image       "SolidDesigner/Process_Info/delete_custom_feature"
 :ui-behavior :relative)


;;----- SolidDesigner: 3D Documentation ---------------------------------------

(:Group "3D Documentation" :title "Documentazione 3D")

("3D Note"
 :title       "Nota 3D"
 :action      "cocreate_3d_note :action :create"
 :description "Crea una Nota 3D"
 :image       "3D_Documentation/3d_note"
 :ui-behavior :relative)

("Delete Anno"
 :title       "Elimina Annotazioni"
 :action      "doc3d_delete_anno"
 :context-action "doc3d_delete_anno :preselect_context :chain :off"
 :context-enable (agent::anno-enable-context-menu-entry :no-section-line-label)
 :description "Elimina le annotazioni 3D"
 :image       "3D_Documentation/3d_anno_delete"
 :ui-behavior :relative)

("Delete Chain"
 :title       "Elimina Catena Annot."
 :action      "doc3d_delete_anno :chain :on"
 :context-action "doc3d_delete_anno :preselect_context :chain :on"
 :context-enable (agent::anno-enable-context-menu-entry :no-section-line-label)
 :description "Elimina le annotazioni 3D"
;:image       no image required because this is only used in the preselect context
 :ui-behavior :relative)

("Move Anno"
 :title       "Sposta Annotazione"
 :action      "doc3d_move_anno"
 :context-enable (agent::anno-enable-context-menu-entry :no-section-arrow-label)
 :context-action "doc3d_move_anno :preselect_context"
 :description "Riposiziona un'etichetta di quota"
 :image       "3D_Documentation/3d_anno_move"
 :ui-behavior :relative)

("Orient Anno"
 :title       "Orienta Annotazione"
 :action      "doc3d_orientate_anno"
 :description "Modifica l'orientamento delle annotazioni"
 :context-enable (agent::anno-enable-context-menu-entry :no-section-line-label)
 :image       "3D_Documentation/3d_anno_orint"
 :ui-behavior :relative)

("Refpos Anno"
 :title       "Modifica la posizione di riferimento"
 :action      "doc3d_change_refpos"
 :context-enable (agent::anno-enable-context-menu-entry :no-dims-but-anno-with-ref)
 :description "Modifica la posizione di riferimento di un'annotazione"
 :image       "3D_Documentation/3d_anno_ref_pos" 
 :ui-behavior :relative)

("Load Font"
 :title       "Carica font"
 :action      "doc3d_load_font"
 :description "Carica un font da utilizzare per le annotazioni 3D"
 :ui-behavior :default
 :sd-access   :yes)

;;----- SolidDesigner: Sheets -------------------------------------------------

(:Group "Sheets" :title "Lamiere")

("New By Outline"
 :title       "Nuova: Contorno"
 :action      (if (elan::check-for-activated-sha)
                (if (equal :yes (oli::sd-display-warning "Il modulo REGULAR di SheetMetal  attivo!
Si desidera veramente utilizzare la funzione BASIC?"
                                   :push-1 "BASIC" 
                                   :push-2 "REGULAR" 
                                   :severity :medium ))
                  (oli::sd-put-buffer "SHA_BASIC_NEW_BY_OUTLINE")
                  (progn
                    (when (boundp 'marabou-ui::*sha-last-current-shop*)
                      (marabou-ui::sha_set_current_shop marabou-ui::*sha-last-current-shop*)
                      (marabou-ui::sha-default-settings marabou-ui::*sha-last-current-shop*))
                    (oli::sd-put-buffer "(oli::sd-switch-application \"SheetAdvisor\") SHA_NEW_BY_OUTLINE")
                  )
                )
                (oli::sd-put-buffer "SHA_BASIC_NEW_BY_OUTLINE")
              )
 :description "Crea una parte in lamiera dal contorno"
 :image       "SheetAdvisor/new_by_outline"
 :ui-behavior :relative)

("Lip"
 :title       "Labbro"
 :action      (if (elan::check-for-activated-sha)
                (if (equal :yes (oli::sd-display-warning "Il modulo REGULAR di SheetMetal  attivo!
Si desidera veramente utilizzare la funzione BASIC?" 
                                     :push-1 "BASIC" 
                                     :push-2 "REGULAR"
                                     :severity :medium ))
                  (oli::sd-put-buffer "SHA_BASIC_ADD_LIP")
                  (progn
                    (when (boundp 'marabou-ui::*sha-last-current-shop*)
                      (marabou-ui::sha_set_current_shop marabou-ui::*sha-last-current-shop*)
                      (marabou-ui::sha-default-settings marabou-ui::*sha-last-current-shop*))
                    (oli::sd-put-buffer "(oli::sd-switch-application \"SheetAdvisor\") SHA_ADD_LIP")
                  )
                )
                (oli::sd-put-buffer "SHA_BASIC_ADD_LIP")
              )
 :description "Aggiunge una lamiera addizionale a uno spigolo di una parte lamiera esistente"
 :image       "SheetAdvisor/lip"
 :ui-behavior :relative)

("Create Bends"
 :title       "Crea Pieghe"
 :action      "bend_create"
 :description "Crea pieghe da spigoli o da una lamiera planare"
 :image       "SolidDesigner/Sheets/bend_create"
 :ui-behavior :relative)

("Modify Bends"
 :title       "Modifica Pieghe"
 :action      "bend_modify"
 :description "Modifica Pieghe"
 :image       "SolidDesigner/Sheets/bend_modify"
 :ui-behavior :relative)

("Fold/Unfold"
 :title       "Piega/Sviluppa"
 :action      "fold_unfold"
 :description "Piega e sviluppa parti"
 :image       "SolidDesigner/Sheets/fold_unfold"
 :ui-behavior :relative)

("Bend Animation"
 :title       "Animazione Pieghe"
 :action      "bend_animation"
 :description "Anima una o pi pieghe"
 :image       "SolidDesigner/Sheets/bend_anim"
 :ui-behavior :relative)

("Unfold Part"
 :title       "Svil. Parte"
 :action      "unfold_part"
 :description "Sviluppa tutte le pieghe di una parte"
 :image       "SolidDesigner/Sheets/unfold_part"
 :ui-behavior :relative)

("Refold Part"
 :title       "Piega Parte"
 :action      "fold_part"
 :description "Ripiega tutte le piege di una parte"
 :image       "SolidDesigner/Sheets/fold_part"
 :ui-behavior :relative)

;;----- SolidDesigner: Filing -------------------------------------------------

(:Group "Filing" :title "Archiviazione")

("New Session"
 :title       "&Nuova Sessione"
 :action      "uic_reset_session"
 :description "Cancella il modello attuale e continua con una nuova parte vuota ed un piano di lavoro"
 :image       "SolidDesigner/Filing/new_doc"
 :sd-access   :yes)

("Load ..."
 :title       "C&arica ..."
 :action      (ui::uic-show-load-browser)
 :description "Carica un file"
 :ui-behavior :relative
 :image       "SolidDesigner/Filing/load_sd"
 :sd-access   :yes)

("Load 3D Data"
 :title       "Carica Dati 3D"
 :action      "load_sd"
 :image       "SolidDesigner/Filing/load_3d_data"
 :ui-behavior :default
 :sd-access   :yes)

("Load Package"
 :title       "Carica Fascicolo"
 :action      "load_package"
 :image       "SolidDesigner/Filing/load_package"
 :ui-behavior :default
 :sd-access   :yes)

("Load Environment"
 :title       "Carica Ambiente"
 :action      "load_environment"
 :image       "SolidDesigner/Filing/load_environment"
 :ui-behavior :default)

("Load Session"
 :title       "Carica Sessione"
 :action      "load_session"
 :image       "SolidDesigner/Filing/load_session"
 :ui-behavior :default)

("Load ME30"
 :title       "Carica ME30"
 :action      "load_me30"
 :image       "SolidDesigner/Filing/load_me30"
 :ui-behavior :default
 :sd-access   :yes)

("Load Profile (MI)"
 :title       "Carica Profilo (MI)"
 :action      "load_profile"
 :image       "SolidDesigner/Filing/load_mi"
 :ui-behavior :default
 :sd-access   :yes)

("Load IGES"
 :title       "Carica IGES"
 :action      "native_cad_in :cad_system :igesdek"
 :image       "SolidDesigner/Filing/load_iges"
 :ui-behavior :default
 :sd-access   :yes)

("Load STEP"
 :title       "Carica STEP"
 :action      "step_import"
 :image       "SolidDesigner/Filing/load_step"
 :ui-behavior :default
 :sd-access   :yes)

("Save ..."
 :title       "&Salva ..."
 :action      (ui::uic-show-save-browser)
 :description "Salva gli oggetti selezionati"
 :ui-behavior :relative
 :image       "SolidDesigner/Filing/save_sd"
 :sd-access   :yes)

("Save 3D Data"
 :title       "Salva Dati 3D"
 :action      "save_sd"
 :image       "SolidDesigner/Filing/save_3d_data"
 :enable      (not (si::eval-feature 'lisp::demomode))
 :ui-behavior :default)

("Save 3D Modified"
 :title       "Salva Modifiche 3D"
 :action      "save_sd_modified"
 :image       "SolidDesigner/Filing/save_3d_modified"
 :enable      (not (si::eval-feature 'lisp::demomode))
 :ui-behavior :default)

("Save Package"
 :title       "Salva Fascicolo"
 :action      "save_package"
 :image       "SolidDesigner/Filing/save_package"
 :ui-behavior :default)

("Save Package All at Top"
 :title       "Salva Fascicolo Tutto dalla Radice"
 :action      "save_package :all_at_top :overwrite"
 :image       "SolidDesigner/Filing/save_pkg_all_at_top"
 :ui-behavior :default)

("Save Package in Assembly"
 :title       "Salva Fascicolo nel Gruppo"
 :action      "save_package :in_assembly"
 :image       "SolidDesigner/Filing/save_pkg_in_assy"
 :ui-behavior :default)

("Save Session"
 :title       "Salva Sessione"
 :action      "save_session"
 :image       "SolidDesigner/Filing/save_session"
 :enable      (not (si::eval-feature 'lisp::demomode))
 :ui-behavior :default)

("Save MI"
 :title       "Salva MI"
 :action      "mi_out"
 :image       "SolidDesigner/Filing/save_layout"
 :ui-behavior :default)

("Save Environment"
 :title       "Salva Ambiente"
 :action      "save_environment"
 :image       "SolidDesigner/Filing/save_environment"
 :enable      (not (si::eval-feature 'lisp::demomode))
 :ui-behavior :default)

("Save ACIS (SAT)"
 :title       "Salva ACIS (SAT)"
 :action      "native_cad_out :cad_system :acis_sat"
 :image       "SolidDesigner/Filing/save_acis"
 :enable      (not (si::eval-feature 'lisp::demomode))
 :ui-behavior :default)

("Save STL"
 :title       "Salva STL"
 :action      "stl"
 :image       "SolidDesigner/Filing/save_stl"
 :enable      (not (si::eval-feature 'lisp::demomode))
 :ui-behavior :default)

("Save IGES"
 :title       "Salva IGES"
 :action      "native_cad_out :cad_system :igesdek"
 :image       "SolidDesigner/Filing/save_iges"
 :ui-behavior :default
 :sd-access   :yes)

;; Currently these settings are not supported by the Elysium IGES interface
;; so we are still using the old IGES
("Save IGES Surface"
 :title       "Salva Superficie IGES"
 :action      "save_iges :settings :trimmed-parametric :select :part"
 :description "Salva come superficie IGES tagliata parametricamente"
 :image       "SolidDesigner/Filing/save_iges_surface"
 :ui-behavior :default
 :sd-access   :yes)

("Save IGES Wireframe"
 :title       "Salva fil di ferro IGES"
 :action      "save_iges :settings :wireframe :select :part"
 :image       "SolidDesigner/Filing/save_iges_wireframe"
 :ui-behavior :default
 :sd-access   :yes)

("Save STEP"
 :title       "Salva STEP"
 :action      "step_export"
 :image       "SolidDesigner/Filing/save_step"
 ;;:enable      (not (si::eval-feature 'lisp::demomode))
 :ui-behavior :default
 :sd-access   :yes)

("Save VRML"
 :title       "Salva VRML"
 :action      "vrml-out :select"
 :image       "SolidDesigner/Filing/save_vrml"
 :enable      (not (si::eval-feature 'lisp::demomode))
 :ui-behavior :relative)

("Save XVL"
 :title       "Salva XVL"
 :action      "native_cad_out :cad_system :xvl"
 :image       "SolidDesigner/Filing/save_xvl"
 :ui-behavior :default
 :sd-access   :yes)

("Database ..."
 :title       "Database ..."
 :action      (oli::sd-show-dialog-shell "SD-AIP-UI-MENU" :position '("TOP-MENU-DATABASE-TB" :bottomleft 0 0))
 :description "Mostra il menu database"
 :enable      (or elan-ui::*database-enabled* (and (functionp 'modelmanager::is-connected)  (modelmanager::is-connected)))
 :image       "SolidDesigner/Filing/database"
 :sd-access   :yes)
 
 ("Load From Database ..."
 :title       "Carica dal database ..."
 :action      (if elan-ui::*database-enabled* (put-buffer "db-aip-ui::db_load_3d_data") (put-buffer "modelmanager::ndm_load"))
 :description "Carica dal database"
 :enable      (or elan-ui::*database-enabled* (and (functionp 'modelmanager::is-connected)  
                                                   (modelmanager::is-connected) 
                                                   (modelmanager::mm-is-cmd-activ :MM_LOAD)))
 :image       "SolidDesigner/ModelManager/load"
 :sd-access   :yes)
 
 ("Save To Database ..."
 :title       "Salva su database ..."
 :action      (if elan-ui::*database-enabled* (put-buffer "db-aip-ui::db_save_3d_data") (put-buffer "modelmanager::ndm_store"))
 :description "Salva nel database"
 :enable      (or elan-ui::*database-enabled* (and (functionp 'modelmanager::is-connected)  
                                                   (modelmanager::is-connected)
                                                   (modelmanager::mm-is-cmd-activ :MM_SAVE)))
 :image       "SolidDesigner/ModelManager/save" 
 :sd-access   :yes)

("Store Workfile"
 :title       "Salva File di Lavoro"
 :action      "uic_store_workfile"
 :description "Memorizza la sessione attuale di OneSpace Designer in un file 'workfile.ses' nella home o nella cartella del profilo"
 :enable      (not (si::eval-feature 'lisp::demomode))
 :image       "SolidDesigner/Filing/store_workfile")

("Recall Workfile"
 :title       "Richiama File di Lavoro"
 :action      "uic_recall_workfile"
 :description "Ricarica un file di sessione '$HOME/workfile.ses' se disponibile"
 :image       "SolidDesigner/Filing/recall_workfile")

("Copy File"
 :title       "Copia File"
 :action      "uic_copy_file :source_file"
 :description "Copia un file sul file system"
 :image       "SolidDesigner/Filing/copy_file"
 :ui-behavior :relative)

("Move File"
 :title       "Sposta File"
 :action      "uic_move_file :source_file"
 :description "Sposta un file sul file system"
 :image       "SolidDesigner/Filing/move_file"
 :ui-behavior :relative)

("Delete File"
 :title       "Elimina File"
 :action      "uic_delete_file :file"
 :description "Elimina un file sul file system"
 :image       "SolidDesigner/Filing/delete_file"
 :ui-behavior :relative)

;;----- SolidDesigner: Print --------------------------------------------------

(:Group "Print" :title "Stampa"
	:all-in-sd-access :yes)

("Print"
 :title       "Stam&pa"
 :sysCmdId    #xE107                            ;; ID_FILE_PRINT
 :description "Stampa il documento attivo"
 :image       "SolidDesigner/Print/print")

("Print Preview"
 :title       "Ant&eprima di Stampa"
 :sysCmdId    #xE109                            ;; ID_FILE_PRINT_PREVIEW
 :description "Mostra a pagina intera"
 :image       "SolidDesigner/Print/preview")

("High Resolution Print"
 :title       "S&tampa ad Alta Risoluzione"
 :action      (ui::uic-call-hr-dump)
 :image       "SolidDesigner/Print/print"
 :description "Stampa la finestra attiva con la risoluzione della stampante")

;;----- SolidDesigner: Edit ---------------------------------------------------

(:Group "Edit" :title "Modifica"
	:all-in-sd-access :yes)

("Cut"
 :title       "&Taglia"
 :sysCmdId    #xE123                 ;; ID_EDIT_CUT
 :description "Taglia la selezione e la pone negli Appunti"
 :image       "SolidDesigner/Edit/cut")

;;----- SolidDesigner: Delete -------------------------------------------------

(:Group "Delete" :title "Elimina"
	:all-in-sd-access :yes)

("Delete 2D"
 :title       "Elimina &2D"
 :action      "delete_2d"
 :context-action "delete_2d :use_preselected_objects"
 :description "Elimina gli elementi 2D selezionati"
 :image       "SolidDesigner/Delete/delete_2d_elem"
 :ui-behavior :relative)

("Delete 3D"
 :title       "Elimina &3D"
 :action      "delete_3d"
 :context-action "delete_3d :use_preselected_objects"
 :description "Elimina gli elementi 3D selezionati"
 :image       "SolidDesigner/Delete/delete_3d"
 :ui-behavior :relative)

("Delete All 2D"
 :title       "Elimina Tutto 2D"
 :action      "delete_2d :all_2d complete"
 :description "Elimina tutta la geometria 2D sul PL attivo"
 :image       "SolidDesigner/Delete/delete_2d_all")

("Delete 2D Geom"
 :title       "Elimina Geometria 2D"
 :action      "delete_2d :current_wp :edge_2d :all_2d complete"
 :description "Elimina tutta la geometria 2D reale sul PL attivo"
 :image       "SolidDesigner/Delete/delete_2d_geom_all")

("Delete 2D Const"
 :title       "Elimina Costr. 2D"
 :action      "delete_2d :current_wp :c_edge_2d :all_2d complete"
 :description "Elimina tutte le geometrie di costruzione sul PL attivo"
 :image       "SolidDesigner/Delete/delete_2d_const_all")

("Delete All 3D"
 :title       "Elimina Tutto 3D"
 :action      "delete_3d :all_at_top complete"
 :description "Elimina tutti gli oggetti 3D da Radice"
 :image       "SolidDesigner/Delete/delete_3d_all")

("Delete Workplane"
 :title       "Elimina Piano di Lavoro"
 :action      "delete_3d :workplane"
 :image       "SolidDesigner/Delete/delete_wp"
)

("Delete Part"
 :title       "Elimina Parte"
 :action      "delete_3d :part"
 :image       "SolidDesigner/Delete/delete_part"
)

("Delete Assembly"
 :title       "Elimina Gruppo"
 :action      "delete_3d :assembly"
 :image       "SolidDesigner/Delete/delete_assy"
)

("Delete View"
 :title       "Elimina Vista"
 :action      "delete_3d :view"
 :description "Elimina una vista da un layout"
 :image       "SolidDesigner/Delete/delete_view"
)

;;----- SolidDesigner: Window -------------------------------------------------

(:Group "Window" :title "Finestra"
	:all-in-sd-access :yes)

("New Standard Viewport"
 :title       "&Nuova Finestra Vista Standard"
 :sysCmdId    #xE130                      ;; ID_WINDOW_NEW
 :description "Apre una nuova Finestra Vista con impostazioni predefinite"
 :image       "SolidDesigner/View/new_std_vp")

("New Viewport ..."
 :title       "Nuova Fin&estra Vista ..."
 :action      (frame2-ui::create-viewport)
 :description "Apre una finestra di dialogo per creare una nuova finestra vista")

("Delete Viewport"
 :title       "Elimina Finestra Vista"
 :action      "delete_vp"
 :description "Elimina una finestra vista"
 :image       "SolidDesigner/Delete/delete_vp")

;;----- SolidDesigner: Show ---------------------------------------------------

(:Group "Show" :title "Mostra"
	:all-in-sd-access :yes)

("3D Shaded"
 :title       "3D Ombreggiata"
 :action      (progn
               (ui::uic-set-show-mode '(:3dgeo_shaded :3dgeo_hidden) :on)
               (ui::uic-set-show-mode '(:3dgeo_wire :3dgeo_edged) :off))
 :description "Mostra il modello in modalit ombreggiata nella finestra attuale"
 :image       "SolidDesigner/Show/shaded")

("3D Shaded and Edged"
 :title       "3D Ombreggiata e Spigoli"
 :action      (progn
               (ui::uic-set-show-mode '(:3dgeo_shaded :3dgeo_edged :3dgeo_hidden) :on)
               (ui::uic-set-show-mode :3dgeo_wire :off))
 :description "Mostra il modello in modalit ombreggiata e spigoli attivati nella finestra attuale"
 :image       "SolidDesigner/Show/shaded_edged")

("3D Edged and Hidden Off"
 :title       "Spigoli 3D On e Linee nascoste Off"
 :action      (progn
               (ui::uic-set-show-mode '(:3dgeo_edged) :on)
               (ui::uic-set-show-mode '(:3dgeo_shaded :3dgeo_wire :3dgeo_hidden) :off))
 :description "Mostra il modello con i soli spigoli"
 :image       "SolidDesigner/Show/edged")

("3D Vertices On/Off"
 :title       "Vertici 3D On/Off"
 :action      (ui::uic-set-show-mode :3dgeo_vertices :toggle)
 :description "Commuta la modalit di visualizzazione dei vertici 3D in una data finestra vista"
 :image       "SolidDesigner/Show/3dgeo_vertices")

("Labels On/Off"
 :title       "Etichette On/off"
 :action      (ui::uic-set-show-mode '(:3dgeo_label :off :workplanes_2dgeo_label :off)
                                     '(:3dgeo_label :on :workplanes_2dgeo_label :on))
 :description "Commuta la modalit di visualizzazione delle etichette in una data finestra vista"
 :image       "SolidDesigner/Show/3dgeo_labels")

("2D Geometry On/Off"
 :title       "Geometria 2D On/Off"
 :action      (ui::uic-set-show-mode
               '(:workplanes_2dgeo :off :workplanes_2dconstruction :off)
               '(:workplanes_2dgeo :on :workplanes_2dconstruction :on))
 :description "Commuta la modalit di visualizzazione della geometria 2D in una data finestra vista"
 :image       "SolidDesigner/Show/wp_2dgeo")

("2D Real Geometry On/Off"
 :title       "Attiva/Disattiva Geometria reale 2D"
 :action      (ui::uic-set-show-mode :workplanes_2dgeo :toggle)
 :description "Mostra o nasconde la geometria 2D reale nella finestra vista attuale"
 :image       "SolidDesigner/Show/wp_2drgeo")

("2D Constr Geometry On/Off"
 :title       "Attiva/Disattiva Geometria costruzione 2D"
 :action      (ui::uic-set-show-mode :workplanes_2dconstruction :toggle)
 :description "Mostra o nasconde la geometria 2D di costruzione nella finestra vista attuale"
 :image       "SolidDesigner/Show/wp_2dcgeo")

("2D Vertex On/Off"
 :title       "Vertici 2D On/Off"
 :action      (ui::uic-set-show-mode :workplanes_2dgeo_vertices :toggle)
 :description "Commuta la modalit di visualizzazione dei vertici 2D in una data finestra vista"
 :image       "SolidDesigner/Show/2d_vertex_on_off")

("Workplanes On/Off"
 :title       "Piani di Lavoro On/Off"
 :action      (ui::uic-set-show-mode :workplanes :toggle)
 :description "Commuta la modalit di visualizzazione dei piani di lavoro in una data finestra vista"
 :image       "SolidDesigner/Show/wp_off")

("3D Hidden On/Off"
 :title       "Nascondi 3D On/Off"
 :action      (ui::uic-set-show-mode :3dgeo_hidden :toggle)
 :description "Commuta la modalit nascondi 3D in una data finestra vista"
 :image       "SolidDesigner/Show/3d_hidden_on_off")

("3D Geometry On/Off"
 :title       "Geometria 3D On/Off"
 :action      (ui::uic-set-show-mode :3dgeo :toggle)
 :description "Commuta la modalit mostra 3D in una data finestra vista"
 :image       "SolidDesigner/Show/3dgeo_off")

("3D Edged On/Off"
 :title       "Spigoli 3d On/Off"
 :action      (ui::uic-set-show-mode :3dgeo_edged :toggle)
 :description "Modifica la visualizzazione a spigoli 3D in una data finestra vista."
 :image       "SolidDesigner/Show/3d_edged_on_off")

("Shaded/Wire"
 :title       "Ombreggiatura/Fil di Ferro"
 :action      (ui::uic-set-show-mode
                  '(:3dgeo_shaded :off :3dgeo_wire :on :3dgeo_hidden :off)
                  '(:3dgeo_shaded :on :3dgeo_wire :off :3dgeo_hidden :on))
 :description "Commuta tra modalit ombreggiato e fil di ferro in una data finestra vista"
 :image       "SolidDesigner/Show/shaded_wire")

("Part Transparency On/Off"
 :title       "Trasparenza Parte On/Off"
 :action      (UI::uic-set-show-mode  :3dgeo_part_transparency  :toggle)
 :description "Attiva/Disattiva la trasparenza della parte in una finestra vista data o selezionata"
 :image       "SolidDesigner/Show/part_transp_on_off")

("Face Transparency On/Off"
 :title       "Trasparenza Faccia On/Off"
 :action      (UI::uic-set-show-mode :3dgeo_face_transparency  :toggle )
 :description "Attiva/Disattiva la trasparenza delle facce in una finestra vista data o selezionata"
 :image       "SolidDesigner/Show/face_transp_on_off")

("WP Borders On/Off"
 :title       "Contorni PL On/Off"
 :action      (UI::uic-set-show-mode
                  '(:workplanes_border :off :workplanes_label :off)
                  '(:workplanes_border :on :workplanes_label :on))
 :description "Commuta i contorni del PL in una data finestra vista"
 :image       "SolidDesigner/Show/wp_borders_on_off")

("WP Axes On/Off"
 :title       "Assi PL On/Off"
 :action      (ui::uic-set-show-mode :workplanes_local_axis :toggle)
 :description "Attiva/Disattiva gli assi del PL in una data finestra vista"
 :image       "SolidDesigner/Show/wp_axes")

("Light Icons On"
 :title       "Attiva Icone Sorgenti Luminose"
 :action      (ui::uic-set-show-mode :light_icons :on)
 :description "Attiva le icone delle sorgenti luminose in una finestra vista data o selezionata"
 :image       "SolidDesigner/Show/light_icons_on")

("Light Icons Off"
 :title       "Disattiva Icone Sorgenti Luminose"
 :action      (ui::uic-set-show-mode :light_icons :off)
 :description "Disattiva le icone delle sorgenti luminose in una finestra vista data o selezionata"
 :image       "SolidDesigner/Show/light_icons_off")

("Light Help Body On"
 :title       "Attiva Sorgenti Luminose d'Aiuto"
 :action      (ui::uic-set-show-mode :light_help_body :on)
 :description "Attiva le sorgenti luminose d'aiuto in una finestra vista data o selezionata"
 :image       "SolidDesigner/Show/light_help_body_on")

("Light Help Body Off"
 :title       "Disattiva Sorgenti Luminose d'Aiuto"
 :action      (ui::uic-set-show-mode :light_help_body :off)
 :description "Disattiva le sorgenti luminose d'aiuto in una finestra vista data o selezionata"
 :image       "SolidDesigner/Show/light_help_body_off")

;;----- SolidDesigner: Drawlist -----------------------------------------------

(:Group "Drawlist" :title "Elementi a Video"
	:all-in-sd-access :yes)

("Add to Drawlist ..."
 :title       "&Aggiungi agli Elementi a Video ..."
 :action      (ui::uic-vp-cmd "add_to_vp_drawlist")
 :image       "SolidDesigner/Drawlist/drawlist_browser_add"
 :description "Aggiunge gli elementi selezionati agli elementi a video della finestra vista")

("Remove from Drawlist ..."
 :title        "&Rimuovi dagli elementi a video ..."
 :action       (ui::uic-vp-cmd "remove_from_vp_drawlist")
 :image       "SolidDesigner/Drawlist/drawlist_browser_remove"
 :description  "Rimuove gli elementi selezionati dagli elementi a video della finestra vista")

("Clear Drawlist"
 :title       "P&ulisci Elementi a Video"
 :action      (ui::uic-vp-cmd "clear_vp")
 :image       "SolidDesigner/Drawlist/drawlist_browser_clear"
 :description "Elimina tutti gli elementi a video dalla attuale finestra")

("Add all to Drawlist"
 :title       "Aggungi tutto ag&li elementi a video"
 :action      (ui::uic-vp-cmd "uic_draw_all")
 :image       "SolidDesigner/Drawlist/drawlist_browser_add_all"
 :description "Aggiunge tutte le parti, gruppi, piani di lavoro, insiemi di piani di lavoro e layout agli elementi a video per la finestra vista attuale")

("Draw Only ..."
 :title       "&Mostra Solo ..."
 :action      (ui::uic-vp-drawlist-cmd "set_vp_drawlist")
 :image       "SolidDesigner/Drawlist/drawlist_browser_draw_only"
 :description "Solo l'elemento selezionato rimane a video")

("Draw Only in New VP ..."
 :title       "Nella nuova Finestra disegna solo ..."
 :action      "draw_only_in_new_vport"
 :image       "SolidDesigner/Drawlist/drawlist_browser_draw_only"
 :description "Gli oggetti selezionati sono mostrati in una nuova finestra vista.")

("Copy Drawlist ..."
 :title       "&Copia elementi a video ..."
 :action      (ui::uic-vp-cmd "copy_vp_drawlist")
 :image       "SolidDesigner/Drawlist/drawlist_browser_copy"
 :description "Copia il contenuto degli elementi a video da una finestra a un'altra")

;;----- SolidDesigner: Catch --------------------------------------------------

(:Group "Catch" :title "Attiva"
	:all-in-sd-access :yes)

("Catch 2D All"
 :title       "Attiva Tutto 2D"
 :action      (elan-ui::push-catch-parameter
                "set_catch_parameters :project set_catch_parameters :all set_catch_parameters :part :off")
 :description "Imposta la modalit di attivazione su tutta la geometria 2D"
 :image       "SolidDesigner/Catch/catch_2d_all")

("Catch 3D->2D All"
 :title       "Attiva Tutto 3D->2D"
 :action      (elan-ui::push-catch-parameter
                "set_catch_parameters :project set_catch_parameters :all set_catch_parameters :part :on")
 :description "Imposta la modalit di attivazione su tutta la geometria 2D e 3D"
 :image       "SolidDesigner/Catch/catch_3d_2d_all")

("Catch 3D->2D Center"
 :title       "Attiva Centri 3D->2D"
 :action      (elan-ui::push-catch-parameter
                "set_catch_parameters :project set_catch_parameters :center set_catch_parameters :part :on")
 :description "Imposta la modalit di attivazione sui centri degli elementi 2D e 3D"
 :image       "SolidDesigner/Catch/catch_center")

;;----- SolidDesigner: Select -------------------------------------------------

(:Group "Select" :title "Selezione"
	:all-in-sd-access :yes)

("Probe"
 :title       "Avanzamento"
 :action      ":step"
 :enable      elan-ui::*stepper-enabled*
 :description "Avanza e seleziona gli oggetti"
 :image       "SolidDesigner/Select/probe"
 :ui-behavior :relative)

("Preselection"
 :title       "Preselezione"
 :range       (("All"
                :title    "Tutto"
                :action   "(set-current-preselection-focus :all_types)")
               ("Assembly"
                :title    "Gruppo"
                :action   "(set-current-preselection-focus :assembly)")
               ("Part"
                :title    "Parte"
                :action   "(set-current-preselection-focus :part)")
               ("Workplane"
                :title    "Piano di Lavoro"
                :action   "(set-current-preselection-focus :workplane)")
               ("Face"
                :title    "Faccia"
                :action   "(set-current-preselection-focus :face_3d)")
               ("Edge"
                :title    "Spigolo 3D"
                :action   "(set-current-preselection-focus :edge_3d)")
               ("Edge2D"
                :title    "Spigolo 2D"
                :action   "(set-current-preselection-focus :edge_2d)")
               ("Annotation"
                :title    "Annotazione"
                :action   "(set-current-preselection-focus :3d_annotation)")
               ("Docuplane"
                :title    "PianoDocumento"
                :action   "(set-current-preselection-focus :docu_plane)"))
 :enable      (agent::get-preselection-allowed)
 :action      "current_presel_focus"
 :description "Imposta il criterio di preselezione"
 :image       "SolidDesigner/Select/preselection"
 :ui-behavior :relative)

("Select All 2D"
 :title       "Seleziona Tutto 2D"
 :action      ":all_2d"
 :image       "SolidDesigner/Select/select_all_2d")

("Select All 3D"
 :title       "Seleziona Tutto 3D"
 :action      ":all_3d"
 :image       "SolidDesigner/Select/select_all_3d")

("Select By Face"
 :title       "Seleziona per Facce"
 :action      ":by_face"
 :image       "SolidDesigner/Select/select_by_face"
)

("Select By Edge3D"
 :title       "Seleziona per Spigoli 3D"
 :action      ":by_edge_3d"
 :image       "SolidDesigner/Select/select_by_edge3d"
)

("Select In Part"
 :title       "Seleziona nella Parte"
 :action      ":in_part"
 :image       "SolidDesigner/Select/select_in_part"
)

("Select In Assembly"
 :title       "Seleziona nel Gruppo"
 :action      ":in_assembly"
 :image       "SolidDesigner/Select/select_in_assy"
)

("Select By VP Box"
 :title       "Seleziona da riquadro FV"
 :action      (if (elan-ui::selector-3d-elem-enabled-p)
		  (put-buffer ":by_box_vp")
		(put-buffer ":by_box_vp_obj"))
 :enable      (and elan-ui::*selector-enabled*
		   (or (elan-ui::selector-3d-elem-enabled-p)
		       (elan-ui::selector-3d-obj-enabled-p)))
 :description "Seleziona da riquadro FV infinito"
 :image       "SolidDesigner/Select/select_by_vp_box"
)

("Select By 3D Box"
 :title       "Seleziona da riquadro 3D"
 :action      (if (elan-ui::selector-3d-elem-enabled-p)
		  (put-buffer ":by_box_wp")
		(put-buffer ":by_box_wp_obj"))
 :enable      (and elan-ui::*selector-enabled*
		   (or (elan-ui::selector-3d-elem-enabled-p)
		       (elan-ui::selector-3d-obj-enabled-p)))
 :description "Seleziona da riquadro 3D sul PL corrente"
 :image       "SolidDesigner/Select/select_by_3d_box"
)

("Select Current"
 :title       "Seleziona Corrente"
 :action      ":current"
; :image       "SolidDesigner/Select/select_current"
)

("Select By Defined Feature"
 :title       "Seleziona per gruppo di facce definito"
 :action      ":by_feature"
 :description "Seleziona per gruppo di facce definito dall'utente"
; :image       "SolidDesigner/Select/select_by_def_feat"
)

("Select By Recognized Feature"
 :title       "Seleziona per Gruppo di Facce Riconosciuto"
 :action      ":by_boss_pocket"
 :description "Seleziona per gruppi di facce riconosciute"
; :image       "SolidDesigner/Select/select_by_rec_feat"
)

("Select By Rib Feature"
 :title       "Seleziona per Nervatura"
 :action      ":convex"
 :description "Seleziona una nervatura tramite i suoi confini convessi"
; :image       "SolidDesigner/Select/select_by_rib_feat"
)

("Select By Slot Feature"
 :title       "Seleziona per gruppo Tasca"
 :action      ":concave"
 :description "Seleziona una tasca tramite i suoi confini concavi"
; :image       "SolidDesigner/Select/select_by_slot_feat"
)

("Select 2D Geometry"
 :title       "Seleziona Geometria 2D"
 :action      ":edge_2d"
 :description "Imposta il criterio di selezione sulla geometria 2D."
)

("Select 2D Construction"
 :title       "Seleziona Costruzione 2D"
 :action      ":c_edge_2d"
 :description "Imposta il criterio di selezione sulla geometria di costruzione."
)

("Select 3D Edges"
 :title       "Seleziona spigoli 3D"
 :action      ":edge_3d"
 :description "Imposta il criterio di selezione sugli spigoli 3D."
)

("Select Faces"
 :title       "Seleziona Facce"
 :action      ":face_3d"
 :description "Imposta il criterio di selezione sulle facce."
)

;;----- SolidDesigner: Measure ------------------------------------------------

(:Group "Measure" :title "Calcola"
	:all-in-sd-access :yes)

("Measure"
 :title       "Calcola"
 :action      (ui::uic-show-measure-menu)
 :description "Menu con comandi di Calcolo"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/measure_menu")

;; Measure commands with output to measure output box

("Point 2D"
 :title       "Punto 2D"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_pt_2d"
 :description "Misura le coordinate di un punto 2D relative all'origine del piano di lavoro nel sistema di coordinate locali."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_point_2D"
 :ui-behavior :relative)

("Point 3D"
 :title       "Punto 3D"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_pt_3d"
 :description "Misura le coordinate di un punto 3D relative all'origine del sistema di coordinate globali."
 :image       "SolidDesigner/Measure/meas_3d_pnt"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Maximal Point 3D"
 :title       "Massimo Punto 3D"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_max_point"
 :description "Misura il punto massimo sugli spigoli/sulle facce in una certa direzione."
 :image       "SolidDesigner/Measure/meas_max_point"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Vector 3D"
 :title       "Vettore 3D"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_vec_3d"
 :description "Apre il menu per il calcolo dei vettori 3D."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_3d_vec"
 :ui-behavior :relative)

("Vector by 2 Points"
 :title       "Vettore per 2 Punti"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_vec_3d :two_ptv"
 :description "Misura il vettore tra 2 punti."
 :image       "SolidDesigner/Measure/meas_vec_2pnts"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Vector by Dir and Length"
 :title       "Vettore per Direz e Lungh"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_vec_3d :dir_len"
 :description "Misura il vettore definito da una direzione e una lunghezza."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_vec_dir_len"
 :ui-behavior :relative)

;;("Vector Face Nor Len"
;; :title       (lola mesg "Vector Face Nor Len" 9999 "browser_item" "Command name")
;; :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_vec_3d :face_nor_len"
;; :description (lola mesg "." 9999 "prompt" "Command description")
;; :image       "SolidDesigner/Measure/meas_vec_face_nor_len"
;;)

("Dist"
 :title       "Distanza"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist"
 :description "Apre il menu per il calcolo delle distanze."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_distance"
 :ui-behavior :relative)

("Dist by 2 Points"
 :title       "Distanza tra 2 Punti"
 :enable      (not (anim::anim-play-command-is-active))
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :between_points"
 :description "Calcola la distanza tra due punti. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_by_2pnts"
 :ui-behavior :relative)

("Distance Horizontal"
 :title       "Distanza Orizzontale"
 :enable      (not (anim::anim-play-command-is-active))
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" uic_measure_dist_horizontal"
 :description "Calcola la distanza orizzontale tra due punti. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_horiz")

("Distance Vertical"
 :title       "Distanza Verticale"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" uic_measure_dist_vertical"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Calcola la distanza verticale tra due punti. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_vert")

("Distance on Workplane"
 :title       "Distanza sul Piano di Lavoro"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" uic_measure_dist_workplane"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Calcola la distanza tra due punti proiettati sul piano di lavoro attivo. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_on_wp")

("Distance in Direction"
 :title       "Distanza in Direzione"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" uic_measure_dist_direction"
 :description "Calcola la distanza tra due punti in una direzione definita dall'utente. (Risultato-> campo dati uscita)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dist_in_dir")

("Maximal Distance"
 :title       "Distanza massima"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_max_dist"
 :description "Misura la distanza massima tra spigoli/facce."
 :image       "SolidDesigner/Measure/meas_max_dist"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Edge Length"
 :title       "Lunghezza spigolo"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :edge_length"
 :description "Calcola la lunghezza di uno spigolo (Risultato-> campo dati uscita)"
 :ui-behavior :relative
 :image       "SolidDesigner/Measure/meas_edge_length")

("Contour Length"
 :title       "Lunghezza contorno"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :contour_length"
 :description "Misura la lunghezza del contorno data dalla somma delle lunghezze dei singoli spigoli. (Risultato -> Campo dati in uscita distanza)"
 :ui-behavior :relative
 :image       "SolidDesigner/Measure/meas_contour_length")

("Radius of Edge"
 :title       "Raggio"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :radius"
 :description "Calcola il raggio di un cilindro, arco, o cerchio. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_radius"
 :ui-behavior :relative)

("Diameter of Edge"
 :title       "Diametro"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :diameter"
 :description "Misura il diametro di un cilindro, arco o cerchio. (Risultato -> Campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_diameter"
 :ui-behavior :relative)

("Perimeter of Face"
 :title       "Perimetro"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :perimeter"
 :description "Misura il perimetro di una faccia (Risultato -> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_perimeter"
 :ui-behavior :relative)

("Dist of Point to Edge"
 :title       "Distanza da Punto a Spigolo"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :point_edge"
 :description "Calcola la distanza minima tra un punto e uno spigolo. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_pnt_on_edge"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Dist of Point to Face"
 :title       "Distanza da Punto a Faccia"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :point_face"
 :description "Calcola la distanza minima tra un punto e una faccia. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_pnt_to_face"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Dist of Point to Curve"
 :title       "Distanza da Punto a Curva"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :point_curve"
 :description "Calcola la distanza minima tra un punto e una curva. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_point_curve"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Dist of Point to Surface"
 :title       "Distanza da Punto a Superficie"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :point_surface"
 :description "Calcola la distanza minima tra un punto e una superficie. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_point_surface"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Dist of Face to Face"
 :title       "Distanza tra Faccia e Faccia"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :face_face"
 :description "Calcola la distanza minima tra due facce. (Risultato-> campo dati uscita)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dist_point_face_face"
 :ui-behavior :relative)

("Dist of Surf to Surf"
 :title       "Distanza tra Superficie e Superficie"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :sf_sf"
 :description "Calcola la distanza minima tra due superfici. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_point_sf_sf"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Dist of Edge to Face"
 :title       "Distanza da Spigolo a Faccia"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :edge_face"
 :description "Calcola la distanza minima tra uno spigolo e una faccia. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_point_edge_face"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Dist of Edge to Surf"
 :title       "Distanza da Spigolo a Superficie"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :edge_sf"
 :description "Calcola la distanza minima tra uno spigolo e una superficie. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_point_edge_sf"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Dist of Edge to Edge"
 :title       "Distanza da Spigolo a Spigolo"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dist :edge_edge"
 :description "Calcola la distanza minima tra due spigoli. (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_dist_point_edge_edge"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Direction 3D"
 :title       "Direzione 3D"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d"
 :description "Apre il menu per il calcolo di direzioni 3D."
 :image       "SolidDesigner/Measure/meas_3d_dir"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Direction of Axis X"
 :title       "Direzione asse X"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :x"
 :description "Calcola la direzione dell'asse X nelle coordinate globali."
 :image       "SolidDesigner/Measure/meas_dir_x"
 :ui-behavior :relative)

("Direction of Axis Y"
 :title       "Direzione asse Y"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :y"
 :description "Calcola la direzione dell'asse Y nelle coordinate globali."
 :image       "SolidDesigner/Measure/meas_dir_y"
 :ui-behavior :relative)

("Direction of Axis Z"
 :title       "Direzione asse Z"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :z"
 :description "Calcola la direzione dell'asse Z nelle coordinate globali."
 :image       "SolidDesigner/Measure/meas_dir_z"
 :ui-behavior :relative)

("Direction of Axis U"
 :title       "Direzione asse U"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :u"
 :description "Calcola la direzione dell'asse U nelle coordinate locali del piano di lavoro."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dir_u"
 :ui-behavior :relative)

("Direction of Axis V"
 :title       "Direzione asse V"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :v"
 :description "Calcola la direzione dell'asse V nelle coordinate locali del piano di lavoro."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dir_v"
 :ui-behavior :relative)

("Direction of Axis W"
 :title       "Direzione asse W"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :w"
 :description "Calcola la direzione dell'asse W nelle coordinate locali del piano di lavoro."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dir_w"
 :ui-behavior :relative)

("Direction of View"
 :title       "Direzione Vista"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :vp_dir"
 :description "Calcola la direzione della vista in una finestra."
 :image       "SolidDesigner/Measure/meas_view_dir"
 :ui-behavior :relative)

("Direction of Face"
 :title       "Direzione Faccia"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :face_normal"
 :description "Calcola la direzione normale a una faccia."
 :image       "SolidDesigner/Measure/meas_face_dir"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Direction by 2 Points"
 :title       "Direzione per 2 Punti"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :two_pt"
 :description "Calcola la direzione 3D tra due punti."
 :image       "SolidDesigner/Measure/meas_dir_2pnts"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Direction of Edge Tangent"
 :title       "Direzione Tangente Spigolo"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :edge_tangent"
 :description "Calcola la direzione 3D di una tangente a uno spigolo."
 :image       "SolidDesigner/Measure/meas_dir_edge_tangent"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Direction of Surf Axis"
 :title       "Direzione Asse Superficie"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_dir_3d :surface_axis"
 :description "Calcola la direzione 3D di un cilindro, cono o toro."
 :image       "SolidDesigner/Measure/meas_dir_surf_axis"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Axis 3D"
 :title       "Asse 3D"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d"
 :description "Apre il menu per il calcolo degli assi 3D."
 :image       "SolidDesigner/Measure/meas_axis_3D"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Axis X"
 :title       "Asse X"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :x"
 :description "Visualizza l'origine dell'asse (origine del sistema di coordinate globale) e la direzione nei due insiemi di campi X,Y,Z."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_axis_x"
 :ui-behavior :relative)

("Axis Y"
 :title       "Asse Y"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :y"
 :description "Visualizza l'origine dell'asse (origine del sistema di coordinate globale) e la direzione nei due insiemi di campi X,Y,Z."
 :image       "SolidDesigner/Measure/meas_axis_y"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Axis Z"
 :title       "Asse Z"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :z"
 :description "Visualizza l'origine dell'asse (origine del sistema di coordinate globale) e la direzione nei due insiemi di campi X,Y,Z."
 :image       "SolidDesigner/Measure/meas_axis_z"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("xis U"
 :title       "Asse U"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :u"
 :description "Visualizza l'origine dell'asse (origine del piano di lavoro relativa al sistema di coordinate globali) e la direzione."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_axis_u"
 :ui-behavior :relative)

("Axis V"
 :title       "Asse V"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :v"
 :description "Visualizza l'origine dell'asse (origine del piano di lavoro relativa al sistema di coordinate globali) e la direzione."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_axis_v"
 :ui-behavior :relative)

("Axis W"
 :title       "Asse W"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :w"
 :description "Visualizza l'origine dell'asse (origine del piano di lavoro relativa al sistema di coordinate globali) e la direzione."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_axis_w"
 :ui-behavior :relative)

("Horiz Axis of Workplane"
 :title       "Asse Orizzontale del Piano di Lavoro"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :horiz"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura l'asse orizzontale di un piano di lavoro."
 :image       "SolidDesigner/Measure/meas_axis_horiz"
 :ui-behavior :relative)

("Vert Axis of Workplane"
 :title       "Asse Verticale del Piano di Lavoro"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :vert"
 :description "Misura l'asse verticale di un piano di lavoro."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_axis_vert"
 :ui-behavior :relative)

("Axis Face Normal"
 :title       "Asse Normale Faccia"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :face_normal"
 :description "Calcola la direzione normale a una faccia come un asse."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_axis_face_normal"
 :ui-behavior :relative)

("Axis by 2 Points"
 :title       "Asse per 2 Punti"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :two_pta"
 :description "Calcola l'asse tra due punti."
 :image       "SolidDesigner/Measure/meas_axis_2pnts"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Axis of Edge Tangen"
 :title       "Asse di Tangente a Spigolo"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :edge_tangent"
 :description "Calcola l'asse di una tangente a spigolo."
 :image       "SolidDesigner/Measure/meas_axis_edge_tangent"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Axis of Surface"
 :title       "Asse di Superficie"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_axis_3d :surface_axis"
 :description "Calcola l'asse di un cilindro, cono o toro."
 :image       "SolidDesigner/Measure/meas_surface_axis"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle"
 :title       "Angolo"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle"
 :description "Apre il menu per il calcolo degli Angoli."
 :image       "SolidDesigner/Measure/meas_angles"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle of Edge"
 :title       "Angolo tra spigoli"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :edge"
 :description "Misura l'angolo da uno spigolo."
 :image       "SolidDesigner/Measure/meas_ang_edges"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle of Face"
 :title       "Angolo tra Facce"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :face"
 :description "Misura un angolo da una faccia."
 :image       "SolidDesigner/Measure/meas_ang_faces"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle of Workplane"
 :title       "Angolo tra Piani di Lavoro"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :wp"
 :description "Misura un angolo da un piano di lavoro."
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_ang_wps"
 :ui-behavior :relative)

("Angle of Direction"
 :title       "Angolo tra Direzioni"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :dir"
 :description "Calcola un angolo da una direzione."
 :image       "SolidDesigner/Measure/meas_ang_dir"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle of Vp Direction"
 :title       "Angolo di Direzione FV"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :dir :vp_dir"
 :description "Misura un angolo da una direzione di finestra vista."
 :image       "SolidDesigner/Measure/meas_ang_dir_vp"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle of Face Normal"
 :title       "Angolo di normale a Faccia"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :dir :face_normal"
 :description "Misura l'angolo relativo alla direzione normale a una faccia."
 :image       "SolidDesigner/Measure/meas_ang_dir_face_normal"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle of Dir by 2 Points"
 :title       "Angolo a Direz per 2 Punti"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :dir :two_pt"
 :description "Misura l'angolo relativo alla direzione definita da due punti."
 :image       "SolidDesigner/Measure/meas_ang_dir_2pnts"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle of Dir of Edge Tangen"
 :title       "Angolo a Direz per Tangente Spigolo"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :dir :edge_tangent"
 :description "Misura l'angolo relativo a una tangente a spigolo."
 :image       "SolidDesigner/Measure/meas_ang_dir_edge_tangent"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Angle of Dir of Surface Axis"
 :title       "Angolo a Direz per Asse Superficie"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_angle :dir :surface_axis"
 :description "Misura l'angolo relativo a un cilindro, cono, toro o spline ruotata."
 :image       "SolidDesigner/Measure/meas_ang_dir_surface_axis"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative)

("Blend/Chamfer"
 :title       "Raccordo/Smusso"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" measure_blend_chamfer"
 :description "Calcola il raggio di un raccordo o distanza e angolo di uno smusso."
 :image       "SolidDesigner/Measure/meas_blend_chamfer"
 :ui-behavior :relative)

("Workplane Area Properties"
 :title       "Calcolo area Piano di Lavoro"
 :action      "area_props"
 :description "Calcola le propriet di area di un piano di lavoro"
 :ui-behavior :relative
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_wp_area_prop"
 :context-enable (agent::workplane-enable-context-menu-entry :with-profile))

("Part Mass Properties"
 :title       "Calcolo Parte"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" get_vol_prop :for_part"
 :description "Calcola le propriet di massa di una parte"
 :image       "SolidDesigner/Measure/meas_part_mass_prop"
 :enable      (not (anim::anim-play-command-is-active))
 :ui-behavior :relative
 :context-enable (not (agent::part-enable-context-menu-entry :face-part)))

("Part Volume"
 :title       "Volume Parte"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" uic_measure_part_volume"
 :description "Calcola il volume di una parte (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_part_vol")

("Part Area"
 :title       "Area Parte"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" uic_measure_part_area"
 :description "Calcola l'area di una parte (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_part_area")

("Face Mass Properties"
 :title       "Calcolo Faccia"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" get_vol_prop :for_face"
 :description "Calcola le propriet di massa di una faccia"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_face_mass_prop"
 :ui-behavior :relative)

("Face Area"
 :title       "Area Faccia"
 :action      "set_pers_context \"MEASURE-OUTPUT-CONTEXT\" uic_measure_face_area"
 :description "Calcola l'area di una faccia (Risultato-> campo dati uscita)"
 :image       "SolidDesigner/Measure/meas_face_area")

;; Calculator specific measure functions -> output into calculator

("Edge Length (Calc)"
 :title       "Lunghezza Spigolo (Calcolatrice)"
 :action      "uic_measure_edge_length"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura la lunghezza di uno spigolo (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_edge_length_calc")

("Distance by 2 Points (Calc)"
 :title       "Distanza tra due Punti (Calcolatrice)"
 :action      "uic_measure_dist_two_pts"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura la distanza tra due punti (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_dist_by_2pnts_calc")

("Distance of Point to Edge (Calc)"
 :title       "Distanza da Punto a Spigolo (Calcolatrice)"
 :action      "uic_measure_dist_pt_edge"
 :description "Misura la distanza minima tra un punto e uno spigolo (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dist_pnt_on_edge_calc")

("Distance of Point to Face (Calc)"
 :title       "Distanza da Punto a Faccia (Calcolatrice)"
 :action      "uic_measure_dist_pt_face"
 :description "Misura la distanza minima tra un punto e una faccia (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dist_pnt_to_face_calc")

("Distance Horizontal (Calc)"
 :title       "Distanza Orizzontale (Calcolatrice)"
 :action      "uic_measure_dist_horizontal"
 :description "Misura la distanza orizzontale tra due punti (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dist_horiz_calc")

("Distance Vertical (Calc)"
 :title       "Distanza Verticale (Calcolatrice)"
 :action      "uic_measure_dist_vertical"
 :description "Misura la distanza verticale tra due punti (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dist_vert_calc")

("Distance on Workplane (Calc)"
 :title       "Distanza su Piano di Lavoro (Calcolatrice)"
 :action      "uic_measure_dist_workplane"
 :description "Misura la distanza tra due punti proiettati sul PL attivo (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dist_on_wp_calc")

("Distance in Direction (Calc)"
 :title       "Distanza in Direzione (Calcolatrice)"
 :action      "uic_measure_dist_direction"
 :description "Misura la distanza tra due punti lungo una direzione definita dall'utente  (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_dist_in_dir_calc")

("Radius of Edge (Calc)"
 :title       "Raggio dello Spigolo (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_edge_radius" :radius)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il raggio degli spigoli circolari (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_edge_radius")

("Radius of Cylinder (Calc)"
 :title       "Raggio del Cilindro (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_cylinder_radius" :radius)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il raggio dei cilindri (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_cyl_radius")

("Radius of Sphere (Calc)"
 :title       "Raggio della Sfera (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_sphere_radius" :radius)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il raggio delle sfere (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_sphere_radius")

("Radius of Torus (Major) (Calc)"
 :title       "Raggio del Toro (Maggiore) (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_torus_major" :radius)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il raggio maggiore dei tori (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_torus_major_radius")

("Radius of Torus (Minor) (Calc)"
 :title       "Raggio del Toro (Minore) (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_torus_minor" :radius)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il raggio minore dei tori (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_torus_minor_radius")

("Diameter of Edge (Calc)"
 :title       "Diametro di Spigolo (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_edge_radius" :diameter)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il diametro di spigoli circolari (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_edge_diameter")

("Diameter of Cylinder (Calc)"
 :title       "Diametro di Cilindro (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_cylinder_radius" :diameter)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il diametro di cilindri (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_cyl_diameter")

("Diameter of Sphere (Calc)"
 :title       "Diametro di Sfera (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_sphere_radius" :diameter)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il diametro di sfere (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_sphere_diameter")

("Diameter of Torus (Major) (Calc)"
 :title       "Diametro di Tori (Maggiore) (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_torus_major" :diameter)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il diametro maggiore dei tori (Risultato->Calcolatrice)"
 :image       "SolidDesigner/Measure/meas_torus_major_diameter")

("Diameter of Torus (Minor) (Calc)"
 :title       "Diametro di Tori (Minore) (Calcolatrice)"
 :action      (ui::uic-measure-radius-cmd "uic_measure_torus_minor" :diameter)
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il diametro minore dei tori (Risultato->Calcolatrice)"
 :image       "SolidDesigner/Measure/meas_torus_minor_diameter")

("Angle between Edges (Calc)"
 :title       "Angolo tra spigoli (Calcolatrice)"
 :action      "uic_measure_angle_edges"
 :description "Misura l'angolo tra spigoli (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_ang_edges_calc")

("Angle between Faces (Calc)"
 :title       "Angolo tra Facce (Calcolatrice)"
 :action      "uic_measure_angle_faces"
 :description "Misura l'angolo tra facce (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_ang_faces_calc")

("Angle between Workplanes (Calc)"
 :title       "Angolo tra Piani di Lavoro (Calcolatrice)"
 :action      "uic_measure_angle_workplanes"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura l'angolo tra Piani di Lavoro (risultato -> calcolatrice) "
 :image       "SolidDesigner/Measure/meas_ang_wps_calc")

("3D Direction (Calc)"
 :title       "Direzione 3D (Calcolatrice)"
 :action      "uic_measure_3d_direction"
 :description "Misura una direzione 3D (risultato -> calcolatrice) "
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_3d_dir_calc")

("3D Point (Calc)"
 :title       "Punto 3D (Calcolatrice)"
 :action      "uic_measure_3d_point"
 :description "Misura un punto 3D (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_3d_pnt_calc")

("3D Vector (Calc)"
 :title       "Vettore 3D (Calcolatrice)"
 :action      "uic_measure_3d_vector"
 :description "Misura un vettore 3D (risultato -> calcolatrice)"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_3d_vec_calc")

("Part Volume (Calc)"
 :title       "Volume Parte (Calcolatrice)"
 :action      "uic_measure_part_volume"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura il volume di una parte (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_part_vol_calc")

("Part Area (Calc)"
 :title       "Area Parte (Calcolatrice)"
 :action      "uic_measure_part_area"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura l'area di una parte (risultato -> calcolatrice)"
 :image       "SolidDesigner/Measure/meas_part_area_calc")

("Face Area (Calc)"
 :title       "Area Faccia (Calcolatrice)"
 :action      "uic_measure_face_area"
 :enable      (not (anim::anim-play-command-is-active))
 :description "Misura l'area di una faccia (risultato -> calcolatrice) "
 :image       "SolidDesigner/Measure/meas_face_area_calc")

("Calculator"
 :title       "Calcolatrice"
 :action      (raise-mini-calc)
 :description "Mostra la calcolatrice"
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/calculator")

("Calculator Context Menu"
 :title       "Calcolatrice"
 :enable      (not (anim::anim-play-command-is-active))
 :action      (win-raise-calc-from-data)
 :description "Mostra la calcolatrice"
 :image       "SolidDesigner/Measure/calculator")

("Generic Distance"
 :title       "Distanza tra 2 elementi"
 :action      "measure_distance_simple"
 :description "Misura Distanza"
 :ui-behavior :on-request
 :enable      (not (anim::anim-play-command-is-active))
 :image       "SolidDesigner/Measure/meas_distance")

("Clipped Cross Section"
 :title       "Definisci Sezione Trasversale"
 :action      "xsection_clip"
 :description "Abilita piano di clipping e di posizione"
 :ui-behavior :default
 :image       "SolidDesigner/View/clipping")

("Create Cross Section"
 :title       "Abilita Sezione Trasversale Esatta"
 :action      "xsection_create"
 :enable      elan-ui::*xsection-defined*
 :description "Crea un'esatta sezione trasversale"
 :ui-behavior :default
 :image       "SolidDesigner/Create_2d/cross_section")

("Insert Measure Result"
 :title       "Inserisci risultato misurazione"
 :action      (oli::sd-put-buffer (elan::prim-get-measure-result-value))
 :description "Copia l'ultimo risultato misurato nel campo d'inserimento attuale"
 :ui-behavior :none)

;;----- SolidDesigner: Settings -----------------------------------------------

(:Group "Settings" :title "Impostazioni")

("2D Edge Properties"
 :title       "Propriet spigoli 2D ..."
 :action      "edge_2d_prop"
 :description "Visualizza le propriet degli spigoli 2D"
 :ui-behavior :relative
 :context-enable (agent::property-enable-context-menu-entry :edge-2d))

("Edge Properties"
 :title       "Propriet Spigolo ..."
 :action      "edge_3d_prop"
 :description "Mostra le propriet dello spigolo"
 :ui-behavior :relative
 :image       "SolidDesigner/Settings/edge3d_properties"
 :context-enable (agent::property-enable-context-menu-entry :edge)
 )

("Face Properties"
 :title       "Propriet Faccia ..."
 :action      "face_prop"
 :description "Mostra le propriet della faccia preselezionata"
 :ui-behavior :relative
 :image       "SolidDesigner/Settings/face_properties"
 :context-enable (agent::property-enable-context-menu-entry :face))

("Color Selector"
 :title       "Selettore di Colore"
 :action      "edit_color_selector"
 :description "Mostra il selettore dei colori. E' possibile modificare i colori o la tavolozza."
 :ui-behavior :relative)

("Refine Face"
 :title       "Rifinisci Faccia"
 :action      "refine_face"
 :description "Rifinisce le faccette su una faccia"
; :image       "SolidDesigner/Settings/refine_face"
 :ui-behavior :relative)

("Refine Part"
 :title       "Rifinisci Parte"
 :action      "refine_part"
 :description "Rifinisce le faccette su una parte"
; :image       "SolidDesigner/Settings/refine_part"
 :ui-behavior :relative)

("Workplane Settings"
 :title       "Impostazioni Piano di Lavoro"
 :action      (elan-ui::show-dialog-default-wp-settings)
 :description "Imposta e modifica l'aspetto dei piani di lavoro"
 :image       "SolidDesigner/Workplane/wp_settings"
 )

("Workplane Properties"
 :title       "Propriet Piano di Lavoro"
 :action      "wp_prop"
 :description "Mostra le propriet del piano di lavoro"
 :ui-behavior :relative
 :context-enable (agent::property-enable-context-menu-entry :wp))

("Part Settings"
 :title       "Impostazioni Parte"
 :action      (elan-ui::show-dialog-default-part-settings )
 :description "Imposta e modifica l'aspetto delle parti."
 :image       "SolidDesigner/Settings/part_settings"
 )

("Part Properties"
 :title       "Propriet Parte ..."
 :action      "part_prop"
 :description "Imposta le propriet della parte preselezionata."
 :ui-behavior :relative
 :context-enable (agent::property-enable-context-menu-entry :part))

("Assembly Properties"
 :title       "Propriet gruppo ..."
 :action      "assembly_prop"
 :description "Imposta le propriet del gruppo preselezionato."
 :ui-behavior :relative
 :context-enable (agent::property-enable-context-menu-entry :assembly))

("Coord Sys Settings"
 :title       "Impostazioni Sist. Coord."
 :action      (elan-ui::show-dialog-default-coord-sys-settings)
 :description "Imposta e modifica l'aspetto dei sistemi di coordinate prestabiliti."
 :image       "SolidDesigner/Part_Assy/coord_sys_settings"
 )

("Coord Sys Settings (Selected)"
 :title       "Propriet sist. coord."
 :action      "change_coordinate_system_properties"
 :description "Imposta e modifica l'aspetto dei sistemi di coordinate selezionati."
; :image       "SolidDesigner/Settings/coord_sys_settings"
 :ui-behavior :relative
 )

("Machining Settings"
 :title       "Impostazioni Lavorazioni"
 :action      (elan::show-dialog-machining-settings)
 :description "Mostra il menu Impostazioni Lavorazioni"
 :image       "SolidDesigner/Machine/machine_settings"
 )

("Modify 3d Settings"
 :title       "Modifica Impostazioni 3D"
 :action      (k2-ui::show-modify-3d-ui)
 :description "Imposta e modifica le impostazioni 3D"
 :image       "SolidDesigner/Modify_3D/modify_3d_settings"
 )

("Surfacing Settings"
 :title       "Impostazioni curva 3D e di superficie"
 :action      "curve_settings"
 :image       "SolidDesigner/Surfacing/SUR_Settings"
 :description "Modifica le impostazioni per la creazione delle curve 3D e per la modifica della superficie.")

("Annotation 3D Settings"
 :title       "Impostazioni annotazioni 3D"
 :action      "doc3d_change_anno_settings :DEFAULT"
 :image       "3D_Documentation/3d_anno_settings"
 :description "Imposta e modifica l'aspetto delle annotazioni 3D predefinite.")

("Annotation 3D Settings (Selected)"
 :title       "Propriet annotazioni 3D"
 :action      "doc3d_change_anno_settings :SELECTED"
; :image       "SolidDesigner/Settings/3d_anno_settings"
 :description "Imposta e modifica l'aspetto delle annotazioni 3D")

("Initial System Settings"
 :title       "Impostazioni iniziali di sistema"
 :action      (frame2-ui::initial-system-settings-ui)
 :description "Imposta e modifica le impostazioni iniziali del sistema, p. es. unit"
; :image       "SolidDesigner/Settings/system_settings"
 :sd-access   :no)

("3D CoPilot Settings"
 :title       "Impostazioni CoPilota 3D"
 :action      (nx::show-3d-copilot-switches)
 :description "Mostra il menu impostazioni del CoPilota 3D."
 :sd-access   :yes)

("Registered Settings"
 :title       "Impostazioni registrate"
 :sysCmdId    54000
 :description "Verr sostituito in fase di esecuzione con le impostazioni registrate"
 :sd-access   :yes)

;;----- SolidDesigner: Miscellaneous ------------------------------------------

(:Group "Miscellaneous" :title "Varie")

("Search"
 :title       "Ricerca"
 :action      (g-browser::show-search-and-filter-ui "parcel-gbrowser")
 :description "Ricerca un modello specifico"
 :sd-access   :yes)

("Undo One"
 :title       "Annulla 1 passo"
 :action      "cancel_all undo :next complete"
 :description "Annulla una operazione di modellazione"
 :image       "SolidDesigner/Miscellaneous/undo_one"
 :enable      elan-ui::*undo-one-enabled*
 :sd-access   :yes)

("Redo One"
 :title       "Rifai un passo"
 :action      "cancel_all undo :forward :num_steps 1 complete"
 :description "Ripete una operazione di modellazione"
 :image       "SolidDesigner/Miscellaneous/redo_one"
 :enable      elan-ui::*redo-one-enabled*
 :sd-access   :yes)

("Undo / Redo"
 :title       "Annulla / Rifai"  ;; Edit Menu
 :action      "cancel_all undo"
 :description "Annulla o ripete operazioni di modellazione")

("Memory Usage"
 :title       "Utilizzo Memoria"
 :action      (ui::uic-show-memory-usage)
 :description "Mostra la memoria attualmente utilizzata, disponibile e limite"
 :image       "SolidDesigner/Miscellaneous/memory_usage"
)

("Translate 2 Points"
 :title       "Sposta per 2 Punti"
 :action      ":call-translation"
 :description "Specifica le opzioni di spostamento per 2 punti."
 :ui-behavior :none
)

("Translate Dir Len"
 :title       "Sposta per Direzione e Lunghezza"
 :action      ":call-translation :dir-len :on"
 :description "Specifica le opzioni di spostamento per direzione e lunghezza."
 :ui-behavior :none
)

("Rotate"
 :title       "Ruota"
 :action      ":call-rotation"
 :description "Specifica le opzioni di posizionamento per rotazione."
 :ui-behavior :none
)

("Pt Pt Pt"
 :title       "Abbina Punti"
 :action      ":call-point-point-point"
 :description "Specifica le opzioni di posizionamento abbinando tre punti."
 :ui-behavior :none
)

("Pt Dir Pt"
 :title       "Punto Direz Punto"
 :action      ":call-point-dir-point"
 :description "Specificare opzione di posizionamento punto direzione punto."
 :ui-behavior :none
)

;;----- SolidDesigner: Database -----------------------------------------------

(:Group "Database" :title "Database"
	:all-in-sd-access :yes)

("Database Commands"
 :title       "Comandi database"
 :sysCmdId    50194
 :description "Sar sostituito all'esecuzione con comandi database")

("Open Editor"
 :title       "Apri Editor"
 :action      "db-aip-ui::db_editor"
 :description "Porta in primo piano l'editor di database"
 :enable      elan-ui::*database-enabled*
 :image "SolidDesigner/ModelManager/workspace"
 :ui-behavior :relative)
 
("Info Part"
 :title       "Info Parte"
 :action      "db-aip-ui::db_info_part"
 :description "Selezionare parte/gruppo su cui ottenere informazioni."
 :enable      elan-ui::*database-enabled*
 :image       "SolidDesigner/Help/cocreate_on_the_web"
 :ui-behavior :relative)

("Reload"
 :title       "Ricarica"
 :action      "db-aip-ui::db_reload"
 :description "Ricarica dati 3D dal database"
 :enable      elan-ui::*database-enabled*
 :image "SolidDesigner/ModelManager/reload"
 :ui-behavior :relative)

("Store Package"
 :title       "Salva fascicolo"
 :action      "db-aip-ui:start_package"
 :description "Salva un fascicolo nel database"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative
 :image "SolidDesigner/ModelManager/save-pkg")

("Store VRML"
 :title       "Salva VRML"
 :action      "vrml:vrml-out :destination :none :select"
 :description "Salva VRML nel database"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative)

("Store IGES"
 :title       "Salva IGES"
 :action      "(db-aip-ui::start-native-cad-out-iges)"
 :description "Salva IGES nel database"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative)

("Store STEP"
 :title       "Salva STEP"
 :action      "(db-aip-ui::start-step)"
 :description "Salva STEP nel database"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative)

("Store ACIS(SAT)"
 :title       "Salva ACIS (SAT)"
 :action      "(db-aip-ui::start-native-cad-out-sat)"
 :description "Salva ACIS (SAT) nel database"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative)

("Store STL"
 :title       "Salva STL"
 :action      "db-aip-ui:start_stl"
 :description "Salva STL nel database"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative)

("Assign"
 :title       "Assegna"
 :action      "db-aip-ui:db_assign"
 :description "Assegna Datioriginali a una parte"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative)

("Reserve"
 :title       "Riserva"
 :action      "db-aip-ui::db_reserve_part"
 :description "Riserva una parte o gruppo"
 :enable      elan-ui::*database-enabled*
 :image "SolidDesigner/ModelManager/reserve"
 :ui-behavior :relative)

("Set Modify"
 :title       "Imposta Modifica"
 :action      "db-aip-ui::db_modify_part"
 :description "Imposta una parte o gruppo modificabile"
 :enable      elan-ui::*database-enabled*
 :image "SolidDesigner/ModelManager/allow_edit"
 :ui-behavior :relative)

("Unreserve"
 :title       "Annulla Riserva"
 :action      "db-aip-ui::db_unreserve_part"
 :description "Annulla la riserva di una parte o gruppo"
 :enable      elan-ui::*database-enabled*
 :image "SolidDesigner/ModelManager/unreserve"
 :ui-behavior :relative)

("Open BOM"
 :title       "Apri DB"
 :action      "db-aip-ui:db_open_bom"
 :description "Apre l'editor DB per un oggetto selezionato"
 :enable      (and elan-ui::*database-enabled* db-aip-ui::*wmsd-bom-active*)
 :ui-behavior :relative
 :sd-access   :no)

("Scan BOM"
 :title       "Esamina DB"
 :action      "db-aip-ui::db_scan"
 :description "Esamina la struttura DB per un oggetto selezionato"
 :enable      (and elan-ui::*database-enabled* db-aip-ui::*wmsd-bom-active*)
 :ui-behavior :relative
 :sd-access   :no)

("Load 3D Data (DesignManagement)"
 :title       "Carica dati 3D"
 :action      "(db-aip-ui::ddm_load)"
 :description "Carica dati 3D dal database"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative)

("Save 3D Data (DesignManagement)"
  :title       "Salva Dati 3D"
 :action      "(db-aip-ui::ddm_store)"
 :description  "Salva dati 3D nel database utilizzando un normale metodo di memorizzazione"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative
 :image "SolidDesigner/ModelManager/save")

("Save 3D Data Mod (DesignManagement)"
 :title       "Salva Modifiche 3D"
 :action      "(db-aip-ui::smod-check-wm-stor-mod)"
 :description "Salva dati 3D nel database utilizzando un metodo di modifica della memorizzazione"
 :enable      elan-ui::*database-enabled*
 :ui-behavior :relative
 :image "SolidDesigner/ModelManager/save")

;; --- Model Manager Functions ----------------------------------------------

(:Group "ModelManager" :title "Model Manager" ;; not localised
	:all-in-sd-access :yes)

("MM WorkSpace"
	:title "Spazio di lav."
	:action "(MODELMANAGER::MM-SEND-CMD \"SHOW-MANAGER\")"
	:description "Apre la finestra Spazio di lavoro di Model Manager"
	:enable (and (functionp 'modelmanager::is-connected)  
                 (modelmanager::is-connected))
	:image "SolidDesigner/ModelManager/workspace"
)

("MM Add Thumbnail"
	:title "Agg. Miniat."
	:action "ndm_thumbnail"
	:description "Aggiunge una miniatura"
    :enable (and (functionp 'modelmanager::is-connected)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_ADD_THUMBNAIL))	
    :ui-behavior :relative
	:image "SolidDesigner/ModelManager/thumbnail"
)

("MM View Details"
	:title "Propriet DB"
	:action "ndm_showeditor"
	:description "Mostra le propriet del database per una parte selezionata"
	:enable (and (functionp 'modelmanager::is-connected)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_AM_OPENEDITOR))	
    :ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM Save"
	:title "Salva"
	:action "ndm_store"
	:description "Salva una parte o gruppo nel database"
	:enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_store)   
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_SAVE))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/save"
)

("MM Save PKG"
	:title "Salva PKG"
	:action "ndm_store_pkg"
	:description "Salva una parte/un gruppo nel database in formato file pkg "
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_store_pkg)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_SAVE_PKG))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/save-pkg"
)

("MM Reload"
	:title "Ricarica"
	:action "ndm_reload"
	:description "Ricarica una parte o gruppo dal database"
	:enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_reload)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_RELOAD))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/reload"
)

("MM Reload Lightweight"
	:title "Ricarica completamente"
	:action "ndm_reload_lightweight_models"
	:description "Chiama il ricarimento dal comando di database per i modelli leggeri preselezionati. "
	:enable (and (functionp 'modelmanager::is-connected)
		  (functionp 'modelmanager::ndm_reload_lightweight_models)
		  (modelmanager::is-connected)
		  (modelmanager::mm-is-cmd-activ :MM_RELOAD))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/reload"
)

("MM Change Load Type Partial"
	:title "su parziale"
	:action "ndm_change_load_type_partial"
	:description "Modifica una parte in modo che sia caricata parzialmente"
	:enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_change_load_type_partial)
                     (modelmanager::is-connected)
                     (modelmanager::mm-is-cmd-activ :MM_CHANGE_LOAD_TYPE))
	:ui-behavior :relative
)

("MM Change Load Type Lightweight"
	:title "su leggero"
	:action "ndm_change_load_type_lightweight"
	:description "Modifica una parte per eseguirne il caricamento leggero "
	:enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_change_load_type_lightweight)  
                     (modelmanager::is-connected)
                     (modelmanager::mm-is-cmd-activ :MM_CHANGE_LOAD_TYPE))	
	:ui-behavior :relative
)

("MM Change Load Type Full"
	:title "su completo"
	:action "ndm_change_load_type_full"
	:description "Modifica una parte per eseguirne il caricamento completo"
	:enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_change_load_type_full)  
                     (modelmanager::is-connected)
                     (modelmanager::mm-is-cmd-activ :MM_CHANGE_LOAD_TYPE))	
	:ui-behavior :relative
)

("MM Merge"
	:title "Aggiorna"
	:action "ndm_merge"
	:description "Aggiorna una parte o un gruppo dal database"
        :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_merge)  
                     (modelmanager::is-connected)
                     (modelmanager::mm-is-cmd-activ :MM_UPDATE))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/reload"
)

("MM Refresh Status"
	:title "Agg. Stato"
	:action "ndm_refresh_status"
	:description "Aggiorna lo stato nell'elenco delle strutture"
        :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_refresh_status)  
                     (modelmanager::is-connected)
                     (modelmanager::mm-is-cmd-activ :MM_REFRESH_STATUS))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/refresh"
)

("MM Refresh All"
	:title "Aggiorna stato tutto"
	:action "ndm_refresh_status :ALL_ITEMS t"
	:description "Aggiorna lo stato nell'elenco delle strutture"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_refresh_status)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_REFRESH_STATUS))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/refresh"
)

("MM Sync Library Elements"
	:title "Sinc. elementi di libreria"
	:action "ndm_sync_library_parts"
	:description "Sincronizza gli elementi della libreria con il database"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_sync_library_parts)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_SYNC_LIBRARY_PARTS))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/syncLib"
)

("MM Reserve"
	:title "Riserva"
	:action "ndm_reserve"
	:description "Riserva una parte o un gruppo specifico"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_reserve)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_RESERVE))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/reserve"
)

("MM Unreserve"
	:title "Annulla Riserva"
	:action "ndm_unreserve"
	:description "Annulla la riserva di una parte o gruppo specifico"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_unreserve)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_UNRESERVE))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/unreserve"
)

("MM Allow Edit"
	:title "Permetti Mod."
	:action "ndm_allow_edit"
	:description "Rimuove l'indicatore di sola lettura, se consentito"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_allow_edit)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_ALLOW_EDIT))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/allow_edit"
)

("MM Save LoadConfiguration"
	:title "Salva Snapshot"
	:action (ModelManager::ndm_saveconfig_root_fnc)
	:description "Salva una visualizzazione dei dati"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_saveconfig_root_fnc)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_SAVE_SNAPSHOT))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/save_view"
)

("MM Compare"
	:title "Confronta i modelli locali e database giustapposti "
	:action "ndm_compare"
	:description "Confronta con una versione memorizzata nel database"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_compare)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_COMPARE))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_compare"
)

("MM Properties Newest Version"
	:title "Visualizza propriet del modello database"
	:action "ndm_show_properties_of_newest_version"
	:description "Mostra le propriet del database per la versione pi recente della parte selezionata"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_show_properties_of_newest_version)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_CR_SHOW_PROPERTIES_OF_NEWEST_VERSION)
                 modelmanager::*mm-any-conflict*)	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_viewdetails_nv"
)

("MM Assign New ID"
	:title "Assegna nuova ID di sistema al modello locale"
	:action "ndm_assign_new_sysid"
	:description "Assegna nuova ID di sistema al modello locale"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_assign_new_sysid)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_ASSIGN_NEW_SYSID))	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_assign_new_id"
)

("MM Overwrite DB"
	:title "Sostituisci il modello database con il modello locale (Sovrascrivi database o Nuova versione)"
	:action "ndm_overwrite-db"
	:description "Sostituisci il modello database con il modello locale (Sovrascrivi database o Nuova versione)"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_overwrite-db)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_CR_OVERWRITE_DB)
                 modelmanager::*mm-any-conflict*)	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_overwrite_db"
)

("MM Replace by Newest Version"
	:title "Sostituisci il modello locale con il modello database"
	:action "ndm_replace_by_newest_version"
	:description "Sostituisce il modello locale con il modello database"
    :enable (and (functionp 'modelmanager::is-connected)
	             (functionp 'modelmanager::ndm_replace_by_newest_version)  
                 (modelmanager::is-connected)
                 (modelmanager::mm-is-cmd-activ :MM_CR_REPLACE_BY_NEWEST_VERSION)
                 modelmanager::*mm-any-conflict*)	
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_replace_by_newest_version"
)

("MM Refresh Compare VPs"
	:title "Aggiorna FV di confronto"
	:action "cr_refresh_compare_vps"
	:description "Aggiorna FV di confronto"
	:enable (and (functionp 'modelmanager::cr_refresh_compare_vps) 
	             (modelmanager::is-connected) 
	             (modelmanager::db-compare-viewports-visible)
	             (modelmanager::mm-is-cmd-activ :MM_CR_REFRESH_COMPARE_VPS))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_refresh_compare_vps"
)

("MM Close Compare VPs"
	:title "Chiudi FV di confronto"
	:action "cr_close_compare_vps"
	:description "Chiude FV di confronto"
	:enable (and (functionp 'modelmanager::cr_close_compare_vps) 
	             (modelmanager::is-connected) 
	             (modelmanager::db-compare-viewports-visible)
	             (modelmanager::mm-is-cmd-activ :MM_CR_CLOSE_COMPARE_VPS))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_close_compare_vps"
)

("MM Replace by compare model"
	:title "Sostituisci Modello con Confronta modello"
	:action "cr_replace_by_compare_model"
	:description "Sostituisce Modello con Confronta modello"
	:enable (and (functionp 'modelmanager::cr_replace_by_compare_model) 
	             (modelmanager::is-connected)
	             (modelmanager::mm-is-cmd-activ :MM_CR_REPLACE_BY_COMPARE_MODEL)
	             )
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_replace_by_compare_model"
)

("MM Close Compare VPs after resolve"
	:title "Chiudi FV di confronto a risultato ottenuto"
	:action "cr_close_VP_at_resolve_switch"
	:description "Chiude le finestre di confronto a risultato ottenuto"
	:enable (and (functionp 'modelmanager::cr_close_VP_at_resolve_switch)
	             (modelmanager::is-connected)
	             (modelmanager::mm-is-cmd-activ :MM_CR_CLOSE_VP_AT_RESOLVE_SWITCH)
	             )
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/MM_close_VP_at_resolve_switch"
)

("MM View Details Structure"
	:title "Struttura"
	:action "ndm_showeditor :tab-name \"STRUCTURE\""
	:description "Mostra la struttura dei modelli database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor) 
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Attributes"
	:title "Attributi"
	:action "ndm_showeditor"
	:description "Mostra gli attributi dei modelli database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor) 
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Where Used"
	:title "Se usati"
	:action "ndm_showeditor :tab-name \"WHEREUSED\""
	:description "Mostra i modelli database se questi sono usati per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Notes"
	:title "Note"
	:action "ndm_showeditor :tab-name \"NOTES\""
	:description "Mostra le note dei modelli database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Revision History"
	:title "Cronologia di revisione"
	:action "ndm_showeditor :tab-name \"REVISION_HISTORY\""
	:description "Mostra la cronologia di revisione dei modelli database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor) 
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Masterdata"
	:title "Dati originali"
	:action "ndm_showeditor :tab-name \"MASTERDATA\""
	:description "Mostra i dati originali dei modelli database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Drawing Status"
	:title "Stato disegno"
	:action "ndm_showeditor :tab-name \"2D3DLINKS-2D\""
	:description "Mostra lo stato dei disegni dei modelli database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Simplification"
	:title "Semplificazione"
	:action "ndm_showeditor :tab-name \"SIMPLIFICATION\""
	:description "Mostra le semplificazioni dei modelli database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Files"
	:title "File"
	:action "ndm_showeditor :tab-name \"FILES\""
	:description "Mostra i file dei modelli di database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Part Structure"
	:title "Struttura"
	:action "ndm_showeditor_part :tab-name \"STRUCTURE\""
	:description "Mostra la struttura dei dati originali del database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR_PART))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Part"
	:title "Attributi"
	:action "ndm_showeditor_part"
	:description "Mostra gli attributi dei dati originali del database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR_PART))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Part Where Used"
	:title "Se usati"
	:action "ndm_showeditor_part :tab-name \"WHEREUSED\""
	:description "Mostra i dati originali del database se questi sono usati per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR_PART))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Part Bom Versions"
	:title "Versioni DB"
	:action "ndm_showeditor_part :tab-name \"BOM_VERSIONS\""
	:description "Mostra le versioni DB dei dati originali del database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR_PART))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Part Notes"
	:title "Note"
	:action "ndm_showeditor_part :tab-name \"NOTES\""
	:description "Mostra le note dei dati originali del database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR_PART))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM View Details Part Revision History"
	:title "Cronologia di revisione"
	:action "ndm_showeditor_part :tab-name \"REVISION_HISTORY\""
	:description "Mostra la cronologia di revisione dei dati originali del database per una parte selezionata"
	:enable (and (functionp 'modelmanager::ndm_showeditor)  
	             (modelmanager::is-connected)
   	             (modelmanager::mm-is-cmd-activ :MM_SHOWEDITOR_PART))
	:ui-behavior :relative
	:image "SolidDesigner/ModelManager/viewdetails"
)

("MM Structure Compare"
        :title       "Confronto struttura"
        :action      "ndm_structure_compare"
        :description "Confronta una struttura di Modeling rispetto al database"
        :enable (and (functionp 'modelmanager::ndm_structure_compare)  
	                 (modelmanager::is-connected)
   	                 (modelmanager::mm-is-cmd-activ :MM_STRUCTURE_COMPARE))
        :ui-behavior :relative
)

("MM Save eDrawing"
        :title       "Salva file eDrawings"
        :action      "ndm_save_edrawing_3d"
        :description "Salva un file eDrawings in Model Manager"
        :enable (and (functionp 'modelmanager::ndm_save_edrawing_3d) 
                     (modelmanager::is-connected) 
                     (modelmanager::mm-is-cmd-activ :MM_SAVE_EDRAWING_3D)
                      modelmanager::enable-edrawing-support)
        :image "eDrawings/eDPublish"
        :ui-behavior :relative
)

("MM Save XVL"
        :title       "Salva XVL"
        :action      "ndm_save_xvl"
        :description "Salva un file XVL in Model Manager"
        :enable (and (functionp 'modelmanager::ndm_save_xvl)
                     (modelmanager::is-connected) 
                      modelmanager::enable-xvl-support
                     (modelmanager::mm-is-cmd-activ :MM_SAVE_XVL))
        :ui-behavior :relative
)

("MM Add Lightweight"
        :title       "Aggiungi leggero"
        :action      "ndm_save_graphics"
        :description "Aggiunge un file leggero in Model Manager "
        :enable (and (functionp 'modelmanager::ndm_save_graphics) 
                     (modelmanager::is-connected)
                     (modelmanager::mm-is-cmd-activ :MM_SAVE_LIGHTWEIGHT))
        :ui-behavior :relative
)

;;----- SolidDesigner: Versioning ------------------------------------------

(:Group "Versioning" :title "Avvia Meeting")

("Make Version"
 :title       "Concludi Meeting"
 :action      "make_version_lav"
 :image       "SolidDesigner/Versioning/VERS_makeVers"
 :description "Converte il modello originale in una versione"
 :ui-behavior :relative)

("Make Original"
 :title       "Crea Originale"
 :action      "make_original_lav"
 :image       "SolidDesigner/Versioning/VERS_makeOrig"
 :description "Converte una versione in un modello originale"
 :ui-behavior :relative)

("Replace ByVersion"
 :title       "Sostituisci con Versione"
 :action      "substitute_lav"
 :image       "SolidDesigner/Versioning/VERS_ReplaceByVers"
 :description "Sostituisce il modello originale con una versione"
 :ui-behavior :relative)

("Highlight Original"
 :title       "Evidenzia Originale"
 :action      "lav_hl_original"
 :image       "SolidDesigner/Versioning/Vers_HiLiOrig"
 :description "Evidenzia l'originale per una versione selezionata"
 :ui-behavior :relative)

("Highlight Version"
 :title       "Evidenzia Versione"
 :action      "lav_hl_version"
 :image       "SolidDesigner/Versioning/Vers_HiliVers"
 :description "Evidenzia la versione per un modello selezionato"
 :ui-behavior :relative)

;;----- SolidDesigner: 3D Documentation (3D Access only!) ---------------------

(:Group "3D Documentation" :title "Documentazione 3D"
	:sd-access-only :yes)

("Show Docuplane"
 :title       "Mostra PianoDocumento"
 :action      "doc3d_show_docuplane"
 :ui-behavior :relative)

("Show Group"
 :title       "Mostra Gruppo"
 :action      "doc3d_show_docu_group"
 :ui-behavior :relative)

("Show Annotation"
 :title       "Mostra Annotazione"
 :action      "doc3d_show_anno"
 :ui-behavior :relative)

;;----- SolidDesigner: Inspection (3D Access only!) ---------------------------

(:Group "Inspection" :title "Ispezione"
	:sd-access-only :yes)

("Navigate Measurement Plan"
 :title       "Navigaz. Piano di Mis."
 :action      "navigate_measurement_plan :nav_mode :navigate"
 :enable      (frame2::module-active-p "INSPECTION")
 :ui-behavior :relative)

("Evaluate Measurements"
 :title       "Valutazione Misure"
 :action      "evaluate_measurements"
 :enable      (frame2::module-active-p "INSPECTION")
 :ui-behavior :relative)

;;-------------------------------------------------------
(:Group "Configuration" :title "Configurazione")

("Activate Configuration"
 :title       "Attiva configurazione"
 :action      "cfn_activate_configuration"
 :description "Attivazione di una configurazione"
 :sd-access :yes
 :image       "SolidDesigner/Configuration/ActivateConfiguration"
 :ui-behavior :relative)
 
 ("Deactivate Configuration"
 :title          "Disattiva configurazione"
 :action         "(cfn_activate_configuration :deactivate)"
 :description    "Disattivazione di una configurazione"
 :context-is-visible (cfn::cfn-get-active-configuration)
 :enable         (cfn::cfn-get-active-configuration)
 :image       "SolidDesigner/Configuration/DeactivateConfiguration"
 :sd-access :yes
 :ui-behavior    :relative)

("Create Configuration"
 :title       "Crea configurazione"
 :action      "cfn_create_configuration"
 :description "Creazione di una configurazione"
 :image       "SolidDesigner/Configuration/CreateConfiguration"
 :ui-behavior :relative)

("Delete Configuration"
 :title       "Elimina configurazione"
 :action      "cfn_delete_configuration"
 :description "Eliminazione di una configurazione"
 :image       "SolidDesigner/Configuration/DeleteConfiguration"
 :ui-behavior :relative)

("Capture Camera Drawlist"
 :title       "Cattura nella configurazione"
 :action      "cfn_capture"
 :description "Cattura l'obiettivo + gli elementi a video in una configurazione"
 :image       "SolidDesigner/Configuration/CaptureCameraDrawlist"
 :sd-access   :yes
 :ui-behavior :relative)

("Capture Camera And Drawlist In Active Configuration"
 :title       "Cattura obiettivo + elementi a video"
 :action      "(cfn_capture :consider_camera :on :consider_drawlist :on)"
 :description "Cattura l'obiettivo + gli elementi a video nella configurazione attiva"
 :context-is-visible (cfn::cfn-configuration-is-modifiable 
                   (cfn::cfn-get-active-configuration))
 :enable         (AND (oli::sd-inq-current-vp)
                      (cfn::cfn-configuration-is-modifiable 
                        (cfn::cfn-get-active-configuration)))
 :image       "SolidDesigner/Configuration/CaptureCameraDrawlistInConfiguration"
 :sd-access   :yes
 :ui-behavior :relative)

 ("Capture Camera In Active Configuration"
 :title          "Cattura obiettivo"
 :action         "(cfn_capture :consider_camera :on :consider_drawlist :off)"
 :description    "Cattura l'obiettivo nella configurazione attiva"
 :context-is-visible (cfn::cfn-configuration-is-modifiable 
                   (cfn::cfn-get-active-configuration))
 :enable         (AND (oli::sd-inq-current-vp)
                      (cfn::cfn-configuration-is-modifiable 
                        (cfn::cfn-get-active-configuration)))
 :image          "SolidDesigner/Configuration/CaptureCameraInConfiguration"
 :sd-access      :yes
 :ui-behavior    :relative)

 ("Capture Drawlist In Active Configuration"
 :title          "Cattura elementi a video"
 :action         "(cfn_capture :consider_camera :off :consider_drawlist :on)"
 :description    "Cattura gli elementi a video nella configurazione attiva"
 :context-is-visible (cfn::cfn-configuration-is-modifiable 
                   (cfn::cfn-get-active-configuration))
 :enable         (AND (oli::sd-inq-current-vp)
                      (cfn::cfn-configuration-is-modifiable 
                        (cfn::cfn-get-active-configuration)))
 :image          "SolidDesigner/Configuration/CaptureDrawlistInConfiguration"
 :sd-access      :yes
 :ui-behavior    :relative)


("Configuration Settings"
 :title       "Impostazioni configurazione"
 :action      (cfn::show-configuration-settings-container )
 :description "Impostazioni per la configurazione"
 :image          "SolidDesigner/Configuration/SettingsConfiguration"
 :sd-access :yes
 :ui-behavior :relative)

("Remove Data From Configuration"
 :title       "Rimuovi dati dalla configurazione"
 :action      "cfn_remove_data"
 :description "Rimuove i dati dalla configurazione"
 :image          "SolidDesigner/Configuration/RemoveDataFromConfiguration"
 :ui-behavior :relative)

("Highlight Configuration"
 :title       "Evidenzia"
 :action      "cfn_highlight_configuration"
 :description "Evidenzia lo spostamento degli oggetti di una configurazione"
 :image       "SolidDesigner/Configuration/HighlightConfiguration"
 :sd-access :yes
 :ui-behavior :relative)

("Hold Objects In Configuration"
 :title       "Mantieni oggetti nella configurazione"
 :action      "cfn_hold_object_in_configuration"
 :description "Mantiene gli oggetti nella configurazione"
 :image       "SolidDesigner/Configuration/AncorPartInConfiguration"
;; :image       "SolidDesigner/Configuration/CapturePartInConfiguration"
 :ui-behavior :relative)

("Explode Configuration"
 :title       "Esplodi"
 :action      "cfn_explode"
 :description "Esplode gli oggetti nella configurazione"
 :image        "SolidDesigner/Configuration/ExplodeConfiguration"
 :ui-behavior :relative)

("Copy Configuration"
 :title       "Copia configurazione"
 :action      "cfn_copy_configuration"
 :description "Copia la configurazione"
 :image       "SolidDesigner/Configuration/CopyConfiguration"
 :ui-behavior :relative)

("Modify Configuration"
 :title       "Modifica configurazione"
 :action      "cfn_modify_configuration"
 :description "Modifica la configurazione"
 :image       "SolidDesigner/Configuration/ModifyConfiguration"
 :ui-behavior :relative)

("Convert Formations"
 :title       "Coverti formazioni"
 :action      "cfn_convert_formations"
 :description "Coverte le formazioni in configurazione "
 :image       "SolidDesigner/Configuration/ConvertConfiguration"
 :ui-behavior :relative)

("Multiple Positions"
 :title       "Posizioni multiple"
 :action      "cfn_multiple_positions"
 :description "Posizioni multiple all'interno di un contenitore "
 :image        "SolidDesigner/Configuration/MultiplePositions"
 :ui-behavior :relative)

                                                                                                                   ;-------------------------------------------------------

(:Group "Clash Analysis" :title "Analisi di interferenza")

("Create Clash Analysis"
 :title       "Crea analisi di interferenza"
 :action      "clash_analysis_define :create_new"
 :description "Crea un'analisi di interferenza."
 :image       "SolidDesigner/Part_Assy/clash_analysis_create"
 :ui-behavior :relative)

("Modify Clash Analysis"
 :title       "Modifica analisi di interferenza"
 :action      "clash_analysis_define"
 :description "Modifica la definizione di un'analisi di interferenza."
 :image       "SolidDesigner/Part_Assy/clash_analysis_modify"
 :ui-behavior :relative)

("Rename Clash Analysis"
 :title       "Rinomina analisi di interferenza"
 :action      "rename_analysis"
 :description "Rinomina un'analisi di interferenza."
 :image       "SolidDesigner/Part_Assy/clash_analysis_rename"
 :sd-access   :yes
 :ui-behavior :relative)

("Delete Clash Analysis"
 :title       "Elimina analisi di interferenza"
 :action      "delete_analysis"
 :description "Elimina un'analisi di interferenza."
 :image       "SolidDesigner/Part_Assy/clash_analysis_delete"
 :sd-access   :yes
 :ui-behavior :relative)

("Clear Clash Issues"
 :title       "Rimuovi problemi di interferenza"
 :action      "clear_analysis_issues"
 :description "Rimuove tutti i problemi di un'analisi di interferenza."
 :image       "SolidDesigner/Part_Assy/clash_analysis_clear_issues"
 :sd-access   :yes
 :ui-behavior :relative)

("Calculate Clash Analysis"
 :title       "Calcola analisi di interferenza"
 :action      "clash_analysis_calculate"
 :description "Calcola un'analisi di interferenza"
 :image       "SolidDesigner/Part_Assy/clash_analysis_calculate"
 :sd-access   :yes
 :ui-behavior :relative)

("Clash Analysis Settings"
 :title       "Impostazioni analisi di interferenza"
 :action      (elan::show-clash-analysis-settings-ui)
 :description "Impostazioni per un'analisi di interferenza"
 :sd-access   :yes
 :ui-behavior :relative)
